@@ -59,9 +59,9 @@
     \value FileNameRole
 */
 
-QT_BEGIN_NAMESPACE
+using namespace GammaRay;
 
-class ResourceModelPrivate
+class GammaRay::ResourceModelPrivate
 {
     Q_DECLARE_PUBLIC(ResourceModel)
     ResourceModel * const q_ptr;
@@ -69,7 +69,7 @@ class ResourceModelPrivate
 public:
     struct QDirNode
     {
-        QDirNode() : parent(0), populated(false), stat(false) {}
+        QDirNode() : parent(nullptr), populated(false), stat(false) {}
         ~QDirNode() { children.clear(); }
         QDirNode *parent;
         QFileInfo info;
@@ -228,7 +228,7 @@ ResourceModel::ResourceModel(const QStringList &nameFilters,
     d->nameFilters = nameFilters.isEmpty() ? QStringList(QLatin1String("*")) : nameFilters;
     d->filters = filters;
     d->sort = sort;
-    d->root.parent = 0;
+    d->root.parent = nullptr;
     d->root.info = QFileInfo();
     d->clear(&d->root);
 }
@@ -273,7 +273,7 @@ QModelIndex ResourceModel::index(int row, int column, const QModelIndex &parent)
     if (row >= p->children.count())
         return QModelIndex();
     // now get the internal pointer for the index
-    ResourceModelPrivate::QDirNode *n = d->node(row, d->indexValid(parent) ? p : 0);
+    ResourceModelPrivate::QDirNode *n = d->node(row, d->indexValid(parent) ? p : nullptr);
     Q_ASSERT(n);
 
     return createIndex(row, column, n);
@@ -290,8 +290,8 @@ QModelIndex ResourceModel::parent(const QModelIndex &child) const
     if (!d->indexValid(child))
 	return QModelIndex();
     ResourceModelPrivate::QDirNode *node = d->node(child);
-    ResourceModelPrivate::QDirNode *par = (node ? node->parent : 0);
-    if (par == 0) // parent is the root node
+    ResourceModelPrivate::QDirNode *par = (node ? node->parent : nullptr);
+    if (par == nullptr) // parent is the root node
 	return QModelIndex();
 
     // get the parent's row
@@ -1123,7 +1123,7 @@ void ResourceModelPrivate::init()
     filters = QDir::AllEntries | QDir::NoDotAndDotDot;
     sort = QDir::Name;
     nameFilters << QLatin1String("*");
-    root.parent = 0;
+    root.parent = nullptr;
     root.info = QFileInfo(":");
     clear(&root);
     QHash<int, QByteArray> roles = q->roleNames();
@@ -1135,7 +1135,7 @@ void ResourceModelPrivate::init()
 ResourceModelPrivate::QDirNode *ResourceModelPrivate::node(int row, QDirNode *parent) const
 {
     if (row < 0)
-	return 0;
+	return nullptr;
 
     bool isDir = !parent || parent->info.isDir();
     QDirNode *p = (parent ? parent : &root);
@@ -1144,7 +1144,7 @@ ResourceModelPrivate::QDirNode *ResourceModelPrivate::node(int row, QDirNode *pa
 
     if (row >= p->children.count()) {
         qWarning("node: the row does not exist");
-        return 0;
+        return nullptr;
     }
 
     return const_cast<QDirNode*>(&p->children.at(row));
@@ -1155,7 +1155,7 @@ QVector<ResourceModelPrivate::QDirNode> ResourceModelPrivate::children(QDirNode
     Q_ASSERT(parent);
     QFileInfoList infoList;
     if (parent == &root) {
-        parent = 0;
+        parent = nullptr;
         infoList.append(root.info);
     } else if (parent->info.isDir()) {
         //resolve directory links only if requested.
@@ -1322,7 +1322,7 @@ void ResourceModelPrivate::appendChild(ResourceModelPrivate::QDirNode *parent, c
     ResourceModelPrivate::QDirNode node;
     node.populated = false;
     node.stat = shouldStat;
-    node.parent = (parent == &root ? 0 : parent);
+    node.parent = (parent == &root ? nullptr : parent);
     node.info = QFileInfo(path);
     node.info.setCaching(true);
 
@@ -1360,6 +1360,4 @@ QFileInfo ResourceModelPrivate::resolvedInfo(QFileInfo info)
 #endif
 }
 
-QT_END_NAMESPACE
-
 #include "moc_resourcemodel.cpp"
