@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,14 +45,14 @@ class InternalLauncher : public Launcher
 {
     Q_OBJECT
 public:
-    explicit InternalLauncher(const LaunchOptions &options, QObject *parent = 0)
+    explicit InternalLauncher(const LaunchOptions &options, QObject *parent = nullptr)
         : Launcher(options, parent) {}
 
 signals:
     void launchClient(const QUrl &serverAddress);
 
 protected:
-    void startClient(const QUrl &serverAddress) Q_DECL_OVERRIDE
+    void startClient(const QUrl &serverAddress) override
     {
         emit launchClient(serverAddress);
     }
@@ -62,7 +62,7 @@ class Orchestrator : public QObject
 {
     Q_OBJECT
 public:
-    explicit Orchestrator(QObject *parent = 0)
+    explicit Orchestrator(QObject *parent = nullptr)
         : QObject(parent)
     {
         m_launcherWindow = new LauncherWindow;
