@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ using namespace GammaRay;
 
 Client::Client(QObject *parent)
     : Endpoint(parent)
-    , m_clientDevice(0)
+    , m_clientDevice(nullptr)
     , m_statModel(new MessageStatisticsModel)
     , m_initState(0)
 {
@@ -89,8 +89,7 @@ void Client::connectToHost(const QUrl &url, int tryAgain)
 
     connect(m_clientDevice, SIGNAL(connected()), this, SLOT(socketConnected()));
     connect(m_clientDevice, SIGNAL(transientError()), this, SIGNAL(transientConnectionError()));
-    connect(m_clientDevice, SIGNAL(persistentError(QString)), this,
-            SIGNAL(persisitentConnectionError(QString)));
+    connect(m_clientDevice, SIGNAL(persistentError(QString)), this, SIGNAL(persisitentConnectionError(QString)));
     connect(m_clientDevice, SIGNAL(transientError()), this, SLOT(resetClientDevice()));
     connect(m_clientDevice, SIGNAL(persistentError(QString)), this, SLOT(resetClientDevice()));
     m_clientDevice->setTryAgain(tryAgain);
@@ -101,7 +100,6 @@ void Client::disconnectFromHost()
 {
     if (m_clientDevice) {
         m_clientDevice->disconnectFromHost();
-        resetClientDevice();
     }
 }
 
@@ -115,7 +113,7 @@ void Client::resetClientDevice()
 {
     if (m_clientDevice) {
         m_clientDevice->deleteLater();
-        m_clientDevice = 0;
+        m_clientDevice = nullptr;
     }
 }
 
@@ -140,7 +138,8 @@ void Client::messageReceived(const Message &msg)
         qint32 serverVersion;
         msg >> serverVersion;
         if (serverVersion != Protocol::version()) {
-            emit persisitentConnectionError(tr("Server version is %1, was expecting %2.").arg(
+            emit persisitentConnectionError(tr("Gammaray Protocol Mismatch.\n" \
+                                               "Probe version is %1, was expecting %2.").arg(
                                                 serverVersion).arg(Protocol::version()));
             disconnectFromHost();
         }
@@ -190,8 +189,10 @@ void Client::messageReceived(const Message &msg)
         case Protocol::ServerInfo:
         {
             QString label;
-            msg >> label;
+            QString key;
+            msg >> label >> key;
             setLabel(label);
+            setKey(key);
             m_initState |= ServerInfoReceived;
             break;
         }
