@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ class Client : public Endpoint
 {
     Q_OBJECT
 public:
-    explicit Client(QObject *parent = 0);
+    explicit Client(QObject *parent = nullptr);
     ~Client();
 
     /** Connect to a server reachable on @p url. */
@@ -53,21 +53,19 @@ public:
     /**
      * Register a client-side QObject to send/receive messages to/from the server side.
      */
-    Protocol::ObjectAddress registerObject(const QString &name, QObject *object) Q_DECL_OVERRIDE;
+    Protocol::ObjectAddress registerObject(const QString &name, QObject *object) override;
 
     /** Singleton accessor. */
     static Client *instance();
 
-    bool isRemoteClient() const Q_DECL_OVERRIDE;
-    QUrl serverAddress() const Q_DECL_OVERRIDE;
+    bool isRemoteClient() const override;
+    QUrl serverAddress() const override;
 
     void registerMessageHandler(Protocol::ObjectAddress objectAddress, QObject *receiver,
-                                const char *messageHandlerName) Q_DECL_OVERRIDE;
-    void unregisterMessageHandler(Protocol::ObjectAddress objectAddress) Q_DECL_OVERRIDE;
+                                const char *messageHandlerName) override;
+    void unregisterMessageHandler(Protocol::ObjectAddress objectAddress) override;
 
 signals:
-    /** Emitted when we successfully established a connection and passed the protocol version handshake step. */
-    void connectionEstablished();
     /** Emitted on transient connection errors.
      *  That is, on errors it's worth re-trying, e.g. because the target wasn't up yet.
      */
@@ -78,12 +76,12 @@ signals:
     void persisitentConnectionError(const QString &msg);
 
 protected:
-    void messageReceived(const Message &msg) Q_DECL_OVERRIDE;
+    void messageReceived(const Message &msg) override;
     void objectDestroyed(Protocol::ObjectAddress objectAddress, const QString &objectName,
-                         QObject *object) Q_DECL_OVERRIDE;
+                         QObject *object) override;
     void handlerDestroyed(Protocol::ObjectAddress objectAddress,
-                          const QString &objectName) Q_DECL_OVERRIDE;
-    void doSendMessage(const GammaRay::Message &msg) Q_DECL_OVERRIDE;
+                          const QString &objectName) override;
+    void doSendMessage(const GammaRay::Message &msg) override;
 
 private:
     void monitorObject(Protocol::ObjectAddress objectAddress);
