@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ class ClientDevice : public QObject
 {
     Q_OBJECT
 public:
-    explicit ClientDevice(QObject *parent = 0);
+    explicit ClientDevice(QObject *parent = nullptr);
     ~ClientDevice();
 
     static ClientDevice *create(const QUrl &url, QObject *parent);
@@ -68,13 +68,13 @@ template<typename ClientT>
 class ClientDeviceImpl : public ClientDevice
 {
 public:
-    explicit ClientDeviceImpl(QObject *parent = 0)
+    explicit ClientDeviceImpl(QObject *parent = nullptr)
         : ClientDevice(parent)
-        , m_socket(0)
+        , m_socket(nullptr)
     {
     }
 
-    QIODevice *device() const Q_DECL_OVERRIDE
+    QIODevice *device() const override
     {
         return m_socket;
     }
