@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,6 +32,7 @@
 #include "gammaray_client_export.h"
 #include <common/objectmodel.h>
 #include <common/protocol.h>
+#include <common/remotemodelroles.h>
 
 #include <QAbstractItemModel>
 #include <QRegExp>
@@ -56,41 +57,29 @@ class GAMMARAY_CLIENT_EXPORT RemoteModel : public QAbstractItemModel
         QRegExp filterRegExp READ proxyFilterRegExp WRITE setProxyFilterRegExp NOTIFY proxyFilterRegExpChanged)
 
 public:
-    explicit RemoteModel(const QString &serverObject, QObject *parent = 0);
+    explicit RemoteModel(const QString &serverObject, QObject *parent = nullptr);
     ~RemoteModel();
 
     bool isConnected() const;
 
     QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QModelIndex parent(const QModelIndex &child) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                      const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex &child) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     bool setData(const QModelIndex &index, const QVariant &value,
-                 int role = Qt::EditRole) Q_DECL_OVERRIDE;
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+                 int role = Qt::EditRole) override;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) Q_DECL_OVERRIDE;
+                        int role = Qt::DisplayRole) const override;
+    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) override;
 
 public slots:
     void newMessage(const GammaRay::Message &msg);
     void serverRegistered(const QString &objectName, Protocol::ObjectAddress objectAddress);
     void serverUnregistered(const QString &objectName, Protocol::ObjectAddress objectAddress);
 
-public:
-    enum Roles {
-        LoadingState = ObjectModel::UserRole + 128 // TODO: Tidy up roles in general (and give loading state a proper id)
-    };
-    enum NodeState {
-        NoState = 0,
-        Empty = 1,
-        Loading = 2,
-        Outdated = 4
-    };
-    Q_DECLARE_FLAGS(NodeStates, NodeState)
-
 signals:
     void proxyDynamicSortFilterChanged();
     void proxyFilterCaseSensitivityChanged();
@@ -100,7 +89,7 @@ signals:
 private:
     struct Node { // represents one row
         Node()
-            : parent(0)
+            : parent(nullptr)
             , rowCount(-1)
             , columnCount(-1) {}
         ~Node();
@@ -121,7 +110,7 @@ private:
         qint32 columnCount;
         QVector<QHash<int, QVariant> > data; // column -> role -> data
         QVector<Qt::ItemFlags> flags;      // column -> flags
-        QVector<NodeStates> state;         // column -> state (cache outdated, waiting for data, etc)
+        QVector<RemoteModelNodeState::NodeStates> state;         // column -> state (cache outdated, waiting for data, etc)
     };
 
     void clear();
@@ -136,7 +125,7 @@ private:
     /** Checks if @p ancestor is a (grand)parent of @p child. */
     bool isAncestor(Node *ancestor, Node *child) const;
 
-    NodeStates stateForColumn(Node *node, int columnIndex) const;
+    RemoteModelNodeState::NodeStates stateForColumn(Node *node, int columnIndex) const;
 
     void requestRowColumnCount(const QModelIndex &index) const;
     void requestDataAndFlags(const QModelIndex &index) const;
@@ -204,7 +193,4 @@ private:
 };
 }
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(GammaRay::RemoteModel::NodeStates)
-Q_DECLARE_METATYPE(GammaRay::RemoteModel::NodeStates)
-
 #endif
