@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -81,6 +81,19 @@ void RemoteViewClient::sendWheelEvent(const QPoint &localPos, QPoint pixelDelta,
                                        << QVariant::fromValue(modifiers));
 }
 
+void RemoteViewClient::sendTouchEvent(int type, int touchDeviceType, int deviceCaps, int touchDeviceMaxTouchPoints, int modifiers,
+                                      Qt::TouchPointStates touchPointStates, const QList<QTouchEvent::TouchPoint> &touchPoints)
+{
+    Endpoint::instance()->invokeObject(name(), "sendTouchEvent", QVariantList()
+                                       << QVariant::fromValue(type)
+                                       << QVariant::fromValue(touchDeviceType)
+                                       << QVariant::fromValue(deviceCaps)
+                                       << QVariant::fromValue(touchDeviceMaxTouchPoints)
+                                       << QVariant::fromValue(modifiers)
+                                       << QVariant::fromValue(touchPointStates)
+                                       << QVariant::fromValue(touchPoints));
+}
+
 void RemoteViewClient::setViewActive(bool active)
 {
     Endpoint::instance()->invokeObject(name(), "setViewActive", QVariantList() << active);
