@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,18 +37,21 @@ class RemoteViewClient : public RemoteViewInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::RemoteViewInterface)
 public:
-    explicit RemoteViewClient(const QString &name, QObject *parent = Q_NULLPTR);
-    void requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode) Q_DECL_OVERRIDE;
-    void pickElementId(const GammaRay::ObjectId &id) Q_DECL_OVERRIDE;
+    explicit RemoteViewClient(const QString &name, QObject *parent = nullptr);
+    void requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode) override;
+    void pickElementId(const GammaRay::ObjectId &id) override;
     void sendKeyEvent(int type, int key, int modifiers,
                       const QString &text = QString(), bool autorep = false,
-                      ushort count = 1) Q_DECL_OVERRIDE;
+                      ushort count = 1) override;
     void sendMouseEvent(int type, const QPoint &localPos, int button, int buttons,
-                        int modifiers) Q_DECL_OVERRIDE;
+                        int modifiers) override;
     void sendWheelEvent(const QPoint &localPos, QPoint pixelDelta, QPoint angleDelta, int buttons,
-                        int modifiers) Q_DECL_OVERRIDE;
-    void setViewActive(bool active) Q_DECL_OVERRIDE;
-    void clientViewUpdated() Q_DECL_OVERRIDE;
+                        int modifiers) override;
+    void sendTouchEvent(int type, int touchDeviceType, int deviceCaps, int touchDeviceMaxTouchPoints, int modifiers,
+                        Qt::TouchPointStates touchPointStates, const QList<QTouchEvent::TouchPoint> &touchPoints)
+                        override;
+    void setViewActive(bool active) override;
+    void clientViewUpdated() override;
 };
 }
 
