@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,17 +36,19 @@
 using namespace GammaRay;
 using namespace std;
 
-Endpoint *Endpoint::s_instance = 0;
+Endpoint *Endpoint::s_instance = nullptr;
 
 Endpoint::Endpoint(QObject *parent)
     : QObject(parent)
     , m_propertySyncer(new PropertySyncer(this))
-    , m_socket(0)
+    , m_socket(nullptr)
     , m_myAddress(Protocol::InvalidObjectAddress +1)
 {
-    if (s_instance)
+    if (s_instance) {
         qCritical(
             "Found existing GammaRay::Endpoint instance - trying to attach to a GammaRay client?");
+    }
+
     Q_ASSERT(!s_instance);
     s_instance = this;
 
@@ -62,12 +64,12 @@ Endpoint::Endpoint(QObject *parent)
 
 Endpoint::~Endpoint()
 {
-    for (QHash<Protocol::ObjectAddress, ObjectInfo *>::const_iterator it =
-             m_addressMap.constBegin();
-         it != m_addressMap.constEnd(); ++it)
+    for (QHash<Protocol::ObjectAddress, ObjectInfo *>::const_iterator it = m_addressMap.constBegin();
+         it != m_addressMap.constEnd(); ++it) {
         delete it.value();
+    }
 
-    s_instance = 0;
+    s_instance = nullptr;
 }
 
 Endpoint *Endpoint::instance()
@@ -85,6 +87,7 @@ void Endpoint::sendMessage(const Message &msg)
 {
     if (!isConnected())
         return;
+
     doSendMessage(msg);
 }
 
@@ -138,30 +141,33 @@ void Endpoint::readyRead()
 
 void Endpoint::connectionClosed()
 {
-    m_socket = 0;
+    disconnect(m_socket.data(), SIGNAL(readyRead()), this, SLOT(readyRead()));
+    disconnect(m_socket.data(), SIGNAL(disconnected()), this, SLOT(connectionClosed()));
+    m_socket = nullptr;
     emit disconnected();
 }
 
 Protocol::ObjectAddress Endpoint::objectAddress(const QString &objectName) const
 {
     const QHash<QString, ObjectInfo *>::const_iterator it = m_nameMap.constFind(objectName);
+
     if (it != m_nameMap.constEnd())
         return it.value()->address;
+
     return Protocol::InvalidObjectAddress;
 }
 
 Protocol::ObjectAddress Endpoint::registerObject(const QString &name, QObject *object)
 {
-    ObjectInfo *obj = m_nameMap.value(name, 0);
+    ObjectInfo *obj = m_nameMap.value(name, nullptr);
+#if !defined(NDEBUG)
     Q_ASSERT(obj);
-
     Q_ASSERT(!obj->object);
-
     Q_ASSERT(obj->address != Protocol::InvalidObjectAddress);
-
-    // cppcheck-suppress nullPointerRedundantCheck
+#else
     if (!obj || obj->object || obj->address == Protocol::InvalidObjectAddress)
         return 0;
+#endif
 
     obj->object = object;
 
@@ -179,14 +185,14 @@ void Endpoint::invokeObject(const QString &objectName, const char *method,
     if (!isConnected())
         return;
 
-    ObjectInfo *obj = m_nameMap.value(objectName, 0);
+    ObjectInfo *obj = m_nameMap.value(objectName, nullptr);
+#if !defined(NDEBUG)
     Q_ASSERT(obj);
-
     Q_ASSERT(obj->address != Protocol::InvalidObjectAddress);
-
-    // cppcheck-suppress nullPointerRedundantCheck
+#else
     if (!obj || obj->address == Protocol::InvalidObjectAddress)
         return;
+#endif
 
     Message msg(obj->address, Protocol::MethodCall);
     const QByteArray name(method);
@@ -200,8 +206,9 @@ void Endpoint::invokeObjectLocal(QObject *object, const char *method,
 {
     Q_ASSERT(args.size() <= 10);
     QVector<MethodArgument> a(10);
-    for (int i = 0; i < args.size(); ++i)
+    for (int i = 0; i < args.size(); ++i) {
         a[i] = MethodArgument(args.at(i));
+    }
 
     QMetaObject::invokeMethod(object, method, a[0], a[1], a[2], a[3], a[4], a[5], a[6], a[7], a[8],
                               a[9]);
@@ -262,34 +269,37 @@ void Endpoint::unregisterMessageHandler(Protocol::ObjectAddress objectAddress)
     disconnect(obj->receiver, SIGNAL(destroyed(QObject*)), this,
                SLOT(handlerDestroyed(QObject*)));
     m_handlerMap.remove(obj->receiver, obj);
-    obj->receiver = 0;
+    obj->receiver = nullptr;
     obj->messageHandler = QMetaMethod();
 }
 
 void Endpoint::objectDestroyed(QObject *obj)
 {
-    ObjectInfo *info = m_objectMap.value(obj, 0);
+    ObjectInfo *info = m_objectMap.value(obj, nullptr);
+#if !defined(NDEBUG)
     Q_ASSERT(info);
-
     Q_ASSERT(info->object == obj);
-
-    // cppcheck-suppress nullPointerRedundantCheck
+#else
     if (!info || info->object != obj)
         return;
+#endif
 
-    info->object = 0;
+    info->object = nullptr;
     m_objectMap.remove(obj);
-    objectDestroyed(info->address, QString(info->name), obj); // copy the name, in case unregisterMessageHandlerInternal() is called inside
+    // copy the name, in case unregisterMessageHandlerInternal() is called inside
+    objectDestroyed(info->address, QString(info->name), obj);
 }
 
 void Endpoint::handlerDestroyed(QObject *obj)
 {
-    const QList<ObjectInfo *> objs = m_handlerMap.values(obj); // copy, the virtual method below likely changes the maps.
+    // copy, the virtual method below likely changes the maps.
+    const QList<ObjectInfo *> objs = m_handlerMap.values(obj);
     m_handlerMap.remove(obj);
     foreach (ObjectInfo *obj, objs) {
-        obj->receiver = 0;
+        obj->receiver = nullptr;
         obj->messageHandler = QMetaMethod();
-        handlerDestroyed(obj->address, QString(obj->name)); // copy the name, in case unregisterMessageHandlerInternal() is called inside
+        // copy the name, in case unregisterMessageHandlerInternal() is called inside
+        handlerDestroyed(obj->address, QString(obj->name));
     }
 }
 
@@ -333,10 +343,10 @@ QVector< QPair< Protocol::ObjectAddress, QString > > Endpoint::objectAddresses()
 {
     QVector<QPair<Protocol::ObjectAddress, QString> > addrs;
     addrs.reserve(m_addressMap.size());
-    for (QHash<Protocol::ObjectAddress, ObjectInfo *>::const_iterator it =
-             m_addressMap.constBegin();
-         it != m_addressMap.constEnd(); ++it)
+    for (QHash<Protocol::ObjectAddress, ObjectInfo *>::const_iterator it = m_addressMap.constBegin();
+         it != m_addressMap.constEnd(); ++it) {
         addrs.push_back(qMakePair(it.key(), it.value()->name));
+    }
     return addrs;
 }
 
@@ -385,3 +395,13 @@ void Endpoint::setLabel(const QString &label)
 {
     m_label = label;
 }
+
+QString Endpoint::key() const
+{
+    return m_key;
+}
+
+void Endpoint::setKey(const QString &key)
+{
+    m_key = key;
+}
