@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -106,6 +106,16 @@ public:
      */
     void setLabel(const QString &label);
 
+    /**
+     * Returns a fixed string uniquely describing the host program.
+     */
+    QString key() const;
+
+    /**
+     * Sets the fixed key of this instance used e.g. when saving settings.
+     */
+    void setKey(const QString &key);
+
     /**
      * Returns true for remote clients and false for the in-probe server endpoint.
      */
@@ -131,6 +141,8 @@ public slots:
     void sendMessage(const GammaRay::Message &msg);
 
 signals:
+    /** Emitted when a connection to another endpoint was successfully established and passed the protocol version handshake step. */
+    void connectionEstablished();
     /** Emitted when we lost the connection to the other endpoint. */
     void disconnected();
 
@@ -139,7 +151,7 @@ signals:
     void objectUnregistered(const QString &objectName, Protocol::ObjectAddress objectAddress);
 
 protected:
-    Endpoint(QObject *parent = 0);
+    Endpoint(QObject *parent = nullptr);
     /** Call with the socket once you have established a connection to another endpoint, takes ownership of @p device. */
     void setDevice(QIODevice *device);
 
@@ -197,8 +209,8 @@ private:
     {
         ObjectInfo()
             : address(Protocol::InvalidObjectAddress)
-            , object(0)
-            , receiver(0)
+            , object(nullptr)
+            , receiver(nullptr)
         {
         }
 
@@ -226,6 +238,7 @@ private:
     Protocol::ObjectAddress m_myAddress;
 
     QString m_label;
+    QString m_key;
 };
 }
 
