@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,7 +39,7 @@ class GammaRay::MethodArgumentPrivate : public QSharedData
 public:
     MethodArgumentPrivate()
         : QSharedData()
-        , data(0)
+        , data(nullptr)
         , unwrapVariant(true) {}
 
     MethodArgumentPrivate(const MethodArgumentPrivate &other)
@@ -47,7 +47,7 @@ public:
     {
         value = other.value;
         name = other.name;
-        data = 0;
+        data = nullptr;
         unwrapVariant = other.unwrapVariant;
     }
 
