@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -54,7 +54,11 @@ PluginManagerBase::~PluginManagerBase()
 
 QStringList PluginManagerBase::pluginPaths() const
 {
+#ifndef GAMMARAY_STATIC_PROBE
     return Paths::pluginPaths(GAMMARAY_PROBE_ABI);
+#else
+    return QStringList();
+#endif
 }
 
 QStringList PluginManagerBase::pluginFilter() const
@@ -85,6 +89,20 @@ void PluginManagerBase::scan(const QString &serviceType)
     m_errors.clear();
     QStringList loadedPluginNames;
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+    foreach (const auto &staticPlugin, QPluginLoader::staticPlugins()) {
+        PluginInfo pluginInfo(staticPlugin);
+
+        if (!pluginInfo.isValid() || loadedPluginNames.contains(pluginInfo.id()) || pluginInfo.interfaceId() != serviceType) {
+            qDebug() << "skipping static plugin " << pluginInfo.id() << pluginInfo.interfaceId();
+            continue;
+        }
+
+        if (createProxyFactory(pluginInfo, m_parent))
+            loadedPluginNames.push_back(pluginInfo.id());
+    }
+#endif
+
     foreach (const QString &pluginPath, pluginPaths()) {
         const QDir dir(pluginPath);
         IF_DEBUG(cout << "checking plugin path: " << qPrintable(dir.absolutePath()) << endl);
