@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -34,7 +34,7 @@ using namespace GammaRay;
 
 ProxyFactoryBase::ProxyFactoryBase(const PluginInfo &pluginInfo, QObject *parent)
     : QObject(parent)
-    , m_factory(0)
+    , m_factory(nullptr)
     , m_pluginInfo(pluginInfo)
 {
 }
@@ -57,13 +57,19 @@ void ProxyFactoryBase::loadPlugin()
 {
     if (m_factory)
         return;
-    QPluginLoader loader(pluginInfo().path(), this);
-    m_factory = loader.instance();
-    if (m_factory) {
-        m_factory->setParent(this);
+
+    if (!pluginInfo().isStatic()) {
+        QPluginLoader loader(pluginInfo().path(), this);
+        m_factory = loader.instance();
+        if (!m_factory) {
+            m_errorString = loader.errorString();
+            std::cerr << "error loading plugin " << qPrintable(pluginInfo().path())
+                      << ": " << qPrintable(loader.errorString()) << std::endl;
+        }
     } else {
-        m_errorString = loader.errorString();
-        std::cerr << "error loading plugin " << qPrintable(pluginInfo().path())
-                  << ": " << qPrintable(loader.errorString()) << std::endl;
+        m_factory = pluginInfo().staticInstance();
     }
+
+    if (m_factory)
+        m_factory->setParent(this);
 }
