@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,7 @@
 
 #include "plugininfo.h"
 
+#include <QCoreApplication>
 #include <QObject>
 #include <QString>
 
@@ -40,7 +41,7 @@ class ProxyFactoryBase : public QObject
 {
     Q_OBJECT
 public:
-    explicit ProxyFactoryBase(const PluginInfo &pluginInfo, QObject *parent = 0);
+    explicit ProxyFactoryBase(const PluginInfo &pluginInfo, QObject *parent = nullptr);
     ~ProxyFactoryBase();
 
     PluginInfo pluginInfo() const;
@@ -60,11 +61,11 @@ template<typename IFace>
 class ProxyFactory : public ProxyFactoryBase, public IFace
 {
 public:
-    explicit inline ProxyFactory(const PluginInfo &pluginInfo, QObject *parent = 0)
+    explicit inline ProxyFactory(const PluginInfo &pluginInfo, QObject *parent = nullptr)
         : ProxyFactoryBase(pluginInfo, parent) {}
     inline ~ProxyFactory() {}
 
-    QString id() const Q_DECL_OVERRIDE
+    QString id() const override
     {
         return pluginInfo().id();
     }
@@ -75,9 +76,9 @@ protected:
         loadPlugin();
         IFace *iface = qobject_cast<IFace *>(m_factory);
         if (!iface) {
-            m_errorString
-                = QObject::tr("Plugin does not provide an instance of %1.").
-                  arg(qobject_interface_iid<IFace *>());
+            m_errorString = qApp->translate("GammaRay::ProxyFactory",
+                                            "Plugin does not provide an instance of %1.")
+                                                .arg(qobject_interface_iid<IFace *>());
             std::cerr << "Failed to cast object from " << qPrintable(pluginInfo().path())
                       << " to " << qobject_interface_iid<IFace *>() << std::endl;
         }
