@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -35,6 +35,7 @@
 
 #include <QObject>
 #include <QPoint>
+#include <QTouchEvent>
 
 namespace GammaRay {
 class RemoteViewFrame;
@@ -49,7 +50,7 @@ public:
         RequestAll
     };
 
-    explicit RemoteViewInterface(const QString &name, QObject *parent = Q_NULLPTR);
+    explicit RemoteViewInterface(const QString &name, QObject *parent = nullptr);
 
     QString name() const;
 
@@ -67,6 +68,10 @@ public slots:
     virtual void sendWheelEvent(const QPoint &localPos, QPoint pixelDelta, QPoint angleDelta,
                                 int buttons, int modifiers) = 0;
 
+    virtual void sendTouchEvent(int type, int touchDeviceType, int deviceCaps, int touchDeviceMaxTouchPoints, int modifiers,
+                                Qt::TouchPointStates touchPointStates,
+                                const QList<QTouchEvent::TouchPoint> &touchPoints) = 0;
+
     virtual void setViewActive(bool active) = 0;
 
     /// Tell the server we are ready for the next frame.
@@ -76,6 +81,7 @@ signals:
     void reset();
     void elementsAtReceived(const GammaRay::ObjectIds &ids, int bestCandidate);
     void frameUpdated(const GammaRay::RemoteViewFrame &frame);
+    void requestClearFrameData();
 
 private:
     QString m_name;
@@ -83,8 +89,13 @@ private:
 
 }
 
+Q_DECLARE_METATYPE(QTouchEvent::TouchPoint)
+Q_DECLARE_METATYPE(Qt::TouchPointStates)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+Q_DECLARE_METATYPE(QTouchEvent::TouchPoint::InfoFlags)
+#endif
+Q_DECLARE_METATYPE(QList<QTouchEvent::TouchPoint>)
 Q_DECLARE_METATYPE(GammaRay::RemoteViewInterface::RequestMode)
-
 QT_BEGIN_NAMESPACE
 Q_DECLARE_INTERFACE(GammaRay::RemoteViewInterface, "com.kdab.GammaRay.RemoteViewInterface/1.0")
 QT_END_NAMESPACE
