@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,6 +32,8 @@
 #include "sourcelocation.h"
 #include "qmetaobjectvalidatorresult.h"
 #include "objectid.h"
+#include "enumdefinition.h"
+#include "enumvalue.h"
 
 #include <QMetaMethod>
 
@@ -67,4 +69,7 @@ void StreamOperators::registerOperators()
     qRegisterMetaTypeStreamOperators<GammaRay::VariantWrapper>();
     qRegisterMetaTypeStreamOperators<GammaRay::SourceLocation>();
     qRegisterMetaTypeStreamOperators<GammaRay::QMetaObjectValidatorResult::Results>();
+
+    qRegisterMetaTypeStreamOperators<EnumDefinition>();
+    qRegisterMetaTypeStreamOperators<EnumValue>();
 }
