@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,7 +37,7 @@ class ConnectionsExtensionInterface : public QObject
 {
     Q_OBJECT
 public:
-    explicit ConnectionsExtensionInterface(const QString &name, QObject *parent = 0);
+    explicit ConnectionsExtensionInterface(const QString &name, QObject *parent = nullptr);
     ~ConnectionsExtensionInterface();
 
     QString name() const;
