@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,7 +38,7 @@ class MethodsExtensionInterface : public QObject
     Q_OBJECT
     Q_PROPERTY(bool hasObject READ hasObject WRITE setHasObject NOTIFY hasObjectChanged)
 public:
-    explicit MethodsExtensionInterface(const QString &name, QObject *parent = 0);
+    explicit MethodsExtensionInterface(const QString &name, QObject *parent = nullptr);
     virtual ~MethodsExtensionInterface();
 
     const QString &name() const;
