@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,8 +33,7 @@
  *  Compatibility hacks to allow usage of more modern Qt5/C++11 features in Qt4 builds.
  */
 
-#define Q_DECL_OVERRIDE
-#define Q_NULLPTR 0
+#define override
 
 #define QStringLiteral(str) QString::fromUtf8("" str "", sizeof(str) - 1)
 #define QByteArrayLiteral(str) QByteArray("" str "", sizeof(str) - 1)
