@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -35,18 +35,20 @@
 #include "propertyadaptorfactory.h"
 #include "toolfactory.h"
 #include "varianthandler.h"
-#include "util.h"
+#include "enumrepositoryserver.h"
+#include "enumutil.h"
 
 #include <common/objectid.h>
 #include <common/propertymodel.h>
 
 #include <QDebug>
+#include <QMetaEnum>
 
 using namespace GammaRay;
 
 AggregatedPropertyModel::AggregatedPropertyModel(QObject *parent)
     : QAbstractItemModel(parent)
-    , m_rootAdaptor(0)
+    , m_rootAdaptor(nullptr)
     , m_inhibitAdaptorCreation(false)
 {
     qRegisterMetaType<GammaRay::PropertyAdaptor *>();
@@ -88,7 +90,7 @@ void AggregatedPropertyModel::clear()
 
     m_parentChildrenMap.clear();
     delete m_rootAdaptor;
-    m_rootAdaptor = 0;
+    m_rootAdaptor = nullptr;
 
     if (count)
         endRemoveRows();
@@ -151,7 +153,7 @@ QVariant AggregatedPropertyModel::data(PropertyAdaptor *adaptor, const PropertyD
         {
             // QMetaProperty::read sets QVariant::typeName to int for enums,
             // so we need to handle that separately here
-            const QString enumStr = Util::enumToString(d.value(), d.typeName().toLatin1(), adaptor->object().metaObject());
+            const QString enumStr = EnumUtil::enumToString(d.value(), d.typeName().toLatin1(), adaptor->object().metaObject());
             if (!enumStr.isEmpty())
                 return enumStr;
             return VariantHandler::displayString(d.value());
@@ -163,8 +165,14 @@ QVariant AggregatedPropertyModel::data(PropertyAdaptor *adaptor, const PropertyD
         }
         break;
     case Qt::EditRole:
-        if (column == 1)
+        if (column == 1) {
+            const auto me = EnumUtil::metaEnum(d.value(), d.typeName().toLatin1(), adaptor->object().metaObject());
+            if (me.isValid()) {
+                const auto num = EnumUtil::enumToInt(d.value(), me);
+                return QVariant::fromValue(EnumRepositoryServer::valueFromMetaEnum(num, me));
+            }
             return VariantHandler::serializableVariant(d.value());
+        }
         break;
     case Qt::ToolTipRole:
         return d.details();
@@ -207,9 +215,22 @@ bool AggregatedPropertyModel::setData(const QModelIndex &index, const QVariant &
     const auto adaptor = adaptorForIndex(index);
     switch (role) {
     case Qt::EditRole:
-        adaptor->writeProperty(index.row(), value);
+    {
+        if (value.userType() == qMetaTypeId<EnumValue>()) {
+            const auto d = adaptor->propertyData(index.row());
+            if (d.value().type() == QVariant::Int) {
+                adaptor->writeProperty(index.row(), value.value<EnumValue>().value());
+            } else {
+                auto v = d.value();
+                *(static_cast<int*>(v.data())) = value.value<EnumValue>().value();
+                adaptor->writeProperty(index.row(), v);
+            }
+        } else {
+            adaptor->writeProperty(index.row(), value);
+        }
         propagateWrite(adaptor);
         return true;
+    }
     case PropertyModel::ResetActionRole:
         adaptor->resetProperty(index.row());
         return true;
@@ -349,7 +370,7 @@ void AggregatedPropertyModel::propertyAdded(int first, int last)
     if (first >= children.size())
         children.resize(last + 1);
     else
-        children.insert(first, last - first + 1, 0);
+        children.insert(first, last - first + 1, nullptr);
     endInsertRows();
 }
 
@@ -426,7 +447,7 @@ void AggregatedPropertyModel::reloadSubTree(PropertyAdaptor *parentAdaptor, int
         auto oldRowCount = m_parentChildrenMap.value(oldAdaptor).size();
         if (oldRowCount > 0)
             beginRemoveRows(createIndex(index, 0, parentAdaptor), 0, oldRowCount - 1);
-        m_parentChildrenMap[parentAdaptor][index] = 0;
+        m_parentChildrenMap[parentAdaptor][index] = nullptr;
         m_parentChildrenMap.remove(oldAdaptor);
         delete oldAdaptor;
         if (oldRowCount)
