@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,16 +39,16 @@ class AssociativePropertyAdaptor : public PropertyAdaptor
 {
     Q_OBJECT
 public:
-    explicit AssociativePropertyAdaptor(QObject *parent = 0);
+    explicit AssociativePropertyAdaptor(QObject *parent = nullptr);
     ~AssociativePropertyAdaptor();
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
-    int count() const Q_DECL_OVERRIDE;
-    PropertyData propertyData(int index) const Q_DECL_OVERRIDE;
+    int count() const override;
+    PropertyData propertyData(int index) const override;
 #endif
 
 protected:
-    void doSetObject(const ObjectInstance &oi) Q_DECL_OVERRIDE;
+    void doSetObject(const ObjectInstance &oi) override;
 
 private:
     QVariant m_value;
