@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,17 +39,17 @@ class GAMMARAY_CORE_EXPORT AbstractAttributeModel : public QAbstractTableModel
 {
     Q_OBJECT
 public:
-    explicit AbstractAttributeModel(QObject *parent = Q_NULLPTR);
+    explicit AbstractAttributeModel(QObject *parent = nullptr);
     ~AbstractAttributeModel();
 
     void setAttributeType(const char *name);
 
-    int columnCount(const QModelIndex &parent) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const Q_DECL_OVERRIDE;
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
-    bool setData(const QModelIndex &index, const QVariant &value, int role) Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role) override;
 
 protected:
     virtual bool testAttribute(int attr) const = 0;
@@ -63,9 +63,9 @@ template<typename Class, typename Enum>
 class AttributeModel : public AbstractAttributeModel
 {
 public:
-    explicit AttributeModel(QObject *parent = Q_NULLPTR)
+    explicit AttributeModel(QObject *parent = nullptr)
         : AbstractAttributeModel(parent)
-        , m_obj(Q_NULLPTR)
+        , m_obj(nullptr)
     {
     }
 
@@ -82,14 +82,14 @@ public:
     }
 
 protected:
-    bool testAttribute(int attr) const Q_DECL_OVERRIDE
+    bool testAttribute(int attr) const override
     {
         if (!m_obj)
             return false;
         return m_obj->testAttribute(static_cast<Enum>(attr));
     }
 
-    void setAttribute(int attr, bool on) Q_DECL_OVERRIDE
+    void setAttribute(int attr, bool on) override
     {
         if (!m_obj)
             return;
