@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,9 +40,9 @@ template<typename MetaThing,
 class MetaObjectModel : public QAbstractItemModel
 {
 public:
-    explicit MetaObjectModel(QObject *parent = 0)
+    explicit MetaObjectModel(QObject *parent = nullptr)
         : QAbstractItemModel(parent)
-        , m_metaObject(0)
+        , m_metaObject(nullptr)
     {
     }
 
@@ -51,10 +51,10 @@ public:
         const auto oldRowCount = rowCount();
         if (oldRowCount) {
             beginRemoveRows(QModelIndex(), 0, oldRowCount - 1);
-            m_metaObject = 0;
+            m_metaObject = nullptr;
             endRemoveRows();
         } else {
-            m_metaObject = 0;
+            m_metaObject = nullptr;
         }
 
         if (!metaObject)
@@ -70,7 +70,7 @@ public:
         }
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid() || !m_metaObject
             || index.row() < 0 || index.row() >= rowCount(index.parent()))
@@ -87,7 +87,7 @@ public:
     }
 
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+                        int role = Qt::DisplayRole) const override
     {
         if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
             if (section == columnCount() - 1)
@@ -97,7 +97,7 @@ public:
         return QAbstractItemModel::headerData(section, orientation, role);
     }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!m_metaObject || parent.isValid())
             return 0;
@@ -105,7 +105,7 @@ public:
     }
 
     QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+                      const QModelIndex &parent = QModelIndex()) const override
     {
         if (row >= 0 && row < rowCount(parent) && column >= 0
             && column < columnCount(parent) && !parent.isValid())
@@ -113,7 +113,7 @@ public:
         return QModelIndex();
     }
 
-    QModelIndex parent(const QModelIndex &child) const Q_DECL_OVERRIDE
+    QModelIndex parent(const QModelIndex &child) const override
     {
         Q_UNUSED(child);
         return QModelIndex();
