@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -87,7 +87,7 @@ Q_DECLARE_METATYPE(QThread::Priority)
 
 void MetaObjectRepository::initQObjectTypes()
 {
-    MetaObject *mo = 0;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT0(QMetaObject);
     MO_ADD_PROPERTY_RO(QMetaObject, int, classInfoCount);
     MO_ADD_PROPERTY_RO(QMetaObject, int, classInfoOffset);
@@ -175,7 +175,7 @@ Q_DECLARE_METATYPE(Qt::SortOrder)
 
 void MetaObjectRepository::initIOTypes()
 {
-    MetaObject *mo = 0;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT1(QIODevice, QObject);
     MO_ADD_PROPERTY_RO(QIODevice, QIODevice::OpenMode, openMode);
     MO_ADD_PROPERTY(QIODevice, bool, isTextModeEnabled, setTextModeEnabled);
