@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,7 +42,7 @@ public:
         , q(parent) {}
     ~MultiSignalMapperPrivate() {}
 
-    int qt_metacall(QMetaObject::Call call, int methodId, void **args) Q_DECL_OVERRIDE
+    int qt_metacall(QMetaObject::Call call, int methodId, void **args) override
     {
         methodId = QObject::qt_metacall(call, methodId, args);
         if (methodId < 0)
@@ -101,5 +101,5 @@ void MultiSignalMapper::connectToSignal(QObject *sender, const QMetaMethod &sign
 {
     QMetaObject::connect(sender, signal.methodIndex(), d,
                          QObject::metaObject()->methodCount() + signal.methodIndex(), Qt::AutoConnection | Qt::UniqueConnection,
-                         0);
+                         nullptr);
 }
