@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,13 +42,13 @@ class ObjectMethodModel : public MetaObjectModel<QMetaMethod, &QMetaObject::meth
 {
     Q_OBJECT
 public:
-    explicit ObjectMethodModel(QObject *parent = 0);
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QMap< int, QVariant > itemData(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    explicit ObjectMethodModel(QObject *parent = nullptr);
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QMap< int, QVariant > itemData(const QModelIndex &index) const override;
 
 protected:
     QVariant metaData(const QModelIndex &index, const QMetaMethod &method,
-                      int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                      int role = Qt::DisplayRole) const override;
 };
 }
 
