@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,6 +45,7 @@
 #include <common/objectmodel.h>
 #include <common/sourcelocation.h>
 
+#include <QCoreApplication>
 #include <QModelIndex>
 #include <QObject>
 
@@ -70,7 +71,7 @@ public:
      * @param parent is the model QModelIndex.
      * @return the column count for specified model.
      */
-    int columnCount(const QModelIndex &parent = QModelIndex()) const
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override
     {
         Q_UNUSED(parent);
         return 2;
@@ -113,7 +114,7 @@ public:
         return QVariant();
     }
 
-    QMap<int, QVariant> itemData(const QModelIndex &index) const
+    QMap<int, QVariant> itemData(const QModelIndex &index) const override
     {
         QMap<int, QVariant> map = Base::itemData(index);
         map.insert(ObjectModel::ObjectIdRole, this->data(index, ObjectModel::ObjectIdRole));
@@ -137,14 +138,14 @@ public:
      *         QVariant() if some anamoly occurs.
      *
      */
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
     {
         if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
             switch (section) {
             case 0:
-                return QObject::tr("Object");
+                return qApp->translate("GammaRay::ObjectModelBase", "Object");
             case 1:
-                return QObject::tr("Type");
+                return qApp->translate("GammaRay::ObjectModelBase", "Type");
             }
         }
         return Base::headerData(section, orientation, role);
