@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
@@ -31,10 +31,10 @@
 #include <config-gammaray.h>
 
 #include "probe.h"
+#include "enumrepositoryserver.h"
 #include "metaobjectrepository.h"
 #include "objectlistmodel.h"
 #include "objecttreemodel.h"
-#include "metaobjecttreemodel.h"
 #include "probesettings.h"
 #include "probecontroller.h"
 #include "toolmanager.h"
@@ -97,7 +97,7 @@ extern QSignalSpyCallbackSet qt_signal_spy_callback_set;
 using namespace GammaRay;
 using namespace std;
 
-QAtomicPointer<Probe> Probe::s_instance = QAtomicPointer<Probe>(0);
+QAtomicPointer<Probe> Probe::s_instance = QAtomicPointer<Probe>(nullptr);
 
 namespace GammaRay {
 static void signal_begin_callback(QObject *caller, int method_index, void **argv)
@@ -206,29 +206,26 @@ Probe::Probe(QObject *parent)
     : QObject(parent)
     , m_objectListModel(new ObjectListModel(this))
     , m_objectTreeModel(new ObjectTreeModel(this))
-    , m_metaObjectTreeModel(new MetaObjectTreeModel(this))
-    , m_window(0)
+    , m_window(nullptr)
     , m_queueTimer(new QTimer(this))
-    , m_server(Q_NULLPTR)
+    , m_server(nullptr)
 {
     Q_ASSERT(thread() == qApp->thread());
-    IF_DEBUG(cout << "attaching GammaRay probe" << endl;
-             )
+    IF_DEBUG(cout << "attaching GammaRay probe" << endl;)
 
+    StreamOperators::registerOperators();
     ProbeSettings::receiveSettings();
 
     m_server = new Server(this);
-    ProbeSettings::sendServerAddress(m_server->externalAddress());
 
-    StreamOperators::registerOperators();
     ObjectBroker::setSelectionModelFactoryCallback(selectionModelFactory);
     ObjectBroker::registerObject<ProbeControllerInterface *>(new ProbeController(this));
     m_toolManager = new ToolManager(this);
     ObjectBroker::registerObject<ToolManagerInterface *>(m_toolManager);
 
+    EnumRepositoryServer::create(this);
     registerModel(QStringLiteral("com.kdab.GammaRay.ObjectTree"), m_objectTreeModel);
     registerModel(QStringLiteral("com.kdab.GammaRay.ObjectList"), m_objectListModel);
-    registerModel(QStringLiteral("com.kdab.GammaRay.MetaObjectModel"), m_metaObjectTreeModel);
 
     ToolPluginModel *toolPluginModel = new ToolPluginModel(
         m_toolManager->toolPluginManager()->plugins(), this);
@@ -270,7 +267,7 @@ Probe::~Probe()
     MetaObjectRepository::instance()->clear();
     VariantHandler::clear();
 
-    s_instance = QAtomicPointer<Probe>(0);
+    s_instance = QAtomicPointer<Probe>(nullptr);
 }
 
 void Probe::setWindow(QObject *window)
@@ -286,7 +283,7 @@ QObject *Probe::window() const
 Probe *GammaRay::Probe::instance()
 {
     if (!qApp)
-        return NULL;
+        return nullptr;
 
 #if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
     return s_instance;
@@ -320,7 +317,7 @@ void Probe::createProbe(bool findExisting)
     // example are QAbstractSocketEngine.
     IF_DEBUG(cout << "setting up new probe instance" << endl;
              )
-    Probe *probe = 0;
+    Probe *probe = nullptr;
     {
         ProbeGuard guard;
         probe = new Probe;
@@ -360,6 +357,7 @@ void Probe::resendServerAddress()
 {
     Q_ASSERT(isInitialized());
     Q_ASSERT(m_server);
+    Q_ASSERT(m_server->isListening());
     ProbeSettings::receiveSettings();
     ProbeSettings::sendServerAddress(m_server->externalAddress());
 }
@@ -388,7 +386,11 @@ void Probe::delayedInit()
     }
     if (appName.isEmpty())
         appName = tr("PID %1").arg(qApp->applicationPid());
-    Server::instance()->setLabel(appName);
+    m_server->setLabel(appName);
+    // The applicationName might be translated, so let's go with the application file base name
+    m_server->setKey(QFileInfo(qApp->applicationFilePath()).completeBaseName());
+    m_server->listen();
+    ProbeSettings::sendServerAddress(m_server->externalAddress());
 
     if (ProbeSettings::value(QStringLiteral("InProcessUi"), false).toBool())
         showInProcessUi();
@@ -487,11 +489,6 @@ QAbstractItemModel *Probe::objectTreeModel() const
     return m_objectTreeModel;
 }
 
-QAbstractItemModel *Probe::metaObjectModel() const
-{
-    return m_metaObjectTreeModel;
-}
-
 QObject *Probe::probe() const
 {
     return const_cast<GammaRay::Probe *>(this);
@@ -519,7 +516,6 @@ QMutex *Probe::objectLock()
  * (3) other thread, from ctor:
  * - wait until next event-loop re-entry in other thread (FIXME: we do not currently do this!!)
  * - post information to our thread
- * - emit objectCreated right away if object still valid
  * (4) other thread, after ctor:
  * - post information to our thread
  * - emit objectCreated there right away if object still valid
@@ -979,7 +975,7 @@ void Probe::registerSignalSpyCallbackSet(const SignalSpyCallbackSet &callbacks)
 
 void Probe::setupSignalSpyCallbacks()
 {
-    QSignalSpyCallbackSet cbs = { 0, 0, 0, 0 };
+    QSignalSpyCallbackSet cbs = { nullptr, nullptr, nullptr, nullptr };
     foreach (const auto &it, m_signalSpyCallbacks) {
         if (it.signalBeginCallback) cbs.signal_begin_callback = signal_begin_callback;
         if (it.signalEndCallback) cbs.signal_end_callback = signal_end_callback;
