@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,7 +49,6 @@ QT_END_NAMESPACE
 
 namespace GammaRay {
 class ProbeCreator;
-class MetaObjectTreeModel;
 class ObjectListModel;
 class ObjectTreeModel;
 class MainWindow;
@@ -76,23 +75,22 @@ public:
     static void objectAdded(QObject *obj, bool fromCtor = false);
     static void objectRemoved(QObject *obj);
 
-    QAbstractItemModel *objectListModel() const Q_DECL_OVERRIDE;
-    QAbstractItemModel *objectTreeModel() const Q_DECL_OVERRIDE;
-    QAbstractItemModel *metaObjectModel() const;
-    void registerModel(const QString &objectName, QAbstractItemModel *model) Q_DECL_OVERRIDE;
-    void installGlobalEventFilter(QObject *filter) Q_DECL_OVERRIDE;
-    bool needsObjectDiscovery() const Q_DECL_OVERRIDE;
-    void discoverObject(QObject *object) Q_DECL_OVERRIDE;
-    void selectObject(QObject *object, const QPoint &pos = QPoint()) Q_DECL_OVERRIDE;
+    QAbstractItemModel *objectListModel() const override;
+    QAbstractItemModel *objectTreeModel() const override;
+    void registerModel(const QString &objectName, QAbstractItemModel *model) override;
+    void installGlobalEventFilter(QObject *filter) override;
+    bool needsObjectDiscovery() const override;
+    void discoverObject(QObject *object) override;
+    void selectObject(QObject *object, const QPoint &pos = QPoint()) override;
     void selectObject(QObject *object, const QString &toolId,
-                      const QPoint &pos = QPoint()) Q_DECL_OVERRIDE;
-    void selectObject(void *object, const QString &typeName) Q_DECL_OVERRIDE;
-    void registerSignalSpyCallbackSet(const SignalSpyCallbackSet &callbacks) Q_DECL_OVERRIDE;
+                      const QPoint &pos = QPoint()) override;
+    void selectObject(void *object, const QString &typeName) override;
+    void registerSignalSpyCallbackSet(const SignalSpyCallbackSet &callbacks) override;
 
     QObject *window() const;
     void setWindow(QObject *window);
 
-    QObject *probe() const Q_DECL_OVERRIDE;
+    QObject *probe() const override;
 
     /**
      * Lock this to check the validity of a QObject
@@ -107,7 +105,7 @@ public:
      */
     bool isValidObject(QObject *obj) const;
 
-    bool filterObject(QObject *obj) const Q_DECL_OVERRIDE;
+    bool filterObject(QObject *obj) const override;
 
     /// internal
     static void startupHookReceived();
@@ -155,7 +153,7 @@ signals:
     void objectReparented(QObject *obj);
 
 protected:
-    bool eventFilter(QObject *receiver, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *receiver, QEvent *event) override;
 
 private slots:
     void delayedInit();
@@ -190,7 +188,7 @@ private:
     static void createProbe(bool findExisting);
     void resendServerAddress();
 
-    explicit Probe(QObject *parent = 0);
+    explicit Probe(QObject *parent = nullptr);
     static QAtomicPointer<Probe> s_instance;
 
     /** Set up all needed signal spy callbacks. */
@@ -198,7 +196,6 @@ private:
 
     ObjectListModel *m_objectListModel;
     ObjectTreeModel *m_objectTreeModel;
-    MetaObjectTreeModel *m_metaObjectTreeModel;
     ToolManager *m_toolManager;
     QObject *m_window;
     QSet<QObject *> m_validObjects;
