@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,11 +40,11 @@ class ProbeController : public ProbeControllerInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::ProbeControllerInterface)
 public:
-    explicit ProbeController(QObject *parent = 0);
+    explicit ProbeController(QObject *parent = nullptr);
 
 public slots:
-    void detachProbe() Q_DECL_OVERRIDE;
-    void quitHost() Q_DECL_OVERRIDE;
+    void detachProbe() override;
+    void quitHost() override;
 };
 }
 
