@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ class GAMMARAY_CORE_EXPORT PropertyAdaptor : public QObject
 {
     Q_OBJECT
 public:
-    explicit PropertyAdaptor(QObject *parent = 0);
+    explicit PropertyAdaptor(QObject *parent = nullptr);
     ~PropertyAdaptor();
 
     /** Returns the object instance who's properties this accesses. */
