@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,7 +49,7 @@ public:
     virtual ~AbstractPropertyAdaptorFactory();
 
     /** Create a custom property adaptor if it can handle @p oi, return @c nullptr otherwise. */
-    virtual PropertyAdaptor *create(const ObjectInstance &oi, QObject *parent = 0) const = 0;
+    virtual PropertyAdaptor *create(const ObjectInstance &oi, QObject *parent = nullptr) const = 0;
 
 private:
     Q_DISABLE_COPY(AbstractPropertyAdaptorFactory)
@@ -60,7 +60,7 @@ namespace PropertyAdaptorFactory {
 /** Create a property adaptor for @p oi, if necessary wrapped in an aggregator.
  *  Can return @c nullptr.
  */
-GAMMARAY_CORE_EXPORT PropertyAdaptor *create(const ObjectInstance &oi, QObject *parent = 0);
+GAMMARAY_CORE_EXPORT PropertyAdaptor *create(const ObjectInstance &oi, QObject *parent = nullptr);
 
 /** Register a custom property adaptor factory. */
 GAMMARAY_CORE_EXPORT void registerFactory(AbstractPropertyAdaptorFactory *factory);
