@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -101,7 +101,7 @@ void PropertyController::setObject(QObject *object)
 
 void PropertyController::setObject(void *object, const QString &className)
 {
-    setObject(0);
+    setObject(nullptr);
 
     QStringList availableExtensions;
 
@@ -115,7 +115,7 @@ void PropertyController::setObject(void *object, const QString &className)
 
 void PropertyController::setMetaObject(const QMetaObject *metaObject)
 {
-    setObject(0);
+    setObject(nullptr);
 
     QStringList availableExtensions;
 
@@ -129,5 +129,5 @@ void PropertyController::setMetaObject(const QMetaObject *metaObject)
 
 void PropertyController::objectDestroyed()
 {
-    setObject(0);
+    setObject(nullptr);
 }
