@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,17 +45,17 @@ class ProxyToolFactory : public ProxyFactory<ToolFactory>
     Q_OBJECT
 public:
     /**
-     * @param path Path to the plugin spec file
+     * @param pluginInfo Plugin spec file
      */
-    explicit ProxyToolFactory(const PluginInfo &pluginInfo, QObject *parent = 0);
+    explicit ProxyToolFactory(const PluginInfo &pluginInfo, QObject *parent = nullptr);
 
     /** Returns @c true if the plugin seems valid from all the information we have so far. */
     bool isValid() const;
 
-    bool isHidden() const Q_DECL_OVERRIDE;
-    QVector<QByteArray> selectableTypes() const Q_DECL_OVERRIDE;
+    bool isHidden() const override;
+    QVector<QByteArray> selectableTypes() const override;
 
-    void init(ProbeInterface *probe) Q_DECL_OVERRIDE;
+    void init(ProbeInterface *probe) override;
 };
 }
 
