@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,11 +45,11 @@
 using namespace GammaRay;
 using namespace std;
 
-void(*RemoteModelServer::s_registerServerCallback)() = 0;
+void(*RemoteModelServer::s_registerServerCallback)() = nullptr;
 
 RemoteModelServer::RemoteModelServer(const QString &objectName, QObject *parent)
     : QObject(parent)
-    , m_model(0)
+    , m_model(nullptr)
     , m_dummyBuffer(new QBuffer(&m_dummyData, this))
     , m_monitored(false)
 {
@@ -472,7 +472,7 @@ void RemoteModelServer::sendMoveMessage(Protocol::MessageType type,
 
 void RemoteModelServer::modelDeleted()
 {
-    m_model = 0;
+    m_model = nullptr;
     if (m_monitored)
         modelReset();
 }
