@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,12 +42,13 @@ class ServerDevice : public QObject
 {
     Q_OBJECT
 public:
-    explicit ServerDevice(QObject *parent = 0);
+    explicit ServerDevice(QObject *parent = nullptr);
     ~ServerDevice();
 
     void setServerAddress(const QUrl &serverAddress);
 
     virtual bool listen() = 0;
+    virtual bool isListening() const = 0;
     virtual QString errorString() const = 0;
     virtual QIODevice *nextPendingConnection() = 0;
 
@@ -56,7 +57,7 @@ public:
      */
     virtual QUrl externalAddress() const = 0;
 
-    static ServerDevice *create(const QUrl &serverAddress, QObject *parent = 0);
+    static ServerDevice *create(const QUrl &serverAddress, QObject *parent = nullptr);
 
     /** Broadcast the given message on an appropriate channel, if backend supports broadcasting. */
     virtual void broadcast(const QByteArray &data);
@@ -72,9 +73,9 @@ template<typename ServerT>
 class ServerDeviceImpl : public ServerDevice
 {
 public:
-    explicit inline ServerDeviceImpl(QObject *parent = 0)
+    explicit inline ServerDeviceImpl(QObject *parent = nullptr)
         : ServerDevice(parent)
-        , m_server(0)
+        , m_server(nullptr)
     {
     }
 
@@ -82,12 +83,12 @@ public:
     {
     }
 
-    QString errorString() const Q_DECL_OVERRIDE
+    QString errorString() const override
     {
         return m_server->errorString();
     }
 
-    QIODevice *nextPendingConnection() Q_DECL_OVERRIDE
+    QIODevice *nextPendingConnection() override
     {
         Q_ASSERT(m_server->hasPendingConnections());
         return m_server->nextPendingConnection();
