@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -44,9 +44,9 @@ namespace GammaRay {
 template<typename BaseProxy> class ServerProxyModel : public BaseProxy
 {
 public:
-    explicit ServerProxyModel(QObject *parent = 0)
+    explicit ServerProxyModel(QObject *parent = nullptr)
         : BaseProxy(parent)
-        , m_sourceModel(Q_NULLPTR)
+        , m_sourceModel(nullptr)
         , m_active(false)
     {
     }
@@ -58,14 +58,14 @@ public:
     }
 
     /** Additional roles used from the proxy model itself for transfer to the client.
-     *  This is useful if @tparam BaseProxy overrides data().
+     *  This is useful if BaseProxy overrides data().
      */
     void addProxyRole(int role)
     {
         m_extraProxyRoles.push_back(role);
     }
 
-    QMap<int, QVariant> itemData(const QModelIndex &index) const Q_DECL_OVERRIDE
+    QMap<int, QVariant> itemData(const QModelIndex &index) const override
     {
         const QModelIndex sourceIndex = BaseProxy::mapToSource(index);
         auto d = BaseProxy::sourceModel()->itemData(sourceIndex);
@@ -76,7 +76,7 @@ public:
         return d;
     }
 
-    void setSourceModel(QAbstractItemModel *sourceModel) Q_DECL_OVERRIDE
+    void setSourceModel(QAbstractItemModel *sourceModel) override
     {
         m_sourceModel = sourceModel;
         if (m_active && sourceModel) {
@@ -86,14 +86,14 @@ public:
     }
 
     QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+                      const QModelIndex &parent = QModelIndex()) const override
     {
         Model::used(this);
         return BaseProxy::index(row, column, parent);
     }
 
 protected:
-    void customEvent(QEvent *event) Q_DECL_OVERRIDE
+    void customEvent(QEvent *event) override
     {
         if (event->type() == ModelEvent::eventType()) {
             auto mev = static_cast<ModelEvent *>(event);
@@ -103,7 +103,7 @@ protected:
                 if (mev->used() && BaseProxy::sourceModel() != m_sourceModel)
                     BaseProxy::setSourceModel(m_sourceModel);
                 else if (!mev->used())
-                    BaseProxy::setSourceModel(0);
+                    BaseProxy::setSourceModel(nullptr);
             }
         }
         BaseProxy::customEvent(event);
