@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -56,6 +56,11 @@ bool TcpServerDevice::listen()
     return m_server->listen(address, 0);
 }
 
+bool TcpServerDevice::isListening() const
+{
+    return m_server->isListening();
+}
+
 QUrl TcpServerDevice::externalAddress() const
 {
     const QHostAddress address(m_server->serverAddress());
