@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ using namespace GammaRay;
 
 RemoteViewServer::RemoteViewServer(const QString &name, QObject *parent)
     : RemoteViewInterface(name, parent)
-    , m_eventReceiver(Q_NULLPTR)
+    , m_eventReceiver(nullptr)
     , m_updateTimer(new QTimer(this))
     , m_clientActive(false)
     , m_sourceChanged(false)
@@ -78,6 +78,13 @@ void RemoteViewServer::resetView()
         emit reset();
 }
 
+
+void RemoteViewServer::clearFrameData()
+{
+    if (isActive())
+        emit requestClearFrameData();
+}
+
 bool RemoteViewServer::isActive() const
 {
     return m_clientActive;
@@ -151,6 +158,33 @@ void RemoteViewServer::sendWheelEvent(const QPoint &localPos, QPoint pixelDelta,
     QCoreApplication::postEvent(m_eventReceiver, event);
 }
 
+void RemoteViewServer::sendTouchEvent(int type, int touchDeviceType, int deviceCaps, int touchDeviceMaxTouchPoints,
+                                      int modifiers, Qt::TouchPointStates touchPointStates, const QList<QTouchEvent::TouchPoint> &touchPoints)
+{
+    if (!m_eventReceiver)
+        return;
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    if (!m_touchDevice) {
+        //create our own touch device, the system may not have one already, or it may not have
+        //the properties we want
+        m_touchDevice.reset(new QTouchDevice);
+    }
+    m_touchDevice->setType(QTouchDevice::DeviceType(touchDeviceType));
+    m_touchDevice->setCapabilities(QTouchDevice::CapabilityFlag(deviceCaps));
+    m_touchDevice->setMaximumTouchPoints(touchDeviceMaxTouchPoints);
+
+    auto event = new QTouchEvent(QEvent::Type(type), m_touchDevice.get(), Qt::KeyboardModifiers(modifiers), touchPointStates, touchPoints);
+    event->setWindow(m_eventReceiver);
+
+#else
+    Q_UNUSED(deviceCaps)
+    Q_UNUSED(touchDeviceMaxTouchPoints)
+    auto event = new QTouchEvent(QEvent::Type(type), QTouchEvent::DeviceType(touchDeviceType), Qt::KeyboardModifiers(modifiers), touchPointStates, touchPoints);
+#endif
+    QCoreApplication::sendEvent(m_eventReceiver, event);
+}
+
 void RemoteViewServer::setViewActive(bool active)
 {
     m_clientActive = active;
