@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,8 @@
 #ifndef GAMMARAY_REMOTEVIEWSERVER_H
 #define GAMMARAY_REMOTEVIEWSERVER_H
 
+#include <memory>
+
 #include "gammaray_core_export.h"
 
 #include <common/remoteviewinterface.h>
@@ -36,6 +38,7 @@
 QT_BEGIN_NAMESPACE
 class QTimer;
 class QWindow;
+class QTouchDevice;
 QT_END_NAMESPACE
 
 namespace GammaRay {
@@ -45,7 +48,7 @@ class GAMMARAY_CORE_EXPORT RemoteViewServer : public RemoteViewInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::RemoteViewInterface)
 public:
-    explicit RemoteViewServer(const QString &name, QObject *parent = Q_NULLPTR);
+    explicit RemoteViewServer(const QString &name, QObject *parent = nullptr);
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     typedef QWindow EventReceiver;
@@ -58,6 +61,9 @@ public:
     /// resets the client view if the window selection changed
     void resetView();
 
+    /// clear the client current frame data
+    void clearFrameData();
+
     /// returns @c true if there is a client displaying our content
     bool isActive() const;
 
@@ -75,16 +81,19 @@ signals:
     void requestUpdate();
 
 private:
-    void requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode) Q_DECL_OVERRIDE;
-    void pickElementId(const GammaRay::ObjectId &id) Q_DECL_OVERRIDE;
+    void requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode) override;
+    void pickElementId(const GammaRay::ObjectId &id) override;
     void sendKeyEvent(int type, int key, int modifiers, const QString &text, bool autorep,
-                      ushort count) Q_DECL_OVERRIDE;
+                      ushort count) override;
     void sendMouseEvent(int type, const QPoint &localPos, int button, int buttons,
-                        int modifiers) Q_DECL_OVERRIDE;
+                        int modifiers) override;
     void sendWheelEvent(const QPoint &localPos, QPoint pixelDelta, QPoint angleDelta, int buttons,
-                        int modifiers) Q_DECL_OVERRIDE;
-    void setViewActive(bool active) Q_DECL_OVERRIDE;
-    void clientViewUpdated() Q_DECL_OVERRIDE;
+                        int modifiers) override;
+    void sendTouchEvent(int type, int touchDeviceType, int deviceCaps, int touchDeviceMaxTouchPoints, int modifiers,
+                        Qt::TouchPointStates touchPointStates, const QList<QTouchEvent::TouchPoint> &touchPoints) 
+                        override;
+    void setViewActive(bool active) override;
+    void clientViewUpdated() override;
 
     void checkRequestUpdate();
 
@@ -98,6 +107,9 @@ private:
     bool m_clientActive;
     bool m_sourceChanged;
     bool m_clientReady;
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    std::unique_ptr<QTouchDevice> m_touchDevice;
+#endif
 };
 }
 
