@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -130,12 +130,12 @@ public:
         setSupportedTypes(QVector<QByteArray>() << Type::staticMetaObject.className());
     }
 
-    QString id() const Q_DECL_OVERRIDE
+    QString id() const override
     {
         return Tool::staticMetaObject.className();
     }
 
-    void init(ProbeInterface *probe) Q_DECL_OVERRIDE
+    void init(ProbeInterface *probe) override
     {
         new Tool(probe, probe->probe());
     }
