@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,12 +45,16 @@ using namespace GammaRay;
 
 MetaObjectBrowser::MetaObjectBrowser(ProbeInterface *probe, QObject *parent)
     : QObject(parent)
-    , m_propertyController(new PropertyController(QStringLiteral(
-                                                      "com.kdab.GammaRay.MetaObjectBrowser"), this))
+    , m_propertyController(new PropertyController(QStringLiteral("com.kdab.GammaRay.MetaObjectBrowser"), this))
+    , m_motm(new MetaObjectTreeModel(this))
+    , m_model(nullptr)
 {
+    connect(probe->probe(), SIGNAL(objectCreated(QObject*)), m_motm, SLOT(objectAdded(QObject*)));
+    connect(probe->probe(), SIGNAL(objectDestroyed(QObject*)), m_motm, SLOT(objectRemoved(QObject*)));
+
     auto model = new ServerProxyModel<KRecursiveFilterProxyModel>(this);
     model->addRole(QMetaObjectModel::MetaObjectIssues);
-    model->setSourceModel(Probe::instance()->metaObjectModel());
+    model->setSourceModel(m_motm);
     m_model = model;
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.MetaObjectBrowserTreeModel"), m_model);
 
@@ -59,12 +63,19 @@ MetaObjectBrowser::MetaObjectBrowser(ProbeInterface *probe, QObject *parent)
     connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             SLOT(objectSelected(QItemSelection)));
 
-    m_propertyController->setMetaObject(0); // init
+    m_propertyController->setMetaObject(nullptr); // init
 
     connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), this,
             SLOT(objectSelected(QObject*)));
     connect(probe->probe(), SIGNAL(nonQObjectSelected(void*,QString)), this,
             SLOT(objectSelected(void*,QString)));
+
+    ObjectBroker::registerObject(QStringLiteral("com.kdab.GammaRay.MetaObjectBrowser"), this);
+}
+
+void MetaObjectBrowser::rescanMetaTypes()
+{
+    m_motm->scanMetaTypes();
 }
 
 void MetaObjectBrowser::objectSelected(const QItemSelection &selection)
@@ -78,7 +89,7 @@ void MetaObjectBrowser::objectSelected(const QItemSelection &selection)
             = index.data(QMetaObjectModel::MetaObjectRole).value<const QMetaObject*>();
         m_propertyController->setMetaObject(metaObject);
     } else {
-        m_propertyController->setMetaObject(0);
+        m_propertyController->setMetaObject(nullptr);
     }
 }
 
