@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -40,17 +40,17 @@ class AbstractConnectionsModel : public QAbstractTableModel
 {
     Q_OBJECT
 public:
-    explicit AbstractConnectionsModel(QObject *parent = 0);
+    explicit AbstractConnectionsModel(QObject *parent = nullptr);
     ~AbstractConnectionsModel();
 
     virtual void setObject(QObject *object) = 0;
 
-    int columnCount(const QModelIndex &parent) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &parent) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent) const override;
+    int rowCount(const QModelIndex &parent) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    QMap< int, QVariant > itemData(const QModelIndex &index) const Q_DECL_OVERRIDE;
+                        int role = Qt::DisplayRole) const override;
+    QMap< int, QVariant > itemData(const QModelIndex &index) const override;
 
 protected:
     struct Connection {
