@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,14 +37,14 @@ class InboundConnectionsModel : public AbstractConnectionsModel
 {
     Q_OBJECT
 public:
-    explicit InboundConnectionsModel(QObject *parent = 0);
+    explicit InboundConnectionsModel(QObject *parent = nullptr);
     ~InboundConnectionsModel();
 
-    void setObject(QObject *object) Q_DECL_OVERRIDE;
+    void setObject(QObject *object) override;
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                        int role = Qt::DisplayRole) const override;
 };
 }
 
