@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -53,13 +53,13 @@ public:
     explicit MethodsExtension(PropertyController *controller);
     ~MethodsExtension();
 
-    bool setQObject(QObject *object) Q_DECL_OVERRIDE;
-    bool setMetaObject(const QMetaObject *metaObject) Q_DECL_OVERRIDE;
+    bool setQObject(QObject *object) override;
+    bool setMetaObject(const QMetaObject *metaObject) override;
 
 public slots:
-    void activateMethod() Q_DECL_OVERRIDE;
-    void invokeMethod(Qt::ConnectionType type) Q_DECL_OVERRIDE;
-    void connectToSignal() Q_DECL_OVERRIDE;
+    void activateMethod() override;
+    void invokeMethod(Qt::ConnectionType type) override;
+    void connectToSignal() override;
 
 private slots:
     void signalEmitted(QObject *sender, int signalIndex, const QVector<QVariant> &args);
