@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -83,7 +83,7 @@ void ObjectInspector::objectSelected(const QModelIndex &index)
         QObject *obj = index.data(ObjectModel::ObjectRole).value<QObject *>();
         m_propertyController->setObject(obj);
     } else {
-        m_propertyController->setObject(0);
+        m_propertyController->setObject(nullptr);
     }
 }
 
