@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,7 +46,7 @@ class ObjectInspector : public QObject
 {
     Q_OBJECT
 public:
-    explicit ObjectInspector(ProbeInterface *probe, QObject *parent = 0);
+    explicit ObjectInspector(ProbeInterface *probe, QObject *parent = nullptr);
 
 private slots:
     void objectSelected(const QModelIndex &index);
@@ -70,7 +70,7 @@ public:
     {
     }
 
-    QVector<QByteArray> selectableTypes() const Q_DECL_OVERRIDE;
+    QVector<QByteArray> selectableTypes() const override;
 };
 }
 
