@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,7 +36,7 @@ class StandardPaths : public QObject
 {
     Q_OBJECT
 public:
-    explicit StandardPaths(ProbeInterface *probe, QObject *parent = 0);
+    explicit StandardPaths(ProbeInterface *probe, QObject *parent = nullptr);
     ~StandardPaths();
 };
 
