@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -28,7 +28,9 @@
 
 #include "varianthandler.h"
 #include "util.h"
-#include "common/metatypedeclarations.h"
+#include "enumutil.h"
+
+#include <common/metatypedeclarations.h>
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #include <QApplication>
@@ -57,13 +59,18 @@
 using namespace GammaRay;
 
 namespace GammaRay {
-struct VariantHandlerRepository
+class VariantHandlerRepository
 {
+public:
+    VariantHandlerRepository() {};
     ~VariantHandlerRepository();
     void clear();
 
     QHash<int, VariantHandler::Converter<QString> *> stringConverters;
     QVector<VariantHandler::GenericStringConverter> genericStringConverters;
+
+private:
+    Q_DISABLE_COPY(VariantHandlerRepository)
 };
 
 VariantHandlerRepository::~VariantHandlerRepository()
@@ -118,14 +125,14 @@ QString VariantHandler::displayString(const QVariant &value)
     case QVariant::Cursor:
     {
         const QCursor cursor = value.value<QCursor>();
-        return Util::enumToString(QVariant::fromValue<int>(cursor.shape()), "Qt::CursorShape");
+        return EnumUtil::enumToString(QVariant::fromValue<int>(cursor.shape()), "Qt::CursorShape");
     }
 #endif
     case QVariant::Icon:
     {
         const QIcon icon = value.value<QIcon>();
         if (icon.isNull())
-            return QObject::tr("<no icon>");
+            return qApp->translate("GammaRay::VariantHandler", "<no icon>");
         const auto sizes = icon.availableSizes();
         QStringList l;
         l.reserve(sizes.size());
@@ -262,7 +269,7 @@ QString VariantHandler::displayString(const QVariant &value)
     // types with dynamic type ids
     if (value.userType() == qMetaTypeId<QMargins>()) {
         const QMargins margins = value.value<QMargins>();
-        return QObject::tr("left: %1, top: %2, right: %3, bottom: %4")
+        return qApp->translate("GammaRay::VariantHandler", "left: %1, top: %2, right: %3, bottom: %4")
                .arg(margins.left()).arg(margins.top())
                .arg(margins.right()).arg(margins.bottom());
     }
@@ -307,7 +314,7 @@ QString VariantHandler::displayString(const QVariant &value)
 #endif // Qt5
 
     // enums
-    const QString enumStr = Util::enumToString(value);
+    const QString enumStr = EnumUtil::enumToString(value);
     if (!enumStr.isEmpty())
         return enumStr;
 
