@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,9 +38,9 @@ class PreloadInjector : public ProcessInjector
     Q_OBJECT
 public:
     PreloadInjector();
-    QString name() const Q_DECL_OVERRIDE;
+    QString name() const override;
     bool launch(const QStringList &programAndArgs, const QString &probeDll,
-                const QString &probeFunc, const QProcessEnvironment &env) Q_DECL_OVERRIDE;
+                const QString &probeFunc, const QProcessEnvironment &env) override;
 };
 }
 
