@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -84,12 +84,16 @@ static QStringList dllSearchPaths(const QString &exePath)
 }
 
 /** Resolves imports given a list of search paths. */
-static QString resolveImport(const QString &import, const QStringList &searchPaths)
+static QString resolveImport(const QString &import, const QStringList &searchPaths, const QString &arch)
 {
     foreach (const auto &path, searchPaths) {
         const QString absPath = path + '/' + import;
-        if (QFile::exists(absPath))
-            return absPath;
+        if (!QFile::exists(absPath))
+            continue;
+        PEFile f(absPath);
+        if (!f.isValid() || f.architecture() != arch)
+            continue;
+        return absPath;
     }
     qDebug() << "Could not resolve import" << import << "in" << searchPaths;
     return QString();
@@ -114,7 +118,7 @@ QString ProbeABIDetector::qtCoreForExecutable(const QString &path) const
                 continue;
 
             foreach (const auto &import, f.imports()) {
-                const auto absPath = resolveImport(import, searchPaths);
+                const auto absPath = resolveImport(import, searchPaths, f.architecture());
                 if (!absPath.isEmpty() && !checkedImports.contains(import))
                     resolvedSubImports.push_back(absPath);
                 checkedImports.insert(import);
@@ -151,7 +155,7 @@ QString ProbeABIDetector::qtCoreForProcess(quint64 pid) const
 static QString compilerFromLibraries(const QStringList &libraries)
 {
     foreach (const QString &lib, libraries) {
-        if (lib.toLower().startsWith(QLatin1String("libgcc")))
+        if (lib.startsWith(QLatin1String("libgcc"), Qt::CaseInsensitive))
             return "GNU";
     }
 
@@ -161,9 +165,9 @@ static QString compilerFromLibraries(const QStringList &libraries)
 static bool isDebugRuntime(const QStringList &libraries)
 {
     foreach (const QString &lib, libraries) {
-        if (lib.toLower().startsWith(QLatin1String("msvcr"))
-            || lib.toLower().startsWith(QLatin1String("vcruntime")))
-            return lib.toLower().endsWith(QLatin1String("d.dll"));
+        if (lib.startsWith(QLatin1String("msvcr"), Qt::CaseInsensitive)
+            || lib.startsWith(QLatin1String("vcruntime"), Qt::CaseInsensitive))
+            return lib.endsWith(QLatin1String("d.dll"), Qt::CaseInsensitive);
     }
     return false;
 }
