@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -135,7 +135,7 @@ LaunchOptions LaunchPage::launchOptions() const
 
 void LaunchPage::showFileDialog()
 {
-    const QString exeFilePath
+    QString exeFilePath
         = QFileDialog::getOpenFileName(
         this,
         tr("Executable to Launch"),
@@ -147,7 +147,18 @@ void LaunchPage::showFileDialog()
 
     if (exeFilePath.isEmpty())
         return;
-
+#if QT_VERSION >= QT_VERSION_CHECK(4, 3, 0)
+    {
+        const QFileInfo fileInfo(exeFilePath);
+        if (fileInfo.isBundle()) {
+            const QString bundleTarget = QString::fromLatin1("%1/Contents/MacOS/%2")
+                    .arg(exeFilePath, fileInfo.completeBaseName())
+                    .replace(QLatin1String("/"), QDir::separator());
+            if (QFile::exists(bundleTarget))
+                exeFilePath = bundleTarget;
+        }
+    }
+#endif
     ui->progEdit->setText(exeFilePath);
 }
 
