@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,7 +49,7 @@ class LaunchPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit LaunchPage(QWidget *parent = 0);
+    explicit LaunchPage(QWidget *parent = nullptr);
     ~LaunchPage();
 
     LaunchOptions launchOptions() const;
