@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -44,7 +44,7 @@ class SelfTestPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SelfTestPage(QWidget *parent = 0);
+    explicit SelfTestPage(QWidget *parent = nullptr);
     ~SelfTestPage();
 
 public slots:
