@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -117,7 +117,7 @@ void GammaRay::ActionInspector::objectSelected(QObject *obj)
 
 void ActionInspector::registerMetaTypes()
 {
-    MetaObject *mo = 0;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT1(QAction, QObject);
     MO_ADD_PROPERTY_RO(QAction, QActionGroup *, actionGroup);
     MO_ADD_PROPERTY_CR(QAction, QVariant, data, setData);
