@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,7 @@
 #include "actionmodel.h"
 #include "actionvalidator.h"
 
+#include <core/enumutil.h>
 #include <core/probe.h>
 #include <core/util.h>
 #include <core/varianthandler.h>
@@ -142,7 +143,7 @@ QVariant ActionModel::data(const QModelIndex &index, int role) const
         case CheckablePropColumn:
             return action->isCheckable();
         case PriorityPropColumn:
-            return Util::enumToString(action->priority(), 0, action->metaObject());
+            return EnumUtil::enumToString(action->priority(), nullptr, action->metaObject());
         case ShortcutsPropColumn:
             return toString(action->shortcuts());
         default:
