@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -44,7 +44,7 @@ class ActionValidator : public QObject
     Q_OBJECT
 
 public:
-    explicit ActionValidator(QObject *parent = 0);
+    explicit ActionValidator(QObject *parent = nullptr);
 
     QList<QAction *> actions() const;
     QList<QAction *> actions(const QKeySequence &sequence) const;
