@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -51,7 +51,7 @@ class FontBrowserWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit FontBrowserWidget(QWidget *parent = 0);
+    explicit FontBrowserWidget(QWidget *parent = nullptr);
     ~FontBrowserWidget();
 
 private slots:
