@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,7 +36,7 @@ class GuiSupport : public QObject
 {
     Q_OBJECT
 public:
-    explicit GuiSupport(ProbeInterface *probe, QObject *parent = Q_NULLPTR);
+    explicit GuiSupport(ProbeInterface *probe, QObject *parent = nullptr);
 
 private:
     void registerMetaTypes();
@@ -61,7 +61,7 @@ class GuiSupportFactory : public QObject, public StandardToolFactory<QObject, Gu
     Q_INTERFACES(GammaRay::ToolFactory)
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_guisupport.json")
 public:
-    explicit GuiSupportFactory(QObject *parent = Q_NULLPTR);
+    explicit GuiSupportFactory(QObject *parent = nullptr);
 };
 }
 
