@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,7 +41,7 @@ class KJobTracker : public QObject
 {
     Q_OBJECT
 public:
-    explicit KJobTracker(ProbeInterface *probe, QObject *parent = 0);
+    explicit KJobTracker(ProbeInterface *probe, QObject *parent = nullptr);
     virtual ~KJobTracker();
 
 private:
@@ -55,7 +55,7 @@ class KJobTrackerFactory : public QObject, public StandardToolFactory<KJob, KJob
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_kjobtracker.json")
 
 public:
-    explicit KJobTrackerFactory(QObject *parent = 0)
+    explicit KJobTrackerFactory(QObject *parent = nullptr)
         : QObject(parent)
     {
     }
