@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,7 +45,7 @@ class GraphViewerWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit GraphViewerWidget(QWidget *parent = 0);
+    explicit GraphViewerWidget(QWidget *parent = nullptr);
     virtual ~GraphViewerWidget();
 
 private:
