@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
   Author: Volker Krause <volker.krause@kdab.com>
 
@@ -54,7 +54,7 @@ class VtkWidget : public QVTKWidget
     Q_OBJECT
 
 public:
-    explicit VtkWidget(QWidget *parent = 0);
+    explicit VtkWidget(QWidget *parent = nullptr);
     virtual ~VtkWidget();
 
     vtkGraphLayoutView *layoutView() const
