@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -69,16 +69,16 @@ PropertyData QJSValuePropertyAdaptor::propertyData(int index) const
     return pd;
 }
 
-QJSValuePropertyAdaptorFactory *QJSValuePropertyAdaptorFactory::s_instance = Q_NULLPTR;
+QJSValuePropertyAdaptorFactory *QJSValuePropertyAdaptorFactory::s_instance = nullptr;
 
 PropertyAdaptor *QJSValuePropertyAdaptorFactory::create(const ObjectInstance &oi,
                                                         QObject *parent) const
 {
     if (oi.type() != ObjectInstance::QtVariant)
-        return Q_NULLPTR;
+        return nullptr;
 
     if (!oi.variant().isValid() || !oi.variant().canConvert<QJSValue>())
-        return Q_NULLPTR;
+        return nullptr;
 
     return new QJSValuePropertyAdaptor(parent);
 }
