@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -92,18 +92,18 @@ PropertyData QmlAttachedPropertyAdaptor::propertyData(int index) const
     return pd;
 }
 
-QmlAttachedPropertyAdaptorFactory *QmlAttachedPropertyAdaptorFactory::s_instance = 0;
+QmlAttachedPropertyAdaptorFactory *QmlAttachedPropertyAdaptorFactory::s_instance = nullptr;
 
 PropertyAdaptor *QmlAttachedPropertyAdaptorFactory::create(const ObjectInstance &oi,
                                                            QObject *parent) const
 {
     if (oi.type() != ObjectInstance::QtObject || !oi.qtObject())
-        return Q_NULLPTR;
+        return nullptr;
 
     auto data = QQmlData::get(oi.qtObject());
     if (!data || !data->hasExtendedData() || !data->attachedProperties()
         || data->attachedProperties()->isEmpty())
-        return Q_NULLPTR;
+        return nullptr;
 
     return new QmlAttachedPropertyAdaptor(parent);
 }
