@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,14 +37,14 @@ class QmlAttachedPropertyAdaptor : public PropertyAdaptor
 {
     Q_OBJECT
 public:
-    explicit QmlAttachedPropertyAdaptor(QObject *parent = 0);
+    explicit QmlAttachedPropertyAdaptor(QObject *parent = nullptr);
     ~QmlAttachedPropertyAdaptor();
 
-    int count() const Q_DECL_OVERRIDE;
-    PropertyData propertyData(int index) const Q_DECL_OVERRIDE;
+    int count() const override;
+    PropertyData propertyData(int index) const override;
 
 protected:
-    void doSetObject(const ObjectInstance &oi) Q_DECL_OVERRIDE;
+    void doSetObject(const ObjectInstance &oi) override;
 
 private:
     QVector<int> m_attachedTypes;
@@ -54,7 +54,7 @@ private:
 class QmlAttachedPropertyAdaptorFactory : public AbstractPropertyAdaptorFactory
 {
 public:
-    PropertyAdaptor *create(const ObjectInstance &oi, QObject *parent = 0) const Q_DECL_OVERRIDE;
+    PropertyAdaptor *create(const ObjectInstance &oi, QObject *parent = nullptr) const override;
     static QmlAttachedPropertyAdaptorFactory *instance();
 private:
     static QmlAttachedPropertyAdaptorFactory *s_instance;
