@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -52,6 +52,7 @@
 #include <QQmlContext>
 #include <QQmlError>
 #include <QQmlListProperty>
+#include <QQmlEngine>
 
 #include <private/qjsvalue_p.h>
 #include <private/qqmlmetatype_p.h>
@@ -117,6 +118,8 @@ static QString qmlListPropertyToString(const QVariant &value, bool *ok)
     *ok = true;
     QQmlListProperty<QObject> *prop
         = reinterpret_cast<QQmlListProperty<QObject> *>(const_cast<void *>(value.data()));
+    if (!prop || !prop->count)
+        return QString();
     const int count = prop->count(prop);
     if (!count)
         return QmlSupport::tr("<empty>");
@@ -129,6 +132,13 @@ static QString qjsValueToString(const QJSValue &v)
         return QStringLiteral("<array>");
     else if (v.isBool())
         return v.toBool() ? QStringLiteral("true") : QStringLiteral("false");
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+    // note: v.isQMetaObject() == true => v.isCallable() == true, because QV4::QMetaObjectWrapper inherits
+    // QV4::FunctionObject and isCallable just checks whether the object is a function object.
+    // thus the isQMetaObject check needs to come before the isCallable check
+    else if (v.isQMetaObject())
+        return QStringLiteral("QMetaObject[className=%1]").arg(v.toQMetaObject()->className());
+#endif
     else if (v.isCallable())
         return callableQjsValueToString(v);
     else if (v.isDate())
@@ -166,10 +176,10 @@ namespace GammaRay {
 class QmlObjectDataProvider : public AbstractObjectDataProvider
 {
 public:
-    QString name(const QObject *obj) const Q_DECL_OVERRIDE;
-    QString typeName(QObject *obj) const Q_DECL_OVERRIDE;
-    SourceLocation creationLocation(QObject *obj) const Q_DECL_OVERRIDE;
-    SourceLocation declarationLocation(QObject *obj) const Q_DECL_OVERRIDE;
+    QString name(const QObject *obj) const override;
+    QString typeName(QObject *obj) const override;
+    SourceLocation creationLocation(QObject *obj) const override;
+    SourceLocation declarationLocation(QObject *obj) const override;
 };
 }
 
@@ -275,7 +285,7 @@ QmlSupport::QmlSupport(GammaRay::ProbeInterface *probe, QObject *parent)
 {
     Q_UNUSED(probe);
 
-    MetaObject *mo = 0;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT1(QQmlComponent, QObject);
     MO_ADD_PROPERTY_RO(QQmlComponent, QList<QQmlError>, errors);
     MO_ADD_PROPERTY_RO(QQmlComponent, bool, isError);
@@ -290,7 +300,10 @@ QmlSupport::QmlSupport(GammaRay::ProbeInterface *probe, QObject *parent)
     MO_ADD_PROPERTY_RO(QQmlContext, bool, isValid);
     MO_ADD_PROPERTY_RO(QQmlContext, QQmlContext *, parentContext);
 
-    MO_ADD_METAOBJECT1(QQmlEngine, QObject);
+    MO_ADD_METAOBJECT1(QJSEngine, QObject);
+    MO_ADD_PROPERTY_RO(QJSEngine, QJSValue, globalObject);
+
+    MO_ADD_METAOBJECT1(QQmlEngine, QJSEngine);
     MO_ADD_PROPERTY_CR(QQmlEngine, QUrl, baseUrl, setBaseUrl);
     MO_ADD_PROPERTY_CR(QQmlEngine, QStringList, importPathList, setImportPathList);
     MO_ADD_PROPERTY(QQmlEngine, bool, outputWarningsToStandardError,
