@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,24 +31,24 @@
 
 #include <core/toolfactory.h>
 
-#include <QQmlEngine>
+#include <QJSEngine>
 
 namespace GammaRay {
 class QmlSupport : public QObject
 {
     Q_OBJECT
 public:
-    explicit QmlSupport(ProbeInterface *probe, QObject *parent = 0);
+    explicit QmlSupport(ProbeInterface *probe, QObject *parent = nullptr);
 };
 
-class QmlSupportFactory : public QObject, public StandardToolFactory<QQmlEngine, QmlSupport>
+class QmlSupportFactory : public QObject, public StandardToolFactory<QJSEngine, QmlSupport>
 {
     Q_OBJECT
     Q_INTERFACES(GammaRay::ToolFactory)
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_qmlsupport.json")
 
 public:
-    explicit QmlSupportFactory(QObject *parent = 0)
+    explicit QmlSupportFactory(QObject *parent = nullptr)
         : QObject(parent)
     {
     }
