@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -95,6 +95,8 @@ void Qt3DGeometryExtension::updateGeometryData()
     QHash<Qt3DRender::QBuffer *, uint> bufferMap;
     data.attributes.reserve(m_geometry->geometry()->attributes().size());
     foreach (auto attr, m_geometry->geometry()->attributes()) {
+        if (attr->count() == 0) // ignore empty/invalid attributes
+            continue;
         Qt3DGeometryAttributeData attrData;
         attrData.name = attr->name();
         attrData.attributeType = attr->attributeType();
