@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,6 +49,7 @@
 #include <Qt3DRender/QGeometryRenderer>
 #include <Qt3DRender/QGraphicsApiFilter>
 #include <Qt3DRender/QMaterial>
+#include <Qt3DRender/QPointLight>
 #include <Qt3DRender/QParameter>
 #include <Qt3DRender/QRenderAspect>
 #include <Qt3DRender/QRenderPass>
@@ -182,6 +183,14 @@ bool Qt3DGeometryTab::eventFilter(QObject *receiver, QEvent *event)
     geometryEntity->addComponent(m_geometryTransform);
     updateGeometry();
 
+    auto lightEntity = new Qt3DCore::QEntity(rootEntity);
+    auto light = new Qt3DRender::QPointLight(lightEntity);
+    lightEntity->addComponent(light);
+    auto lightTransform = new Qt3DCore::QTransform(lightEntity);
+    lightTransform->setTranslation(m_camera->position());
+    connect(m_camera, &Qt3DRender::QCamera::positionChanged, lightTransform, &Qt3DCore::QTransform::setTranslation);
+    lightEntity->addComponent(lightTransform);
+
     auto skyboxEntity = new Qt3DCore::QEntity(rootEntity);
     auto skyBoxGeometry = new Qt3DExtras::QCuboidMesh;
     skyBoxGeometry->setXYMeshResolution(QSize(2, 2));
