@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,32 +30,28 @@
 #define GAMMARAY_QUICKINSPECTOR_SGGEOMETRYEXTENSION_H
 
 #include <core/propertycontrollerextension.h>
-#include "sggeometryextensioninterface.h"
 
 QT_BEGIN_NAMESPACE
 class QSGGeometryNode;
 QT_END_NAMESPACE
 
 namespace GammaRay {
-class SGGeometryModel;
-
 class PropertyController;
-class SGGeometryModel;
+class SGVertexModel;
+class SGAdjacencyModel;
 
-class SGGeometryExtension : public SGGeometryExtensionInterface, public PropertyControllerExtension
+class SGGeometryExtension : public PropertyControllerExtension
 {
-    Q_OBJECT
-    Q_INTERFACES(GammaRay::SGGeometryExtensionInterface)
-
 public:
     explicit SGGeometryExtension(PropertyController *controller);
     ~SGGeometryExtension();
 
-    bool setObject(void *object, const QString &typeName) Q_DECL_OVERRIDE;
+    bool setObject(void *object, const QString &typeName) override;
 
 private:
     QSGGeometryNode *m_node;
-    SGGeometryModel *m_model;
+    SGVertexModel *m_vertexModel;
+    SGAdjacencyModel *m_adjacencyModel;
 };
 }
 
