@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,7 +27,6 @@
 */
 
 #include "sggeometrytab.h"
-#include "sggeometryextensioninterface.h"
 #include "common/objectbroker.h"
 #include "ui/propertywidget.h"
 #include "ui_sggeometrytab.h"
@@ -39,8 +38,6 @@ using namespace GammaRay;
 SGGeometryTab::SGGeometryTab(PropertyWidget *parent)
     : QWidget(parent)
     , m_ui(new Ui_SGGeometryTab)
-    , m_interface(0)
-    , m_model(0)
 {
     m_ui->setupUi(this);
 
@@ -53,22 +50,16 @@ SGGeometryTab::~SGGeometryTab()
 
 void SGGeometryTab::setObjectBaseName(const QString &baseName)
 {
-    if (m_interface)
-        disconnect(m_interface, 0, m_ui->wireframeWidget, 0);
-    m_model = ObjectBroker::model(baseName + '.' + "sgGeometryModel");
+    m_vertexModel = ObjectBroker::model(baseName + '.' + "sgGeometryVertexModel");
+    m_adjacencyModel = ObjectBroker::model(baseName + '.' + "sgGeometryAdjacencyModel");
 
     QSortFilterProxyModel *proxy = new QSortFilterProxyModel(this);
     proxy->setDynamicSortFilter(true);
-    proxy->setSourceModel(m_model);
+    proxy->setSourceModel(m_vertexModel);
     m_ui->tableView->setModel(proxy);
     QItemSelectionModel *selectionModel = new QItemSelectionModel(proxy);
     m_ui->tableView->setSelectionModel(selectionModel);
 
-    m_interface
-        = ObjectBroker::object<SGGeometryExtensionInterface *>(baseName + ".sgGeometry");
-
-    m_ui->wireframeWidget->setModel(m_model);
+    m_ui->wireframeWidget->setModel(m_vertexModel, m_adjacencyModel);
     m_ui->wireframeWidget->setHighlightModel(selectionModel);
-    connect(m_interface, SIGNAL(geometryChanged(uint,QByteArray,int)),
-            m_ui->wireframeWidget, SLOT(onGeometryChanged(uint,QByteArray,int)));
 }
