@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,8 +37,6 @@ class QAbstractItemModel;
 QT_END_NAMESPACE
 
 namespace GammaRay {
-class SGGeometryExtensionInterface;
-
 class Ui_SGGeometryTab;
 class PropertyWidget;
 
@@ -55,8 +53,8 @@ private:
 
 private:
     Ui_SGGeometryTab *m_ui;
-    SGGeometryExtensionInterface *m_interface;
-    QAbstractItemModel *m_model;
+    QAbstractItemModel *m_vertexModel;
+    QAbstractItemModel *m_adjacencyModel;
 };
 }
 
