@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,7 +38,7 @@ using namespace GammaRay;
 MaterialTab::MaterialTab(PropertyWidget *parent)
     : QWidget(parent)
     , m_ui(new Ui_MaterialTab)
-    , m_interface(0)
+    , m_interface(nullptr)
 {
     m_ui->setupUi(this);
     m_ui->materialPropertyView->header()->setObjectName("materialPropertyViewHeader");
@@ -48,6 +48,8 @@ MaterialTab::MaterialTab(PropertyWidget *parent)
             SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             this, SLOT(shaderSelectionChanged(QItemSelection)));
 
+    m_ui->shaderEdit->setSyntaxDefinition(QLatin1String("GLSL"));
+
     m_ui->splitter->setStretchFactor(0, 1);
     m_ui->splitter->setStretchFactor(1, 3);
 }
@@ -59,7 +61,7 @@ MaterialTab::~MaterialTab()
 void MaterialTab::setObjectBaseName(const QString &baseName)
 {
     if (m_interface)
-        disconnect(m_interface, 0, this, 0);
+        disconnect(m_interface, nullptr, this, nullptr);
 
     m_interface
         = ObjectBroker::object<MaterialExtensionInterface *>(baseName + ".material");
@@ -82,5 +84,5 @@ void MaterialTab::shaderSelectionChanged(const QItemSelection &selection)
 
 void MaterialTab::showShader(const QString &shaderSource)
 {
-    m_ui->shaderEdit->setText(shaderSource);
+    m_ui->shaderEdit->setPlainText(shaderSource);
 }
