@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,6 +27,7 @@
 */
 
 #include "quickinspector.h"
+#include "quickoverlay.h"
 #include "quickitemmodel.h"
 #include "quickscenegraphmodel.h"
 #include "quickpaintanalyzerextension.h"
@@ -41,6 +42,7 @@
 #include <core/metaobject.h>
 #include <core/metaobjectrepository.h>
 #include <core/objecttypefilterproxymodel.h>
+#include <core/probeguard.h>
 #include <core/probeinterface.h>
 #include <core/propertycontroller.h>
 #include <core/remote/server.h>
@@ -235,7 +237,7 @@ static bool isGoodCandidateItem(QQuickItem *item)
 QuickInspector::QuickInspector(ProbeInterface *probe, QObject *parent)
     : QuickInspectorInterface(parent)
     , m_probe(probe)
-    , m_currentSgNode(0)
+    , m_currentSgNode(nullptr)
     , m_itemModel(new QuickItemModel(this))
     , m_sgModel(new QuickSceneGraphModel(this))
     , m_itemPropertyController(new PropertyController(QStringLiteral("com.kdab.GammaRay.QuickItem"),
@@ -243,13 +245,14 @@ QuickInspector::QuickInspector(ProbeInterface *probe, QObject *parent)
     , m_sgPropertyController(new PropertyController(QStringLiteral(
                                                         "com.kdab.GammaRay.QuickSceneGraph"), this))
     , m_remoteView(new RemoteViewServer(QStringLiteral("com.kdab.GammaRay.QuickRemoteView"), this))
-    , m_isGrabbingWindow(false)
 {
     registerPCExtensions();
     registerMetaTypes();
     registerVariantHandlers();
     probe->installGlobalEventFilter(this);
 
+    recreateOverlay();
+
     QAbstractProxyModel *windowModel = new ObjectTypeFilterProxyModel<QQuickWindow>(this);
     windowModel->setSourceModel(probe->objectListModel());
     QAbstractProxyModel *proxy = new SingleColumnObjectProxyModel(this);
@@ -262,6 +265,11 @@ QuickInspector::QuickInspector(ProbeInterface *probe, QObject *parent)
     filterProxy->addRole(ObjectModel::ObjectIdRole);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.QuickItemModel"), filterProxy);
 
+    if (m_probe->needsObjectDiscovery()) {
+        connect(m_probe->probe(), SIGNAL(objectCreated(QObject*)),
+                SLOT(objectCreated(QObject*)));
+    }
+
     connect(probe->probe(), SIGNAL(objectCreated(QObject*)),
             m_itemModel, SLOT(objectAdded(QObject*)));
     connect(probe->probe(), SIGNAL(objectDestroyed(QObject*)),
@@ -292,6 +300,9 @@ QuickInspector::QuickInspector(ProbeInterface *probe, QObject *parent)
 
 QuickInspector::~QuickInspector()
 {
+    disconnect(m_overlay, SIGNAL(destroyed(QObject*)),
+               this, SLOT(recreateOverlay()));
+    delete m_overlay.data();
 }
 
 void QuickInspector::selectWindow(int index)
@@ -307,10 +318,6 @@ void QuickInspector::selectWindow(QQuickWindow *window)
         return;
     }
 
-    if (m_window) {
-        disconnect(m_window, 0, this, 0);
-    }
-
     m_window = window;
     m_itemModel->setWindow(window);
     m_sgModel->setWindow(window);
@@ -320,11 +327,6 @@ void QuickInspector::selectWindow(QQuickWindow *window)
     if (m_window) {
         // make sure we have selected something for the property editor to not be entirely empty
         selectItem(m_window->contentItem());
-
-        // frame swapped isn't enough, we don't get that for FBO render targets such as in QQuickWidget
-        connect(window, &QQuickWindow::afterRendering, this, &QuickInspector::slotSceneChanged);
-        connect(window, &QQuickWindow::frameSwapped, this, &QuickInspector::slotSceneChanged);
-
         m_window->update();
     }
 }
@@ -387,129 +389,136 @@ void QuickInspector::objectSelected(void *object, const QString &typeName)
         selectSGNode(reinterpret_cast<QSGNode *>(object));
 }
 
+void QuickInspector::objectCreated(QObject *object)
+{
+    if (QQuickWindow *window = qobject_cast<QQuickWindow *>(object)) {
+        if (QQuickView *view = qobject_cast<QQuickView *>(object)) {
+            m_probe->discoverObject(view->engine());
+        }
+        else {
+            QQmlContext *context = QQmlEngine::contextForObject(window);
+            QQmlEngine *engine = context ? context->engine() : nullptr;
+
+            if (!engine) {
+                engine = qmlEngine(window->contentItem()->childItems().value(0));
+            }
+
+            m_probe->discoverObject(engine);
+        }
+    }
+}
+
+void QuickInspector::recreateOverlay()
+{
+    ProbeGuard guard;
+    m_overlay = new QuickOverlay;
+
+    connect(m_overlay.data(), &QuickOverlay::sceneChanged, m_remoteView, &RemoteViewServer::sourceChanged);
+    connect(m_overlay.data(), &QuickOverlay::sceneGrabbed, this, &QuickInspector::sendRenderedScene);
+    // the target application might have destroyed the overlay widget
+    // (e.g. because the parent of the overlay got destroyed).
+    // just recreate a new one in this case
+    connect(m_overlay.data(), &QObject::destroyed, this, &QuickInspector::recreateOverlay);
+}
+
 void QuickInspector::sendRenderedScene(const QImage &currentFrame)
 {
-    m_isGrabbingWindow = false;
-
     RemoteViewFrame frame;
     frame.setImage(currentFrame);
     QuickItemGeometry itemGeometry;
-    if (m_currentItem) {
-        QQuickItem *parent = m_currentItem->parentItem();
-
-        if (parent) {
-            itemGeometry.itemRect = m_currentItem->parentItem()->mapRectToScene(
-                QRectF(m_currentItem->x(), m_currentItem->y(),
-                       m_currentItem->width(), m_currentItem->height()));
-        } else {
-            itemGeometry.itemRect = QRectF(0, 0, m_currentItem->width(), m_currentItem->height());
-        }
-
-        itemGeometry.boundingRect
-            = m_currentItem->mapRectToScene(m_currentItem->boundingRect());
-        itemGeometry.childrenRect
-            = m_currentItem->mapRectToScene(m_currentItem->childrenRect());
-        itemGeometry.transformOriginPoint
-            = m_currentItem->mapToScene(m_currentItem->transformOriginPoint());
-
-        QQuickAnchors *anchors = m_currentItem->property("anchors").value<QQuickAnchors *>();
-
-        if (anchors) {
-            QQuickAnchors::Anchors usedAnchors = anchors->usedAnchors();
-            itemGeometry.left = (bool)(usedAnchors &QQuickAnchors::LeftAnchor) || anchors->fill();
-            itemGeometry.right = (bool)(usedAnchors &QQuickAnchors::RightAnchor) || anchors->fill();
-            itemGeometry.top = (bool)(usedAnchors &QQuickAnchors::TopAnchor) || anchors->fill();
-            itemGeometry.bottom = (bool)(usedAnchors &QQuickAnchors::BottomAnchor)
-                                  || anchors->fill();
-            itemGeometry.baseline = (bool)(usedAnchors & QQuickAnchors::BaselineAnchor);
-            itemGeometry.horizontalCenter = (bool)(usedAnchors &QQuickAnchors::HCenterAnchor)
-                                            || anchors->centerIn();
-            itemGeometry.verticalCenter = (bool)(usedAnchors &QQuickAnchors::VCenterAnchor)
-                                          || anchors->centerIn();
-            itemGeometry.leftMargin = anchors->leftMargin();
-            itemGeometry.rightMargin = anchors->rightMargin();
-            itemGeometry.topMargin = anchors->topMargin();
-            itemGeometry.bottomMargin = anchors->bottomMargin();
-            itemGeometry.horizontalCenterOffset = anchors->horizontalCenterOffset();
-            itemGeometry.verticalCenterOffset = anchors->verticalCenterOffset();
-            itemGeometry.baselineOffset = anchors->baselineOffset();
-            itemGeometry.margins = anchors->margins();
-        }
-        itemGeometry.x = m_currentItem->x();
-        itemGeometry.y = m_currentItem->y();
-        QQuickItemPrivate *itemPriv = QQuickItemPrivate::get(m_currentItem);
-        itemGeometry.transform = itemPriv->itemToWindowTransform();
-        if (parent) {
-            QQuickItemPrivate *parentPriv = QQuickItemPrivate::get(parent);
-            itemGeometry.parentTransform = parentPriv->itemToWindowTransform();
-        }
-    }
-    frame.setSceneRect(QRectF(
-                           currentFrame.rect()) | itemGeometry.itemRect | itemGeometry.childrenRect
-                       | itemGeometry.boundingRect);
+    if (m_currentItem)
+        itemGeometry.initFrom(m_currentItem);
+    frame.setSceneRect(QRectF(currentFrame.rect()) | itemGeometry.itemRect |
+                       itemGeometry.childrenRect | itemGeometry.boundingRect);
     frame.setData(QVariant::fromValue(itemGeometry));
     m_remoteView->sendFrame(frame);
 }
 
-void QuickInspector::slotSceneChanged()
-{
-    if (!m_isGrabbingWindow)
-        m_remoteView->sourceChanged();
-}
-
 void QuickInspector::slotGrabWindow()
 {
-    if (!m_remoteView->isActive() || !m_window || m_isGrabbingWindow)
+    if (!m_remoteView->isActive() || !m_window)
         return;
 
     Q_ASSERT(QThread::currentThread() == QCoreApplication::instance()->thread());
-    m_isGrabbingWindow = true;
-    foreach (const auto callback, m_grabWindowCallbacks) {
-        if (callback(m_window))
-            return;
-    }
+    m_overlay->requestGrabWindow();
+}
 
-    // delay this so we can process the signals to slotSceneChanged first, while we are in the m_isGrabbingWindow state
-    // otherwise we end up with an infinite update loop even on static scenes
-    auto img = m_window->grabWindow();
-    // See QTBUG-53795
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
-    img.setDevicePixelRatio(m_window->effectiveDevicePixelRatio());
-#elif QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-    img.setDevicePixelRatio(m_window->devicePixelRatio());
-#endif
-    QMetaObject::invokeMethod(this, "sendRenderedScene", Qt::QueuedConnection, Q_ARG(QImage, img));
+static QByteArray renderModeToString(GammaRay::QuickInspectorInterface::RenderMode customRenderMode)
+{
+    switch (customRenderMode) {
+        case QuickInspectorInterface::VisualizeClipping:
+            return "clip";
+        case QuickInspectorInterface::VisualizeOverdraw:
+            return "overdraw";
+        case QuickInspectorInterface::VisualizeBatches:
+            return "batches";
+        case QuickInspectorInterface::VisualizeChanges:
+            return "changes";
+        case QuickInspectorInterface::NormalRendering:
+            break;
+    }
+    return "";
 }
 
 void QuickInspector::setCustomRenderMode(
     GammaRay::QuickInspectorInterface::RenderMode customRenderMode)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 3, 0)
-    QQuickWindowPrivate *winPriv = QQuickWindowPrivate::get(m_window);
-    winPriv->customRenderMode = customRenderMode == VisualizeClipping ? "clip"
-                                : customRenderMode == VisualizeOverdraw ? "overdraw"
-                                : customRenderMode == VisualizeBatches ? "batches"
-                                : customRenderMode == VisualizeChanges ? "changes"
-                                : "";
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0) && 0 // FIXME this crashes on scene updates with Qt >= 5.5.1 and the multithreaded renderer
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     // Qt does some performance optimizations that break custom render modes.
     // Thus the optimizations are only applied if there is no custom render mode set.
     // So we need to make the scenegraph recheck whether a custom render mode is set.
     // We do this by simply recreating the renderer.
+    // We need however to recreate the renderer in the render thread.
+    QMutexLocker lock(&m_pendingRenderMode.mutex);
+    m_pendingRenderMode.mode = customRenderMode;
+    m_pendingRenderMode.window = m_window;
+    if (m_window && !m_pendingRenderMode.connection) {
+        m_pendingRenderMode.connection = connect(m_window.data(), &QQuickWindow::beforeSynchronizing, this, &QuickInspector::applyRenderMode, Qt::DirectConnection);
+    }
+
+#else
+    if (m_window) {
+        QQuickWindowPrivate *winPriv = QQuickWindowPrivate::get(m_window);
+        winPriv->customRenderMode = renderModeToString(customRenderMode);
+    }
+#endif
+    if (m_window) {
+        m_window->update();
+    }
+
+#else
+    Q_UNUSED(customRenderMode);
+#endif
+}
+
+void QuickInspector::setServerSideDecorationsEnabled(bool enabled)
+{
+    m_overlay->setDrawDecorations(enabled);
+}
+
+void QuickInspector::applyRenderMode()
+{
+    QMutexLocker lock(&m_pendingRenderMode.mutex);
+    disconnect(m_pendingRenderMode.connection);
+
+    if (m_pendingRenderMode.window != m_window) { //we selected another window in the meanwhile, abort
+        return;
+    }
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
+    QQuickWindowPrivate *winPriv = QQuickWindowPrivate::get(m_window);
 
     QQuickItemPrivate *contentPriv = QQuickItemPrivate::get(m_window->contentItem());
     QSGNode *rootNode = contentPriv->itemNode();
     while (rootNode->parent())
         rootNode = rootNode->parent();
 
+    winPriv->customRenderMode = renderModeToString(m_pendingRenderMode.mode);
     delete winPriv->renderer;
     winPriv->renderer = winPriv->context->createRenderer();
     winPriv->renderer->setRootNode(static_cast<QSGRootNode *>(rootNode));
-#endif
-    m_window->update();
-
-#else
-    Q_UNUSED(customRenderMode);
 #endif
 }
 
@@ -517,21 +526,25 @@ void QuickInspector::checkFeatures()
 {
     emit features(
         Features(
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0) // FIXME any render mode crashes on first scene change
-            NoFeatures
-#elif QT_VERSION >= QT_VERSION_CHECK(5, 5, 0) // batching crashes when enabled at runtime >= 5.5.0
-            CustomRenderModeChanges | CustomRenderModeClipping | CustomRenderModeOverdraw
-#elif QT_VERSION >= QT_VERSION_CHECK(5, 3, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 3, 0)
             AllCustomRenderModes
 #endif
             )
         );
 }
 
+void QuickInspector::checkServerSideDecorations()
+{
+    emit serverSideDecorations(m_overlay->drawDecorations());
+}
+
 void QuickInspector::itemSelectionChanged(const QItemSelection &selection)
 {
-    if (selection.isEmpty())
+    if (selection.isEmpty()) {
+        m_overlay->placeOn(ItemOrLayoutFacade());
+        m_remoteView->clearFrameData();
         return;
+    }
 
     const QModelIndex index = selection.first().topLeft();
     m_currentItem = index.data(ObjectModel::ObjectRole).value<QQuickItem *>();
@@ -550,8 +563,7 @@ void QuickInspector::itemSelectionChanged(const QItemSelection &selection)
                                    |QItemSelectionModel::Current);
     }
 
-    if (m_window)
-        m_window->update();
+    m_overlay->placeOn(m_currentItem.data());
 }
 
 void QuickInspector::sgSelectionChanged(const QItemSelection &selection)
@@ -573,7 +585,7 @@ void QuickInspector::sgSelectionChanged(const QItemSelection &selection)
 void QuickInspector::sgNodeDeleted(QSGNode *node)
 {
     if (m_currentSgNode == node)
-        m_sgPropertyController->setObject(0);
+        m_sgPropertyController->setObject(nullptr);
 }
 
 void QuickInspector::requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode)
@@ -604,7 +616,11 @@ ObjectIds QuickInspector::recursiveItemsAt(QQuickItem *parent, const QPointF &po
 
     bestCandidate = -1;
 
-    const auto childItems = parent->childItems();
+    auto childItems = parent->childItems();
+    std::stable_sort(childItems.begin(), childItems.end(),
+                     [](QQuickItem *lhs, QQuickItem *rhs){return lhs->z() < rhs->z();}
+    );
+
     for (int i = childItems.size() - 1; i >= 0; --i) { // backwards to match z order
         auto c = childItems.at(i);
         const QPointF p = parent->mapToItem(c, pos);
@@ -648,11 +664,6 @@ ObjectIds QuickInspector::recursiveItemsAt(QQuickItem *parent, const QPointF &po
     return objects;
 }
 
-void GammaRay::QuickInspector::registerGrabWindowCallback(GrabWindowCallback callback)
-{
-    m_grabWindowCallbacks.push_back(callback);
-}
-
 bool QuickInspector::eventFilter(QObject *receiver, QEvent *event)
 {
     if (event->type() == QEvent::MouseButtonRelease) {
@@ -674,7 +685,7 @@ bool QuickInspector::eventFilter(QObject *receiver, QEvent *event)
 
 void QuickInspector::registerMetaTypes()
 {
-    MetaObject *mo = 0;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT1(QQuickWindow, QWindow);
     MO_ADD_PROPERTY(QQuickWindow, bool, clearBeforeRendering, setClearBeforeRendering);
 #if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
