@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,6 +36,7 @@
 
 #include <QQuickWindow>
 #include <QImage>
+#include <QMutex>
 
 QT_BEGIN_NAMESPACE
 class QQuickShaderEffectSource;
@@ -53,6 +54,7 @@ QT_END_NAMESPACE
 
 namespace GammaRay {
 class PropertyController;
+class QuickOverlay;
 class QuickItemModel;
 class QuickSceneGraphModel;
 class RemoteViewServer;
@@ -65,43 +67,41 @@ class QuickInspector : public QuickInspectorInterface
     Q_INTERFACES(GammaRay::QuickInspectorInterface)
 
 public:
-    explicit QuickInspector(ProbeInterface *probe, QObject *parent = 0);
+    explicit QuickInspector(ProbeInterface *probe, QObject *parent = nullptr);
     ~QuickInspector();
 
-    typedef bool (*GrabWindowCallback)(QQuickWindow *);
-
 signals:
     void elementsAtReceived(const GammaRay::ObjectIds &ids, int bestCandidate);
 
 public slots:
-    void selectWindow(int index) Q_DECL_OVERRIDE;
+    void selectWindow(int index) override;
 
     void setCustomRenderMode(GammaRay::QuickInspectorInterface::RenderMode customRenderMode)
-    Q_DECL_OVERRIDE;
+    override;
 
-    void checkFeatures() Q_DECL_OVERRIDE;
+    void checkFeatures() override;
+
+    void setServerSideDecorationsEnabled(bool enabled) override;
+
+    void checkServerSideDecorations() override;
 
     void requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode);
     void pickElementId(const GammaRay::ObjectId& id);
 
-    /** Allow other plugins to provide specific window grabbing callbacks.
-     *  Needed for QQuickWidget.
-     */
-    void registerGrabWindowCallback(GrabWindowCallback callback);
-
     void sendRenderedScene(const QImage &currentFrame);
 
 protected:
-    bool eventFilter(QObject *receiver, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *receiver, QEvent *event) override;
 
 private slots:
-    void slotSceneChanged();
     void slotGrabWindow();
     void itemSelectionChanged(const QItemSelection &selection);
     void sgSelectionChanged(const QItemSelection &selection);
     void sgNodeDeleted(QSGNode *node);
     void objectSelected(QObject *object);
     void objectSelected(void *object, const QString &typeName);
+    void objectCreated(QObject *object);
+    void recreateOverlay();
 
 private:
     void selectWindow(QQuickWindow *window);
@@ -111,11 +111,13 @@ private:
     void registerVariantHandlers();
     void registerPCExtensions();
     QString findSGNodeType(QSGNode *node) const;
+    void applyRenderMode();
 
     GammaRay::ObjectIds recursiveItemsAt(QQuickItem *parent, const QPointF &pos,
                                          GammaRay::RemoteViewInterface::RequestMode mode, int& bestCandidate) const;
 
     ProbeInterface *m_probe;
+    QPointer<QuickOverlay> m_overlay;
     QPointer<QQuickWindow> m_window;
     QPointer<QQuickItem> m_currentItem;
     QSGNode *m_currentSgNode;
@@ -127,9 +129,12 @@ private:
     PropertyController *m_itemPropertyController;
     PropertyController *m_sgPropertyController;
     RemoteViewServer *m_remoteView;
-    QImage m_currentFrame;
-    QVector<GrabWindowCallback> m_grabWindowCallbacks;
-    bool m_isGrabbingWindow;
+    struct {
+        RenderMode mode;
+        QMetaObject::Connection connection;
+        QQuickWindow *window;
+        QMutex mutex;
+    } m_pendingRenderMode;
 };
 
 class QuickInspectorFactory : public QObject,
@@ -140,7 +145,7 @@ class QuickInspectorFactory : public QObject,
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_quickinspector.json")
 
 public:
-    explicit QuickInspectorFactory(QObject *parent = 0)
+    explicit QuickInspectorFactory(QObject *parent = nullptr)
         : QObject(parent)
     {
     }
