@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -60,3 +60,16 @@ void QuickInspectorClient::checkFeatures()
 {
     Endpoint::instance()->invokeObject(objectName(), "checkFeatures");
 }
+
+void GammaRay::QuickInspectorClient::setServerSideDecorationsEnabled(bool enabled)
+{
+    Endpoint::instance()->invokeObject(objectName(),
+                                       "setServerSideDecorationsEnabled",
+                                       QVariantList()
+                                       << enabled);
+}
+
+void QuickInspectorClient::checkServerSideDecorations()
+{
+    Endpoint::instance()->invokeObject(objectName(), "checkServerSideDecorations");
+}
