@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -42,16 +42,20 @@ class QuickInspectorClient : public QuickInspectorInterface
     Q_INTERFACES(GammaRay::QuickInspectorInterface)
 
 public:
-    explicit QuickInspectorClient(QObject *parent = 0);
+    explicit QuickInspectorClient(QObject *parent = nullptr);
     ~QuickInspectorClient();
 
 public slots:
-    void selectWindow(int index) Q_DECL_OVERRIDE;
+    void selectWindow(int index) override;
 
     void setCustomRenderMode(GammaRay::QuickInspectorInterface::RenderMode customRenderMode)
-    Q_DECL_OVERRIDE;
+    override;
 
-    void checkFeatures() Q_DECL_OVERRIDE;
+    void checkFeatures() override;
+
+    void setServerSideDecorationsEnabled(bool enabled) override;
+
+    void checkServerSideDecorations() override;
 };
 }
 
