@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,7 +32,6 @@
 #include "quickitemtreewatcher.h"
 #include "quickitemmodelroles.h"
 #include "quickscenepreviewwidget.h"
-#include "geometryextension/sggeometryextensionclient.h"
 #include "geometryextension/sggeometrytab.h"
 #include "materialextension/materialextensionclient.h"
 #include "materialextension/materialtab.h"
@@ -43,13 +42,12 @@
 #include <common/objectbroker.h>
 #include <common/objectmodel.h>
 #include <common/objectid.h>
+#include <common/remotemodelroles.h>
 #include <common/sourcelocation.h>
 
 #include <ui/contextmenuextension.h>
 #include <ui/searchlinecontroller.h>
 
-#include <client/remotemodel.h>
-
 #include <QEvent>
 #include <QLabel>
 #include <QMenu>
@@ -57,6 +55,7 @@
 #include <QRectF>
 #include <QtCore/qglobal.h>
 #include <QPropertyAnimation>
+#include <QSettings>
 #include <QDebug>
 
 using namespace GammaRay;
@@ -71,11 +70,6 @@ static QObject *createMaterialExtension(const QString &name, QObject *parent)
     return new MaterialExtensionClient(name, parent);
 }
 
-static QObject *createSGGeometryExtension(const QString &name, QObject *parent)
-{
-    return new SGGeometryExtensionClient(name, parent);
-}
-
 QuickInspectorWidget::QuickInspectorWidget(QWidget *parent)
     : QWidget(parent)
     , ui(new Ui::QuickInspectorWidget)
@@ -124,6 +118,8 @@ QuickInspectorWidget::QuickInspectorWidget(QWidget *parent)
 
     m_previewWidget = new QuickScenePreviewWidget(m_interface, this);
     m_previewWidget->setPickSourceModel(proxy);
+    m_previewWidget->setFlagRole(QuickItemModelRole::ItemFlags);
+    m_previewWidget->setInvisibleMask(QuickItemModelRole::Invisible | QuickItemModelRole::ZeroSize);
 
     ui->itemPropertyWidget->setObjectBaseName(QStringLiteral("com.kdab.GammaRay.QuickItem"));
     ui->sgPropertyWidget->setObjectBaseName(QStringLiteral("com.kdab.GammaRay.QuickSceneGraph"));
@@ -133,27 +129,48 @@ QuickInspectorWidget::QuickInspectorWidget(QWidget *parent)
     connect(m_interface, SIGNAL(features(GammaRay::QuickInspectorInterface::Features)),
             this, SLOT(setFeatures(GammaRay::QuickInspectorInterface::Features)));
 
+    connect(m_interface, SIGNAL(serverSideDecorations(bool)), this, SLOT(setServerSideDecorations(bool)));
+
     connect(ui->itemTreeView, SIGNAL(customContextMenuRequested(QPoint)),
             this, SLOT(itemContextMenu(QPoint)));
 
     m_interface->checkFeatures();
+    m_interface->checkServerSideDecorations();
 
     m_stateManager.setDefaultSizes(ui->mainSplitter, UISizeVector() << "50%" << "50%");
     m_stateManager.setDefaultSizes(ui->previewTreeSplitter, UISizeVector() << "50%" << "50%");
 
-    connect(ui->itemPropertyWidget, SIGNAL(tabsUpdated()), &m_stateManager, SLOT(reset()));
-    connect(ui->sgPropertyWidget, SIGNAL(tabsUpdated()), &m_stateManager, SLOT(reset()));
+    connect(ui->itemPropertyWidget, SIGNAL(tabsUpdated()), this, SLOT(resetState()));
+    connect(ui->sgPropertyWidget, SIGNAL(tabsUpdated()), this, SLOT(resetState()));
+    connect(m_previewWidget, SIGNAL(stateChanged()), this, SLOT(saveState()));
 }
 
 QuickInspectorWidget::~QuickInspectorWidget()
 {
 }
 
+void QuickInspectorWidget::saveTargetState(QSettings *settings) const
+{
+    settings->setValue("tabIndex", ui->tabWidget->currentIndex());
+    settings->setValue("remoteViewState", m_previewWidget->saveState());
+}
+
+void QuickInspectorWidget::restoreTargetState(QSettings *settings)
+{
+    ui->tabWidget->setCurrentIndex(settings->value("tabIndex", 0).toInt());
+    m_previewWidget->restoreState(settings->value("remoteViewState").toByteArray());
+}
+
 void QuickInspectorWidget::setFeatures(QuickInspectorInterface::Features features)
 {
     m_previewWidget->setSupportsCustomRenderModes(features);
 }
 
+void QuickInspectorWidget::setServerSideDecorations(bool enabled)
+{
+    m_previewWidget->setServerSideDecorationsState(enabled);
+}
+
 void QuickInspectorWidget::itemSelectionChanged(const QItemSelection &selection)
 {
     if (selection.isEmpty())
@@ -171,9 +188,8 @@ void QuickInspectorWidget::itemModelDataChanged(const QModelIndex &topLeft,
 
     for (int i = topLeft.row(); i <= bottomRight.row(); i++) {
         const QModelIndex index = ui->itemTreeView->model()->index(i, 0, topLeft.parent());
-        RemoteModel::NodeStates state
-            = index.data(RemoteModel::LoadingState).value<RemoteModel::NodeStates>();
-        if (state & RemoteModel::Empty || ~state & RemoteModel::Outdated)
+        const auto state = index.data(RemoteModelRole::LoadingState).value<RemoteModelNodeState::NodeStates>();
+        if (state & RemoteModelNodeState::Empty || ~state & RemoteModelNodeState::Outdated)
             continue;
 
         QVariantAnimation *colorAnimation = new QVariantAnimation(this);
@@ -197,9 +213,6 @@ void QuickInspectorUiFactory::initUi()
 
     PropertyWidget::registerTab<MaterialTab>(QStringLiteral("material"), tr("Material"));
 
-    ObjectBroker::registerClientObjectFactoryCallback<SGGeometryExtensionInterface *>(
-        createSGGeometryExtension);
-
     PropertyWidget::registerTab<SGGeometryTab>(QStringLiteral("sgGeometry"), tr("Geometry"));
 }
 
@@ -220,3 +233,13 @@ void GammaRay::QuickInspectorWidget::itemContextMenu(const QPoint &pos)
     ext.populateMenu(&contextMenu);
     contextMenu.exec(ui->itemTreeView->viewport()->mapToGlobal(pos));
 }
+
+void QuickInspectorWidget::resetState()
+{
+    m_stateManager.reset();
+}
+
+void QuickInspectorWidget::saveState()
+{
+    m_stateManager.saveState();
+}
