@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -34,6 +34,10 @@
 #include <QPointF>
 #include <QTransform>
 
+QT_BEGIN_NAMESPACE
+class QQuickItem;
+QT_END_NAMESPACE
+
 namespace GammaRay {
 struct QuickItemGeometry {
     // basic geometry
@@ -68,6 +72,9 @@ struct QuickItemGeometry {
     qreal verticalCenterOffset;
     qreal bottomMargin;
     qreal baselineOffset;
+
+    void initFrom(QQuickItem *item);
+    void scaleTo(qreal factor);
 };
 
 QDataStream &operator<<(QDataStream &stream, const GammaRay::QuickItemGeometry &geometry);
