@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,6 +47,7 @@ using namespace GammaRay;
 QuickItemModel::QuickItemModel(QObject *parent)
     : ObjectModelBase<QAbstractItemModel>(parent)
 {
+    m_clickEventFilter = new QuickEventMonitor(this);
 }
 
 QuickItemModel::~QuickItemModel()
@@ -114,7 +115,7 @@ void QuickItemModel::clear()
 {
     for (QHash<QQuickItem *, QQuickItem *>::const_iterator it = m_childParentMap.constBegin();
          it != m_childParentMap.constEnd(); ++it)
-        disconnect(it.key(), 0, this, 0);
+        disconnect(it.key(), nullptr, this, nullptr);
     m_childParentMap.clear();
     m_parentChildMap.clear();
 }
@@ -143,7 +144,6 @@ void QuickItemModel::populateFromItem(QQuickItem *item)
 void QuickItemModel::connectItem(QQuickItem *item)
 {
     connect(item, SIGNAL(parentChanged(QQuickItem*)), this, SLOT(itemReparented()));
-    connect(item, SIGNAL(windowChanged(QQuickWindow*)), this, SLOT(itemWindowChanged()));
     connect(item, SIGNAL(visibleChanged()), this, SLOT(itemUpdated()));
     connect(item, SIGNAL(focusChanged(bool)), this, SLOT(itemUpdated()));
     connect(item, SIGNAL(activeFocusChanged(bool)), this, SLOT(itemUpdated()));
@@ -151,12 +151,19 @@ void QuickItemModel::connectItem(QQuickItem *item)
     connect(item, SIGNAL(heightChanged()), this, SLOT(itemUpdated()));
     connect(item, SIGNAL(xChanged()), this, SLOT(itemUpdated()));
     connect(item, SIGNAL(yChanged()), this, SLOT(itemUpdated()));
-    item->installEventFilter(new QuickEventMonitor(this));
+    item->installEventFilter(m_clickEventFilter);
 }
 
 void QuickItemModel::disconnectItem(QQuickItem *item)
 {
-    disconnect(item, 0, this, 0);
+    disconnect(item, SIGNAL(parentChanged(QQuickItem*)), this, SLOT(itemReparented()));
+    disconnect(item, SIGNAL(visibleChanged()), this, SLOT(itemUpdated()));
+    disconnect(item, SIGNAL(focusChanged(bool)), this, SLOT(itemUpdated()));
+    disconnect(item, SIGNAL(activeFocusChanged(bool)), this, SLOT(itemUpdated()));
+    disconnect(item, SIGNAL(widthChanged()), this, SLOT(itemUpdated()));
+    disconnect(item, SIGNAL(heightChanged()), this, SLOT(itemUpdated()));
+    disconnect(item, SIGNAL(xChanged()), this, SLOT(itemUpdated()));
+    disconnect(item, SIGNAL(yChanged()), this, SLOT(itemUpdated()));
 }
 
 QModelIndex QuickItemModel::indexForItem(QQuickItem *item) const
@@ -183,13 +190,16 @@ void QuickItemModel::objectAdded(QObject *obj)
 {
     Q_ASSERT(thread() == QThread::currentThread());
     QQuickItem *item = qobject_cast<QQuickItem *>(obj);
+    if (!item)
+        return;
+
+    connect(item, SIGNAL(windowChanged(QQuickWindow*)), this, SLOT(itemWindowChanged())); // detect if item is added to scene later
     addItem(item);
 }
 
 void QuickItemModel::addItem(QQuickItem *item)
 {
-    if (!item)
-        return;
+    Q_ASSERT(item);
 
     if (!item->window())
         return; // item not (yet) added to a scene
@@ -210,7 +220,8 @@ void QuickItemModel::addItem(QQuickItem *item)
     connectItem(item);
 
     const QModelIndex index = indexForItem(parentItem);
-    Q_ASSERT(index.isValid() || !parentItem);
+    if (!index.isValid() && parentItem)
+        return;
 
     QVector<QQuickItem *> &children = m_parentChildMap[parentItem];
     QVector<QQuickItem *>::iterator it = std::lower_bound(children.begin(), children.end(), item);
@@ -281,6 +292,9 @@ void QuickItemModel::itemReparented()
 
     QQuickItem *sourceParent = m_childParentMap.value(item);
     Q_ASSERT(sourceParent);
+    if (sourceParent == item->parentItem())
+        return;
+
     const QModelIndex sourceParentIndex = indexForItem(sourceParent);
 
     QVector<QQuickItem *> &sourceSiblings = m_parentChildMap[sourceParent];
@@ -308,8 +322,11 @@ void QuickItemModel::itemReparented()
 void QuickItemModel::itemWindowChanged()
 {
     QQuickItem *item = qobject_cast<QQuickItem *>(sender());
-    Q_ASSERT(item && (!item->window() || item->window() != m_window));
-    removeItem(item);
+    Q_ASSERT(item);
+    if (!item->window() || item->window() != m_window)
+        removeItem(item);
+    else if (m_window && item->window() == m_window)
+        addItem(item);
 }
 
 void QuickItemModel::itemUpdated()
@@ -353,21 +370,30 @@ void QuickItemModel::updateItemFlags(QQuickItem *item)
 {
     QQuickItem *ancestor = item->parentItem();
     bool outOfView = false;
+    bool partiallyOutOfView = false;
+
+    auto rect = item->mapRectToScene(QRectF(0, 0, item->width(), item->height()));
+
     while (ancestor && ancestor != m_window->contentItem()) {
-        QPointF pos = ancestor->mapFromItem(item, QPointF(0, 0));
-        if ((ancestor->parentItem() == m_window->contentItem()
-             || ancestor->clip())
-            && (-pos.x() > item->width() || -pos.y() > item->height()
-                || pos.x() > ancestor->width() || pos.y() > ancestor->height())) {
-            outOfView = true;
-            break;
+        if (ancestor->parentItem() == m_window->contentItem() || ancestor->clip()) {
+            auto ancestorRect = ancestor->mapRectToScene(QRectF(0, 0, ancestor->width(), ancestor->height()));
+
+            partiallyOutOfView |= !ancestorRect.contains(rect);
+            outOfView = partiallyOutOfView && !rect.intersects(ancestorRect);
+
+            if (outOfView) {
+                break;
+            }
         }
         ancestor = ancestor->parentItem();
     }
+
     m_itemFlags[item] = (!item->isVisible() || item->opacity() == 0
                          ? QuickItemModelRole::Invisible : QuickItemModelRole::None)
                         |(item->width() == 0 || item->height() == 0
                           ? QuickItemModelRole::ZeroSize : QuickItemModelRole::None)
+                        |(partiallyOutOfView
+                          ? QuickItemModelRole::PartiallyOutOfView : QuickItemModelRole::None)
                         |(outOfView
                           ? QuickItemModelRole::OutOfView : QuickItemModelRole::None)
                         |(item->hasFocus()
