@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ class QuickItemTreeWatcher : public QObject
     Q_OBJECT
 
 public:
-    explicit QuickItemTreeWatcher(QTreeView *view, QTreeView *sgView, QObject *parent = 0);
+    explicit QuickItemTreeWatcher(QTreeView *view, QTreeView *sgView, QObject *parent = nullptr);
     ~QuickItemTreeWatcher();
 
 private slots:
