@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ using namespace GammaRay;
 
 QuickSceneGraphModel::QuickSceneGraphModel(QObject *parent)
     : ObjectModelBase<QAbstractItemModel>(parent)
-    , m_rootNode(0)
+    , m_rootNode(nullptr)
 {
 }
 
@@ -78,9 +78,9 @@ void QuickSceneGraphModel::updateSGTree(bool emitSignals)
             updateSGTree(false);
         endResetModel();
     } else {
-        m_childParentMap[m_rootNode] = 0;
-        m_parentChildMap[0].resize(1);
-        m_parentChildMap[0][0] = m_rootNode;
+        m_childParentMap[m_rootNode] = nullptr;
+        m_parentChildMap[nullptr].resize(1);
+        m_parentChildMap[nullptr][0] = m_rootNode;
 
         populateFromNode(m_rootNode, emitSignals);
         collectItemNodes(m_window->contentItem());
@@ -90,7 +90,7 @@ void QuickSceneGraphModel::updateSGTree(bool emitSignals)
 QSGNode *QuickSceneGraphModel::currentRootNode() const
 {
     if (!m_window)
-        return Q_NULLPTR;
+        return nullptr;
 
     QQuickItem *item = m_window->contentItem();
     QQuickItemPrivate *itemPriv = QQuickItemPrivate::get(item);
