@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -50,23 +50,28 @@ class QuickScenePreviewWidget : public RemoteViewWidget
     Q_OBJECT
 
 public:
-    explicit QuickScenePreviewWidget(QuickInspectorInterface *inspector, QWidget *parent = 0);
+    explicit QuickScenePreviewWidget(QuickInspectorInterface *inspector, QWidget *parent = nullptr);
     ~QuickScenePreviewWidget();
 
+    void restoreState(const QByteArray &state) override;
+    QByteArray saveState() const override;
+
     void setSupportsCustomRenderModes(QuickInspectorInterface::Features supportedCustomRenderModes);
+    void setServerSideDecorationsState(bool enabled);
+
+    QuickInspectorInterface::RenderMode customRenderMode() const;
+    void setCustomRenderMode(QuickInspectorInterface::RenderMode customRenderMode);
+
+    bool serverSideDecorationsEnabled() const;
+    void setServerSideDecorationsEnabled(bool enabled);
 
 private Q_SLOTS:
-    void visualizeActionTriggered(bool checked);
-    void updateEffectiveGeometry();
+    void visualizeActionTriggered(QAction* current);
+    void serverSideDecorationsTriggered(bool enabled);
 
 private:
-    void drawArrow(QPainter *p, QPointF first, QPointF second);
-    void drawAnchor(QPainter *p, Qt::Orientation orientation, qreal ownAnchorLine, qreal offset,
-                    const QString &label);
-
-private:
-    void drawDecoration(QPainter *p) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *e) Q_DECL_OVERRIDE;
+    void drawDecoration(QPainter *p) override;
+    void resizeEvent(QResizeEvent *e) override;
 
     struct {
         QToolBar *toolbarWidget;
@@ -76,10 +81,10 @@ private:
         QAction *visualizeOverdraw;
         QAction *visualizeBatches;
         QAction *visualizeChanges;
+        QAction *serverSideDecorationsEnabled;
     } m_toolBar;
 
     QuickInspectorInterface *m_inspectorInterface;
-    QuickItemGeometry m_effectiveGeometry; // scaled and translated
 };
 } // namespace GammaRay
 
