@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -37,7 +37,7 @@ using namespace GammaRay;
 
 GraphicsView::GraphicsView(QWidget *parent)
     : QGraphicsView(parent)
-    , m_currentItem(0)
+    , m_currentItem(nullptr)
 {
     setMouseTracking(true);
 }
