@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -51,7 +51,7 @@ class SceneInspectorWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SceneInspectorWidget(QWidget *parent = 0);
+    explicit SceneInspectorWidget(QWidget *parent = nullptr);
     ~SceneInspectorWidget();
 
 private slots:
@@ -64,9 +64,10 @@ private slots:
     void visibleSceneRectChanged();
     void itemSelected(const QRectF &boundingRect);
     void sceneContextMenu(QPoint pos);
+    void propertyWidgetTabsChanged();
 
 private:
-    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
     QScopedPointer<Ui::SceneInspectorWidget> ui;
     UIStateManager m_stateManager;
@@ -82,7 +83,7 @@ class SceneInspectorUiFactory : public QObject, public StandardToolUiFactory<Sce
     Q_INTERFACES(GammaRay::ToolUiFactory)
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolUiFactory" FILE "gammaray_sceneinspector.json")
 public:
-    void initUi() Q_DECL_OVERRIDE;
+    void initUi() override;
 };
 }
 
