@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,7 +46,7 @@ using namespace GammaRay;
 
 SceneModel::SceneModel(QObject *parent)
     : QAbstractItemModel(parent)
-    , m_scene(0)
+    , m_scene(nullptr)
 {
     QGV_ITEMTYPE(QGraphicsLineItem)
     QGV_ITEMTYPE(QGraphicsPixmapItem)
