@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -35,11 +35,11 @@ class StateMachineViewerClient : public StateMachineViewerInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::StateMachineViewerInterface)
 public:
-    explicit StateMachineViewerClient(QObject *parent = 0);
+    explicit StateMachineViewerClient(QObject *parent = nullptr);
 
-    void selectStateMachine(int index) Q_DECL_OVERRIDE;
-    void toggleRunning() Q_DECL_OVERRIDE;
-    void repopulateGraph() Q_DECL_OVERRIDE;
+    void selectStateMachine(int index) override;
+    void toggleRunning() override;
+    void repopulateGraph() override;
 };
 }
 
