@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,8 @@
 
 #include "statemachineviewerclient.h"
 #include "statemodeldelegate.h"
+#include "statemodel.h"
+#include "statemachinedebuginterface.h"
 
 #include <common/objectbroker.h>
 #include <common/objectmodel.h>
@@ -36,6 +38,7 @@
 #include <ui/contextmenuextension.h>
 
 #include <kdstatemachineeditor/core/elementmodel.h>
+#include <kdstatemachineeditor/core/layoutproperties.h>
 #include <kdstatemachineeditor/core/state.h>
 #include <kdstatemachineeditor/core/transition.h>
 #include <kdstatemachineeditor/core/runtimecontroller.h>
@@ -88,10 +91,11 @@ void SelectionModelSyncer::handle_objectInspector_currentChanged(const QModelInd
     QScopedValueRollback<bool> block(m_updatesEnabled);
     m_updatesEnabled = false;
 
-    const auto objectId = index.data(ObjectModel::ObjectIdRole).value<ObjectId>();
+    const auto stateId = index.data(StateModel::StateIdRole).value<StateId>();
+
     const auto model = m_widget->stateMachineView()->scene()->model();
     const auto matches = model->match(model->index(0, 0), KDSME::StateModel::InternalIdRole,
-                                      static_cast<quintptr>(objectId.id()), 1,
+                                      static_cast<quintptr>(stateId), 1,
                                       Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap);
     auto selectionModel = m_widget->stateMachineView()->scene()->selectionModel();
     selectionModel->setCurrentIndex(matches.value(0), QItemSelectionModel::SelectCurrent);
@@ -106,10 +110,9 @@ void SelectionModelSyncer::handle_stateMachineView_currentChanged(const QModelIn
     m_updatesEnabled = false;
 
     const auto internalId = index.data(KDSME::StateModel::InternalIdRole).value<quintptr>();
-    const auto objectId = ObjectId(reinterpret_cast<QObject *>(internalId));
     const auto model = m_widget->objectInspector()->model();
-    const auto matches = model->match(model->index(0, 0), ObjectModel::ObjectIdRole,
-                                      QVariant::fromValue(objectId), 1,
+    const auto matches = model->match(model->index(0, 0), StateModel::StateIdRole,
+                                      QVariant::fromValue(StateId(internalId)), 1,
                                       Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap);
     auto selectionModel = m_widget->objectInspector()->selectionModel();
     selectionModel->setCurrentIndex(matches.value(
@@ -139,7 +142,8 @@ StateMachineViewerWidget::StateMachineViewerWidget(QWidget *parent, Qt::WindowFl
     : QWidget(parent, f)
     , m_ui(new Ui::StateMachineViewerWidget)
     , m_stateManager(this)
-    , m_machine(0)
+    , m_machine(nullptr)
+    , m_showLog(false)
 {
     ObjectBroker::registerClientObjectFactoryCallback<StateMachineViewerInterface *>(
         createStateMachineViewerClient);
@@ -170,7 +174,6 @@ StateMachineViewerWidget::StateMachineViewerWidget(QWidget *parent, Qt::WindowFl
     m_ui->singleStateMachineView->setExpandNewContent(true);
     m_ui->singleStateMachineView->setDeferredResizeMode(0, QHeaderView::Stretch);
     m_ui->singleStateMachineView->setDeferredResizeMode(1, QHeaderView::ResizeToContents);
-    m_ui->singleStateMachineView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     m_ui->singleStateMachineView->setItemDelegate(new StateModelDelegate(this));
     m_ui->singleStateMachineView->setModel(stateModel);
     connect(m_ui->singleStateMachineView, &QWidget::customContextMenuRequested, this,
@@ -239,6 +242,24 @@ StateMachineViewerWidget::~StateMachineViewerWidget()
     saveSettings();
 }
 
+void StateMachineViewerWidget::saveTargetState(QSettings *settings) const
+{
+    settings->setValue("ShowLog", m_showLog);
+
+    const auto scene = m_stateMachineView->scene();
+    settings->setValue("ShowTransitionsLabel", scene->layoutProperties()->showTransitionLabels());
+    settings->setValue("MaximumDepth", scene->maximumDepth());
+}
+
+void StateMachineViewerWidget::restoreTargetState(QSettings *settings)
+{
+    setShowLog(settings->value("ShowLog", m_showLog).toBool());
+
+    auto scene = m_stateMachineView->scene();
+    scene->layoutProperties()->setShowTransitionLabels(settings->value("ShowTransitionsLabel", true).toBool());
+    scene->setMaximumDepth(settings->value("MaximumDepth", 3).toInt());
+}
+
 void StateMachineViewerWidget::showContextMenuForObject(const QModelIndex &index,
                                                         const QPoint &globalPos)
 {
@@ -275,10 +296,6 @@ void StateMachineViewerWidget::loadSettings()
     QSettings settings;
     settings.beginGroup("Plugin_StateMachineViewer");
     m_stateMachineView->setThemeName(settings.value("ThemeName", "SystemTheme").toString());
-
-    // session-specific settings, we should probably save them on a per-target basis
-    m_stateMachineView->scene()->setMaximumDepth(settings.value("MaximumDepth", 3).toInt());
-
     settings.endGroup();
     settings.sync();
 }
@@ -288,9 +305,6 @@ void StateMachineViewerWidget::saveSettings()
     QSettings settings;
     settings.beginGroup("Plugin_StateMachineViewer");
     settings.setValue("ThemeName", m_stateMachineView->themeName());
-
-    settings.setValue("MaximumDepth", m_stateMachineView->scene()->maximumDepth());
-
     settings.endGroup();
     settings.sync();
 }
@@ -324,7 +338,7 @@ void StateMachineViewerWidget::stateAdded(const StateId stateId, const StateId p
         return;
 
     KDSME::State *parentState = m_idToStateMap.value(parentId);
-    KDSME::State *state = 0;
+    KDSME::State *state = nullptr;
     if (type == StateMachineState)
         state = m_machine = new KDSME::StateMachine;
     else if (type == GammaRay::FinalState)
@@ -401,7 +415,7 @@ void StateMachineViewerWidget::clearGraph()
 {
     IF_DEBUG(qDebug() << Q_FUNC_INFO);
 
-    m_stateMachineView->scene()->setRootState(0);
+    m_stateMachineView->scene()->setRootState(nullptr);
 
     m_idToStateMap.clear();
     m_idToTransitionMap.clear();
@@ -416,8 +430,7 @@ void StateMachineViewerWidget::repopulateView()
         return;
     m_stateMachineView->scene()->layout();
 
-    IF_DEBUG(m_machine->dumpObjectTree();
-             )
+    IF_DEBUG(m_machine->dumpObjectTree();)
 
     m_stateMachineView->fitInView();
 }
@@ -441,6 +454,7 @@ void StateMachineViewerWidget::objectInspectorContextMenu(QPoint pos)
 
 void StateMachineViewerWidget::setShowLog(bool show)
 {
+    m_showLog = show;
     m_ui->logExpandingWidget->setVisible(show);
     m_ui->showLogPushButton->setVisible(!show);
     m_ui->verticalSplitter->handle(0)->setEnabled(show);
