@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -52,9 +52,12 @@ class StateMachineViewerWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit StateMachineViewerWidget(QWidget *parent = 0, Qt::WindowFlags f = 0);
+    explicit StateMachineViewerWidget(QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
     virtual ~StateMachineViewerWidget();
 
+    Q_INVOKABLE void saveTargetState(QSettings *settings) const;
+    Q_INVOKABLE void restoreTargetState(QSettings *settings);
+
     KDSME::StateMachineView *stateMachineView() const;
     DeferredTreeView *objectInspector() const;
 
@@ -97,6 +100,7 @@ private:
     QHash<StateId, KDSME::State *> m_idToStateMap;
     QHash<TransitionId, KDSME::Transition *> m_idToTransitionMap;
     KDSME::StateMachine *m_machine;
+    bool m_showLog;
 };
 
 class StateMachineViewerUiFactory : public QObject,
