@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -35,11 +35,19 @@
 
 using namespace GammaRay;
 
+static State toState(QAbstractState *state = nullptr) {
+    return State(reinterpret_cast<quintptr>(state));
+}
+
+static Transition toTransition(QAbstractTransition *transition) {
+    return Transition(reinterpret_cast<quintptr>(transition));
+}
+
 StateMachineWatcher::StateMachineWatcher(QObject *parent)
     : QObject(parent)
-    , m_watchedStateMachine(0)
-    , m_lastEnteredState(0)
-    , m_lastExitedState(0)
+    , m_watchedStateMachine(nullptr)
+    , m_lastEnteredState(nullptr)
+    , m_lastExitedState(nullptr)
 {
 }
 
@@ -105,7 +113,7 @@ void StateMachineWatcher::handleTransitionTriggered()
     QAbstractTransition *transition = qobject_cast<QAbstractTransition *>(QObject::sender());
     Q_ASSERT(transition);
 
-    emit transitionTriggered(transition);
+    emit transitionTriggered(toTransition(transition));
 }
 
 void StateMachineWatcher::handleStateEntered()
@@ -120,7 +128,7 @@ void StateMachineWatcher::handleStateEntered()
         return;
 
     m_lastEnteredState = state;
-    emit stateEntered(state);
+    emit stateEntered(toState(state));
 }
 
 void StateMachineWatcher::handleStateExited()
@@ -135,7 +143,7 @@ void StateMachineWatcher::handleStateExited()
         return;
 
     m_lastExitedState = state;
-    emit stateExited(state);
+    emit stateExited(toState(state));
 }
 
 void StateMachineWatcher::handleStateDestroyed()
