@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,6 +30,8 @@
 #include <QObject>
 #include <QVector>
 
+#include "statemachinedebuginterface.h"
+
 QT_BEGIN_NAMESPACE
 class QAbstractState;
 class QAbstractState;
@@ -43,17 +45,17 @@ class StateMachineWatcher : public QObject
 {
     Q_OBJECT
 public:
-    explicit StateMachineWatcher(QObject *parent = 0);
+    explicit StateMachineWatcher(QObject *parent = nullptr);
     virtual ~StateMachineWatcher();
 
     void setWatchedStateMachine(QStateMachine *machine);
     QStateMachine *watchedStateMachine() const;
 
 Q_SIGNALS:
-    void stateEntered(QAbstractState *state);
-    void stateExited(QAbstractState *state);
+    void stateEntered(State state);
+    void stateExited(State state);
 
-    void transitionTriggered(QAbstractTransition *);
+    void transitionTriggered(Transition transition);
 
     void watchedStateMachineChanged(QStateMachine *);
 
