@@ -9,7 +9,7 @@
 
   Contact info@kdab.com if any conditions of this licensing are not clear to you.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,9 @@
 #ifndef GAMMARAY_STATEMACHINEVIEWER_STATEMODEL_H
 #define GAMMARAY_STATEMACHINEVIEWER_STATEMODEL_H
 
-#include <core/objectmodelbase.h>
+#include <common/objectmodel.h>
+
+#include <QAbstractItemModel>
 
 QT_BEGIN_NAMESPACE
 class QAbstractTransition;
@@ -37,30 +39,35 @@ QT_END_NAMESPACE
 
 namespace GammaRay {
 class StateModelPrivate;
+class StateMachineDebugInterface;
 
-class StateModel : public ObjectModelBase<QAbstractItemModel>
+class StateModel : public QAbstractItemModel
 {
     Q_OBJECT
 
 public:
     enum Roles {
-        TransitionsRole = ObjectModel::UserRole + 1,
-        IsInitialStateRole,
-        StateObjectRole = ObjectModel::UserRole + 11
+        TransitionsRole = ObjectModel::UserRole + 1, ///< return bool, see StateMachineDebugInterface::transitions()
+        IsInitialStateRole, ///< return bool, see StateMachineDebugInterface::isInitialState()
+        StateValueRole,     ///< return GammaRay::State
+        StateIdRole         ///< return GammaRay::StateId
     };
-    explicit StateModel(QObject *parent = 0);
+
+    explicit StateModel(QObject *parent = nullptr);
     ~StateModel();
 
-    void setStateMachine(QStateMachine *stateMachine);
-    QStateMachine *stateMachine() const;
+    void setStateMachine(StateMachineDebugInterface *stateMachine);
+    StateMachineDebugInterface *stateMachine() const;
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
+                      const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex &index) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                        int role = Qt::DisplayRole) const override;
+    QMap<int, QVariant> itemData(const QModelIndex &index) const override;
 
 protected:
     Q_DECLARE_PRIVATE(StateModel)
