@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,11 +36,11 @@ class StateModelDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
-    explicit StateModelDelegate(QObject *parent = Q_NULLPTR);
+    explicit StateModelDelegate(QObject *parent = nullptr);
 
 protected:
     void initStyleOption(QStyleOptionViewItem *option,
-                         const QModelIndex &index) const Q_DECL_OVERRIDE;
+                         const QModelIndex &index) const override;
 };
 }
 
