@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,6 +27,7 @@
 */
 
 #include "abstractstyleelementmodel.h"
+#include "dynamicproxystyle.h"
 
 #include <QApplication>
 #include <QProxyStyle>
@@ -78,3 +79,8 @@ bool AbstractStyleElementModel::isMainStyle() const
         style = proxy->baseStyle();
     }
 }
+
+QStyle* AbstractStyleElementModel::effectiveStyle() const
+{
+    return (isMainStyle() && DynamicProxyStyle::exists()) ? DynamicProxyStyle::instance() : m_style;
+}
