@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,14 +49,14 @@ class AbstractStyleElementStateTable : public GammaRay::AbstractStyleElementMode
 {
     Q_OBJECT
 public:
-    explicit AbstractStyleElementStateTable(QObject *parent = 0);
+    explicit AbstractStyleElementStateTable(QObject *parent = nullptr);
 
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                        int role = Qt::DisplayRole) const override;
 
 protected:
-    int doColumnCount() const Q_DECL_OVERRIDE;
-    QVariant doData(int row, int column, int role) const Q_DECL_OVERRIDE;
+    int doColumnCount() const override;
+    QVariant doData(int row, int column, int role) const override;
 
     /// standard setup for the style option used in a cell in column @p column
     void fillStyleOption(QStyleOption *option, int column) const;
