@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -44,7 +44,7 @@ struct complex_control_element_t {
     QStyle::SubControls subControls;
 };
 
-#define MAKE_CC2(control, factory) { #control, QStyle:: control, &StyleOption:: factory, 0 }
+#define MAKE_CC2(control, factory) { #control, QStyle:: control, &StyleOption:: factory, QStyle::SubControls() }
 #define MAKE_CC3(control, factory, subControls) { #control, QStyle:: control, \
                                                   &StyleOption:: factory, subControls }
 
@@ -97,8 +97,9 @@ QVariant ComplexControlModel::doData(int row, int column, int role) const
         m_style->drawComplexControl(complexControlElements[row].control, opt.data(), &painter);
 
         int colorIndex = 7;
-        for (int i = 0; i < 32; ++i) {
-            QStyle::SubControl sc = static_cast<QStyle::SubControl>(1 << i);
+        unsigned int nshifts = sizeof(unsigned int) * 8;
+        for (unsigned int i = 0; i < nshifts; ++i) {
+            QStyle::SubControl sc = static_cast<QStyle::SubControl>(1U << i);
             if (sc & complexControlElements[row].subControls) {
                 QRectF scRect
                     = m_style->subControlRect(complexControlElements[row].control, opt.data(), sc);
