@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -64,6 +64,11 @@ void DynamicProxyStyle::setPixelMetric(QStyle::PixelMetric metric, int value)
     m_pixelMetrics.insert(metric, value);
 }
 
+void DynamicProxyStyle::setStyleHint(QStyle::StyleHint hint, int value)
+{
+    m_styleHints.insert(hint, value);
+}
+
 int DynamicProxyStyle::pixelMetric(QStyle::PixelMetric metric, const QStyleOption *option,
                                    const QWidget *widget) const
 {
@@ -72,3 +77,11 @@ int DynamicProxyStyle::pixelMetric(QStyle::PixelMetric metric, const QStyleOptio
         return it.value();
     return QProxyStyle::pixelMetric(metric, option, widget);
 }
+
+int DynamicProxyStyle::styleHint(QStyle::StyleHint hint, const QStyleOption *option, const QWidget *widget, QStyleHintReturn *returnData) const
+{
+    const auto it = m_styleHints.find(hint);
+    if (it != m_styleHints.end())
+        return it.value();
+    return QProxyStyle::styleHint(hint, option, widget, returnData);
+}
