@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,12 +49,12 @@ class StyleElementStateTablePage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit StyleElementStateTablePage(QWidget *parent = 0);
+    explicit StyleElementStateTablePage(QWidget *parent = nullptr);
     ~StyleElementStateTablePage();
     void setModel(QAbstractItemModel *model);
 
 protected:
-    void showEvent(QShowEvent *show) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *show) override;
 
 private slots:
     void updateCellSize();
