@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,8 @@
 #include "styleinspectorwidget.h"
 #include "ui_styleinspectorwidget.h"
 
+#include <ui/propertyeditor/propertyeditordelegate.h>
+
 #include <common/objectbroker.h>
 
 using namespace GammaRay;
@@ -69,6 +71,12 @@ StyleInspectorWidget::StyleInspectorWidget(QWidget *parent)
     ui->standardPaletteView->setModel(ObjectBroker::model(QStringLiteral(
                                                               "com.kdab.GammaRay.StyleInspector.PaletteModel")));
 
+    ui->styleHintView->header()->setObjectName("styleHintViewHeader");
+    ui->styleHintView->setDeferredResizeMode(0, QHeaderView::ResizeToContents);
+    ui->styleHintView->setDeferredResizeMode(1, QHeaderView::ResizeToContents);
+    ui->styleHintView->setModel(ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.StyleInspector.StyleHintModel")));
+    ui->styleHintView->setItemDelegate(new PropertyEditorDelegate(this));
+
     // TODO this will fail due to lazy model population
     if (ui->styleSelector->count())
         styleSelected(0);
