@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -98,7 +98,7 @@ void TextDocumentInspector::documentSelected(const QItemSelection &selected,
 {
     Q_UNUSED(deselected);
     if (selected.isEmpty()) {
-        m_textDocumentModel->setDocument(0);
+        m_textDocumentModel->setDocument(nullptr);
         return;
     }
 
@@ -123,7 +123,7 @@ void TextDocumentInspector::documentElementSelected(const QItemSelection &select
 void TextDocumentInspector::registerMetaTypes()
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-    MetaObject *mo = Q_NULLPTR;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT1(QTextObject, QObject);
     MO_ADD_PROPERTY_RO(QTextObject, QTextDocument*, document);
     MO_ADD_PROPERTY_RO(QTextObject, int, formatIndex);
