@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -48,7 +48,7 @@ class TextDocumentInspector : public QObject
 {
     Q_OBJECT
 public:
-    explicit TextDocumentInspector(ProbeInterface *probe, QObject *parent = 0);
+    explicit TextDocumentInspector(ProbeInterface *probe, QObject *parent = nullptr);
 
 private slots:
     void documentSelected(const QItemSelection &selected, const QItemSelection &deselected);
@@ -71,7 +71,7 @@ class TextDocumentInspectorFactory : public QObject,
     Q_INTERFACES(GammaRay::ToolFactory)
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_textdocumentinspector.json")
 public:
-    explicit TextDocumentInspectorFactory(QObject *parent = Q_NULLPTR)
+    explicit TextDocumentInspectorFactory(QObject *parent = nullptr)
         : QObject(parent)
     {
     }
