@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -57,7 +57,7 @@ static QString formatTypeToString(int type)
 
 TextDocumentModel::TextDocumentModel(QObject *parent)
     : QStandardItemModel(parent)
-    , m_document(0)
+    , m_document(nullptr)
 {
 }
 
