@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ TimerInfo::TimerInfo(QObject *timer)
     , m_totalWakeups(0)
     , m_timer(timer)
     , m_timerId(-1)
-    , m_lastReceiver(0)
+    , m_lastReceiver(nullptr)
 {
     if (QTimer *t = qobject_cast<QTimer *>(timer)) {
         m_type = QTimerType;
@@ -83,7 +83,7 @@ QObject *TimerInfo::timerObject() const
 QTimer *TimerInfo::timer() const
 {
     if (m_type != QTimerType)
-        return 0;
+        return nullptr;
     return qobject_cast<QTimer *>(m_timer);
 }
 
