@@ -1,10 +1,11 @@
+
 /*
   timermodel.cpp
 
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,11 +42,11 @@ static const char timerInfoPropertyName[] = "GammaRay TimerInfo";
 using namespace GammaRay;
 using namespace std;
 
-static TimerModel *s_timerModel = 0;
+static TimerModel *s_timerModel = nullptr;
 
 TimerModel::TimerModel(QObject *parent)
     : QAbstractTableModel(parent)
-    , m_sourceModel(0)
+    , m_sourceModel(nullptr)
     , m_pendingChanedRowsTimer(new QTimer(this))
     , m_timeoutIndex(QTimer::staticMetaObject.indexOfSignal("timeout()"))
     , m_qmlTimerTriggeredIndex(-1)
@@ -57,12 +58,12 @@ TimerModel::TimerModel(QObject *parent)
 
 TimerModel::~TimerModel()
 {
-    s_timerModel = 0;
+    s_timerModel = nullptr;
 }
 
 bool TimerModel::isInitialized()
 {
-    return s_timerModel != 0;
+    return s_timerModel != nullptr;
 }
 
 TimerModel *TimerModel::instance()
@@ -328,7 +329,7 @@ bool TimerModel::eventFilter(QObject *watched, QEvent *event)
         // If there is a QTimer associated with this timer ID, don't handle it here, it will be handled
         // by the signal hooks for QTimer::timeout()
         if (findOrCreateQTimerTimerInfo(timerEvent->timerId()))
-            return false;
+            return QAbstractTableModel::eventFilter(watched, event);
 
         const TimerInfoPtr timerInfo = findOrCreateFreeTimerInfo(timerEvent->timerId());
         TimerInfo::TimeoutEvent timeoutEvent;
@@ -339,7 +340,7 @@ bool TimerModel::eventFilter(QObject *watched, QEvent *event)
         timerInfo->setLastReceiver(watched);
         emitFreeTimerChanged(m_freeTimers.indexOf(timerInfo));
     }
-    return false;
+    return QAbstractTableModel::eventFilter(watched, event);
 }
 
 void TimerModel::slotBeginRemoveRows(const QModelIndex &parent, int start, int end)
