@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -76,7 +76,7 @@ public:
     explicit TimerFilterModel(QObject *parent)
         : ObjectTypeFilterProxyModel<QTimer>(parent) {}
 
-    bool filterAcceptsObject(QObject *object) const Q_DECL_OVERRIDE
+    bool filterAcceptsObject(QObject *object) const override
     {
         if (object && object->inherits("QQmlTimer"))
             return true;
