@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,7 +45,7 @@ class TimerTop : public QObject
 {
     Q_OBJECT
 public:
-    explicit TimerTop(ProbeInterface *probe, QObject *parent = 0);
+    explicit TimerTop(ProbeInterface *probe, QObject *parent = nullptr);
 
 private slots:
     void objectSelected(QObject *obj);
@@ -61,7 +61,7 @@ class TimerTopFactory : public QObject, public StandardToolFactory<QTimer, Timer
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_timertop.json")
 
 public:
-    explicit TimerTopFactory(QObject *parent = 0);
+    explicit TimerTopFactory(QObject *parent = nullptr);
 };
 }
 
