@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,7 +46,7 @@ class TimerTopWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TimerTopWidget(QWidget *parent = 0);
+    explicit TimerTopWidget(QWidget *parent = nullptr);
     ~TimerTopWidget();
 
 private slots:
