@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Jan Dalheimer <jan.dalheimer@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,10 +30,14 @@
 #include "translatorwrapper.h"
 #include "translatorsmodel.h"
 
+#include <core/metaobject.h>
+#include <core/metaobjectrepository.h>
 #include <core/probeinterface.h>
 #include <core/objecttypefilterproxymodel.h>
 #include <core/remote/serverproxymodel.h>
+
 #include <common/objectbroker.h>
+#include <common/objectid.h>
 #include <common/objectmodel.h>
 
 #include <QCoreApplication>
@@ -43,10 +47,11 @@
 using namespace GammaRay;
 
 TranslatorInspector::TranslatorInspector(ProbeInterface *probe, QObject *parent)
-    : TranslatorInspectorInterface(QStringLiteral("com.kdab.GammaRay.TranslatorInspector"),
-                                   parent)
+    : TranslatorInspectorInterface(QStringLiteral("com.kdab.GammaRay.TranslatorInspector"), parent)
     , m_probe(probe)
 {
+    registerMetaTypes();
+
     m_translatorsModel = new TranslatorsModel(this);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.TranslatorsModel"),
                          m_translatorsModel);
@@ -71,6 +76,8 @@ TranslatorInspector::TranslatorInspector(ProbeInterface *probe, QObject *parent)
 
     qApp->installEventFilter(this);
     sendLanguageChangeEvent();
+
+    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), SLOT(objectSelected(QObject*)));
 }
 
 void TranslatorInspector::sendLanguageChangeEvent()
@@ -133,7 +140,7 @@ bool TranslatorInspector::eventFilter(QObject *object, QEvent *event)
 
 void TranslatorInspector::selectionChanged(const QItemSelection &selection)
 {
-    m_translationsModel->setSourceModel(0);
+    m_translationsModel->setSourceModel(nullptr);
     if (!selection.isEmpty()) {
         TranslatorWrapper *translator
             = m_translatorsModel->translator(selection.first().topLeft());
@@ -141,3 +148,27 @@ void TranslatorInspector::selectionChanged(const QItemSelection &selection)
             m_translationsModel->setSourceModel(translator->model());
     }
 }
+
+void TranslatorInspector::objectSelected(QObject* obj)
+{
+    auto t = qobject_cast<QTranslator*>(obj);
+    if (!t)
+        return;
+
+    const auto indexList = m_translatorsModel->match(m_translationsModel->index(0, 0),
+                       TranslatorsModel::ObjectIdRole,
+                       QVariant::fromValue(ObjectId(t)), 1,
+                       Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap);
+    if (indexList.isEmpty())
+        return;
+
+    const auto index = indexList.first();
+    m_selectionModel->select(index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows | QItemSelectionModel::Current);
+}
+
+void TranslatorInspector::registerMetaTypes()
+{
+    MetaObject *mo = nullptr;
+    MO_ADD_METAOBJECT1(QTranslator, QObject);
+    MO_ADD_PROPERTY_RO(QTranslator, bool, isEmpty);
+}
