@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Jan Dalheimer <jan.dalheimer@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -53,19 +53,22 @@ class TranslatorInspector : public TranslatorInspectorInterface
     Q_INTERFACES(GammaRay::TranslatorInspectorInterface)
 
 public:
-    explicit TranslatorInspector(GammaRay::ProbeInterface *probe, QObject *parent = 0);
+    explicit TranslatorInspector(GammaRay::ProbeInterface *probe, QObject *parent = nullptr);
 
 public slots:
-    void sendLanguageChangeEvent() Q_DECL_OVERRIDE;
-    void resetTranslations() Q_DECL_OVERRIDE;
+    void sendLanguageChangeEvent() override;
+    void resetTranslations() override;
 
 private slots:
     void selectionChanged(const QItemSelection &selection);
+    void objectSelected(QObject *obj);
 
 protected:
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *object, QEvent *event) override;
 
 private:
+    void registerMetaTypes();
+
     QItemSelectionModel *m_selectionModel;
     QItemSelectionModel *m_translationsSelectionModel;
     TranslatorsModel *m_translatorsModel;
@@ -82,7 +85,7 @@ class TranslatorInspectorFactory : public QObject,
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_translatorinspector.json")
 
 public:
-    explicit TranslatorInspectorFactory(QObject *parent = 0)
+    explicit TranslatorInspectorFactory(QObject *parent = nullptr)
         : QObject(parent) {}
 };
 }
