@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Jan Dalheimer <jan.dalheimer@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,6 +30,8 @@
 
 #include <core/util.h>
 
+#include <common/objectid.h>
+
 #include "translatorwrapper.h"
 
 using namespace GammaRay;
@@ -56,8 +58,8 @@ QVariant TranslatorsModel::data(const QModelIndex &index, int role) const
     if (!index.isValid())
         return QVariant();
 
-    if (role == TranslatorRole)
-        return QVariant::fromValue(m_translators.at(index.row()));
+    if (role == ObjectIdRole)
+        return QVariant::fromValue(ObjectId(m_translators.at(index.row())->translator()));
     TranslatorWrapper *trans = m_translators.at(index.row());
     Q_ASSERT(trans);
     if (role == Qt::DisplayRole) {
@@ -86,6 +88,13 @@ QVariant TranslatorsModel::headerData(int section, Qt::Orientation orientation,
     return QVariant();
 }
 
+QMap<int, QVariant> TranslatorsModel::itemData(const QModelIndex &index) const
+{
+    auto d = QAbstractTableModel::itemData(index);
+    d.insert(ObjectIdRole, data(index, ObjectIdRole));
+    return d;
+}
+
 TranslatorWrapper *TranslatorsModel::translator(const QModelIndex &index)
 const
 {
@@ -123,7 +132,7 @@ void TranslatorsModel::unregisterTranslator(TranslatorWrapper *translator)
                  qPrintable(Util::addressToString(translator)));
         return;
     }
-    disconnect(translator->model(), 0, this, 0);
+    disconnect(translator->model(), nullptr, this, nullptr);
     beginRemoveRows(QModelIndex(), index, index);
     m_translators.removeAt(index);
     endRemoveRows();
