@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Jan Dalheimer <jan.dalheimer@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -39,18 +39,18 @@ class TranslatorsModel : public QAbstractTableModel
     Q_OBJECT
 
 public:
-    explicit TranslatorsModel(QObject *parent = 0);
+    explicit TranslatorsModel(QObject *parent = nullptr);
 
     enum ExtraRoles
     {
-        TranslatorRole = Qt::UserRole
+        ObjectIdRole = Qt::UserRole + 1
     };
 
-    int columnCount(
-        const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &proxyIndex, int role) const Q_DECL_OVERRIDE;
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &proxyIndex, int role) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    QMap<int, QVariant> itemData(const QModelIndex & index) const override;
 
     TranslatorWrapper *translator(const QModelIndex &index) const;
 
