@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -67,7 +67,7 @@ void WebInspector::objectAdded(QObject *obj)
 {
     // both of the following cases seem to be needed, the web view object changes depending on
     // you have "import QtWebKit.experimental 1.0" or not...
-    QObject *experimental = 0;
+    QObject *experimental = nullptr;
     if (obj->inherits("QQuickWebView"))
         experimental = obj->property("experimental").value<QObject *>();
     if (obj->inherits("QQuickWebViewExperimental"))
