@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -35,6 +35,7 @@
 
 #include "overlaywidget.h"
 #include "widgettreemodel.h"
+#include "widget3dmodel.h"
 
 #include "core/propertycontroller.h"
 #include "core/metaobject.h"
@@ -133,6 +134,10 @@ WidgetInspectorServer::WidgetInspectorServer(ProbeInterface *probe, QObject *par
 
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.WidgetTree"), widgetSearchProxy);
 
+    auto widget3dmodel = new Widget3DModel(this);
+    widget3dmodel->setSourceModel(m_probe->objectTreeModel());
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.Widget3DModel"), widget3dmodel);
+
     m_widgetSelectionModel = ObjectBroker::selectionModel(widgetSearchProxy);
     connect(m_widgetSelectionModel,
             SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
@@ -165,37 +170,38 @@ void WidgetInspectorServer::widgetSelected(const QItemSelection &selection)
     ProbeGuard guard;
 
     if (selection.isEmpty()) {
-        m_propertyController->setObject(0);
+        m_propertyController->setObject(nullptr);
         return;
     }
     const QModelIndex index = selection.first().topLeft();
 
-    QWidget *widget = 0;
+    QLayout *layout = nullptr;
+    QWidget *widget = nullptr;
     if (index.isValid()) {
         QObject *obj = index.data(ObjectModel::ObjectRole).value<QObject *>();
         m_propertyController->setObject(obj);
         widget = qobject_cast<QWidget *>(obj);
-        QLayout *layout = qobject_cast<QLayout *>(obj);
+        layout = qobject_cast<QLayout *>(obj);
         if (!widget && layout)
             widget = layout->parentWidget();
     } else {
-        m_propertyController->setObject(0);
+        m_propertyController->setObject(nullptr);
     }
 
-    if (m_selectedWidget == widget)
+    if (m_selectedWidget == widget && !layout)
         return;
 
     if (!m_selectedWidget || !widget || m_selectedWidget->window() != widget->window())
         m_remoteView->resetView();
     m_selectedWidget = widget;
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-    m_remoteView->setEventReceiver(m_selectedWidget ? m_selectedWidget->window()->windowHandle() : Q_NULLPTR);
+    m_remoteView->setEventReceiver(m_selectedWidget ? m_selectedWidget->window()->windowHandle() : nullptr);
 #endif
 
     if (m_selectedWidget
         && (qobject_cast<QDesktopWidget *>(m_selectedWidget)
             || m_selectedWidget->inherits("QDesktopScreenWidget"))) {
-        m_overlayWidget->placeOn(0);
+        m_overlayWidget->placeOn(WidgetOrLayoutFacade());
         return;
     }
     if (m_selectedWidget == m_overlayWidget) {
@@ -203,7 +209,10 @@ void WidgetInspectorServer::widgetSelected(const QItemSelection &selection)
         return;
     }
 
-    m_overlayWidget->placeOn(m_selectedWidget);
+    if (layout)
+        m_overlayWidget->placeOn(layout);
+    else
+        m_overlayWidget->placeOn(widget);
 
     if (!m_selectedWidget)
         return;
@@ -283,7 +292,7 @@ void WidgetInspectorServer::pickElementId(const GammaRay::ObjectId &id)
 QImage WidgetInspectorServer::imageForWidget(QWidget *widget)
 {
     // prevent "recursion", i.e. infinite update loop, in our eventFilter
-    Util::SetTempValue<QPointer<QWidget> > guard(m_selectedWidget, 0);
+    Util::SetTempValue<QPointer<QWidget> > guard(m_selectedWidget, nullptr);
     // We should use hidpi rendering but it's buggy so let stay with
     // low dpi rendering. See QTBUG-53801
     const qreal ratio = 1; // widget->window()->devicePixelRatio();
@@ -498,7 +507,7 @@ void WidgetInspectorServer::checkFeatures()
 
 void WidgetInspectorServer::registerWidgetMetaTypes()
 {
-    MetaObject *mo = 0;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT0(QLayoutItem)
     MO_ADD_PROPERTY(QLayoutItem, Qt::Alignment, alignment, setAlignment);
     MO_ADD_PROPERTY_RO(QLayoutItem, QSizePolicy::ControlTypes, controlTypes);
