@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -57,14 +57,14 @@ class WidgetInspectorServer : public WidgetInspectorInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::WidgetInspectorInterface)
 public:
-    explicit WidgetInspectorServer(ProbeInterface *probe, QObject *parent = 0);
+    explicit WidgetInspectorServer(ProbeInterface *probe, QObject *parent = nullptr);
     ~WidgetInspectorServer();
 
 signals:
     void elementsAtReceived(const GammaRay::ObjectIds &ids, int bestCandidate);
 
 protected:
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *object, QEvent *event) override;
 
 private:
     GammaRay::ObjectIds recursiveWidgetsAt(QWidget *parent, const QPoint &pos,
@@ -84,12 +84,12 @@ private slots:
 
     void recreateOverlayWidget();
 
-    void saveAsImage(const QString &fileName) Q_DECL_OVERRIDE;
-    void saveAsSvg(const QString &fileName) Q_DECL_OVERRIDE;
-    void saveAsPdf(const QString &fileName) Q_DECL_OVERRIDE;
-    void saveAsUiFile(const QString &fileName) Q_DECL_OVERRIDE;
+    void saveAsImage(const QString &fileName) override;
+    void saveAsSvg(const QString &fileName) override;
+    void saveAsPdf(const QString &fileName) override;
+    void saveAsUiFile(const QString &fileName) override;
 
-    void analyzePainting() Q_DECL_OVERRIDE;
+    void analyzePainting() override;
 
     void updateWidgetPreview();
 
