@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,8 +30,16 @@
 #include "widgetinspectorwidget.h"
 #include "widgetinspectorinterface.h"
 #include "widgetinspectorclient.h"
+#include "widgetclientmodel.h"
 #include "ui_widgetinspectorwidget.h"
 #include "waextension/widgetattributetab.h"
+#include "widgetmodelroles.h"
+
+#ifdef GAMMARAY_WITH_WIDGET3D
+#include "widget3dview.h"
+#include <QQmlEngine>
+#include <QQmlComponent>
+#endif
 
 #include "common/objectbroker.h"
 #include "common/objectmodel.h"
@@ -48,6 +56,9 @@
 #include <QMenu>
 #include <QtPlugin>
 #include <QToolBar>
+#include <QSettings>
+#include <QLayout>
+#include <QTabBar>
 
 using namespace GammaRay;
 
@@ -60,8 +71,9 @@ WidgetInspectorWidget::WidgetInspectorWidget(QWidget *parent)
     : QWidget(parent)
     , ui(new Ui::WidgetInspectorWidget)
     , m_stateManager(this)
-    , m_inspector(0)
+    , m_inspector(nullptr)
     , m_remoteView(new RemoteViewWidget(this))
+    , m_3dView(nullptr)
 {
     ObjectBroker::registerClientObjectFactoryCallback<WidgetInspectorInterface *>(
         createWidgetInspectorClient);
@@ -70,7 +82,9 @@ WidgetInspectorWidget::WidgetInspectorWidget(QWidget *parent)
     ui->setupUi(this);
     ui->widgetPropertyWidget->setObjectBaseName(m_inspector->objectName());
 
-    auto widgetModel = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.WidgetTree"));
+    auto widgetTree = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.WidgetTree"));
+    auto widgetModel = new WidgetClientModel(this);
+    widgetModel->setSourceModel(widgetTree);
     ui->widgetTreeView->header()->setObjectName("widgetTreeViewHeader");
     ui->widgetTreeView->setDeferredResizeMode(0, QHeaderView::Stretch);
     ui->widgetTreeView->setDeferredResizeMode(1, QHeaderView::Interactive);
@@ -85,6 +99,8 @@ WidgetInspectorWidget::WidgetInspectorWidget(QWidget *parent)
 
     m_remoteView->setName(QStringLiteral("com.kdab.GammaRay.WidgetRemoteView"));
     m_remoteView->setPickSourceModel(widgetModel);
+    m_remoteView->setFlagRole(WidgetModelRoles::WidgetFlags);
+    m_remoteView->setInvisibleMask(WidgetModelRoles::Invisible);
 
     auto layout = new QVBoxLayout;
     layout->setMargin(0);
@@ -126,18 +142,59 @@ WidgetInspectorWidget::WidgetInspectorWidget(QWidget *parent)
     m_stateManager.setDefaultSizes(ui->mainSplitter, UISizeVector() << "50%" << "50%");
     m_stateManager.setDefaultSizes(ui->previewSplitter, UISizeVector() << "50%" << "50%");
 
-    connect(ui->widgetPropertyWidget, SIGNAL(tabsUpdated()), &m_stateManager, SLOT(reset()));
+#ifdef GAMMARAY_WITH_WIDGET3D
+    // Check if QQC are available, there's no build-time check for this
+    QQmlEngine engine;
+    QQmlComponent comp(&engine);
+    comp.setData("import QtQuick.Controls 1.2; CheckBox {}", QUrl());
+    QScopedPointer<QObject> obj(comp.create());
+    if (!obj.isNull()) {
+        QWidget *widget3d = new QWidget(this);
+        ui->tabWidget->addTab(widget3d, tr("3D View"));
+        widget3d->setLayout(new QHBoxLayout());
+    } else {
+        qWarning() << "Disabling 3D Widget inspector: missing QtQuick Controls";
+    }
+#else
+    qFindChild<QTabBar *>(ui->tabWidget)->hide();
+#endif
+
+    connect(ui->widgetPropertyWidget, SIGNAL(tabsUpdated()), this, SLOT(propertyWidgetTabsChanged()));
+    connect(ui->tabWidget, SIGNAL(currentChanged(int)), this, SLOT(onTabChanged(int)));
 }
 
 WidgetInspectorWidget::~WidgetInspectorWidget()
 {
 }
 
+void WidgetInspectorWidget::saveTargetState(QSettings *settings) const
+{
+    settings->setValue("remoteViewState", m_remoteView->saveState());
+}
+
+void WidgetInspectorWidget::restoreTargetState(QSettings *settings)
+{
+    m_remoteView->restoreState(settings->value("remoteViewState").toByteArray());
+}
+
+void WidgetInspectorWidget::onTabChanged(int index)
+{
+#ifdef GAMMARAY_WITH_WIDGET3D
+    if (index == 1 && m_3dView == nullptr) {
+        m_3dView = new Widget3DView(this);
+        ui->tabWidget->widget(1)->layout()->addWidget(m_3dView);
+    }
+#else
+    Q_UNUSED(index)
+#endif
+}
+
 void WidgetInspectorWidget::updateActions()
 {
     const auto model = ui->widgetTreeView->selectionModel()->selectedRows();
     const auto selection = !model.isEmpty() && model.first().isValid();
 
+    ui->actionSaveAsImage->setEnabled(selection);
     ui->actionSaveAsSvg->setEnabled(
         selection && m_inspector->features() & WidgetInspectorInterface::SvgExport);
     ui->actionSaveAsPdf->setEnabled(
@@ -153,8 +210,15 @@ void WidgetInspectorWidget::updateActions()
     m_remoteView->setSupportedInteractionModes(f);
 }
 
+void WidgetInspectorWidget::propertyWidgetTabsChanged()
+{
+    m_stateManager.saveState();
+    m_stateManager.reset();
+}
+
 void WidgetInspectorWidget::widgetSelected(const QItemSelection &selection)
 {
+    ui->tabWidget->setCurrentIndex(0); // select the tree view tab
     QModelIndex index;
     if (selection.size() > 0)
         index = selection.first().topLeft();
