@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,6 +41,7 @@ QT_END_NAMESPACE
 namespace GammaRay {
 class RemoteViewWidget;
 class WidgetInspectorInterface;
+class Widget3DView;
 
 namespace Ui {
 class WidgetInspectorWidget;
@@ -50,10 +51,14 @@ class WidgetInspectorWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit WidgetInspectorWidget(QWidget *parent = 0);
+    explicit WidgetInspectorWidget(QWidget *parent = nullptr);
     ~WidgetInspectorWidget();
 
+    Q_INVOKABLE void saveTargetState(QSettings *settings) const;
+    Q_INVOKABLE void restoreTargetState(QSettings *settings);
+
 private slots:
+    void onTabChanged(int index);
     void widgetSelected(const QItemSelection &selection);
     void widgetTreeContextMenu(QPoint pos);
 
@@ -63,12 +68,14 @@ private slots:
     void saveAsUiFile();
     void analyzePainting();
     void updateActions();
+    void propertyWidgetTabsChanged();
 
 private:
     QScopedPointer<Ui::WidgetInspectorWidget> ui;
     UIStateManager m_stateManager;
     WidgetInspectorInterface *m_inspector;
     RemoteViewWidget *m_remoteView;
+    Widget3DView *m_3dView;
 };
 
 class WidgetInspectorUiFactory : public QObject, public StandardToolUiFactory<WidgetInspectorWidget>
@@ -77,7 +84,7 @@ class WidgetInspectorUiFactory : public QObject, public StandardToolUiFactory<Wi
     Q_INTERFACES(GammaRay::ToolUiFactory)
     Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolUiFactory" FILE "gammaray_widgetinspector.json")
 public:
-    void initUi() Q_DECL_OVERRIDE;
+    void initUi() override;
 };
 }
 
