@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -28,10 +28,9 @@
 
 #include "widgettreemodel.h"
 #include "common/modelutils.h"
+#include "widgetmodelroles.h"
 
-#include <QApplication>
 #include <QLayout>
-#include <QPalette>
 #include <QWidget>
 
 using namespace GammaRay;
@@ -56,7 +55,7 @@ QPair<int, QVariant> WidgetTreeModel::defaultSelectedItem() const
 
 QVariant WidgetTreeModel::data(const QModelIndex &index, int role) const
 {
-    if (index.isValid() && role == Qt::ForegroundRole) {
+    if (index.isValid() && role == WidgetModelRoles::WidgetFlags) {
         QObject *obj = index.data(ObjectModel::ObjectRole).value<QObject *>();
         QWidget *widget = qobject_cast<QWidget *>(obj);
         if (!widget) {
@@ -64,12 +63,22 @@ QVariant WidgetTreeModel::data(const QModelIndex &index, int role) const
             if (layout)
                 widget = layout->parentWidget();
         }
+
         if (widget && !widget->isVisible())
-            return qApp->palette().color(QPalette::Disabled, QPalette::Text);
+            return WidgetModelRoles::Invisible;
+
+        return WidgetModelRoles::None;
     }
     return QSortFilterProxyModel::data(index, role);
 }
 
+QMap<int, QVariant> WidgetTreeModel::itemData(const QModelIndex &index) const
+{
+    auto d = ObjectFilterProxyModelBase::itemData(index);
+    d.insert(WidgetModelRoles::WidgetFlags, data(index, WidgetModelRoles::WidgetFlags));
+    return d;
+}
+
 bool WidgetTreeModel::filterAcceptsObject(QObject *object) const
 {
     return object->isWidgetType() || qobject_cast<QLayout *>(object);
