@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Giulio Camuffo <giulio.camuffo@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,25 +29,31 @@
 #include "wlcompositorinspector.h"
 
 #include <QAbstractTableModel>
+#include <QElapsedTimer>
 #include <QFile>
+#include <QItemSelectionModel>
 #include <QWaylandClient>
 #include <QWaylandSurface>
 #include <QWaylandView>
 #include <QWaylandSurfaceGrabber>
-#include <QElapsedTimer>
+
+#include <common/modelroles.h>
+#include <common/objectbroker.h>
+#include <common/objectid.h>
+#include <common/objectmodel.h>
+#include <common/remoteviewframe.h>
 
 #include <core/metaobject.h>
 #include <core/metaobjectrepository.h>
-#include <common/objectmodel.h>
 #include <core/objecttypefilterproxymodel.h>
 #include <core/singlecolumnobjectproxymodel.h>
 #include <core/remote/serverproxymodel.h>
 #include <3rdparty/kde/krecursivefilterproxymodel.h>
 #include <core/remoteviewserver.h>
-#include <common/remoteviewframe.h>
 
 #include <wayland-server.h>
 
+#include "clientsmodel.h"
 #include "ringbuffer.h"
 #include "resourceinfo.h"
 
@@ -130,8 +136,7 @@ public:
 
     Logger(WlCompositorInspector *inspector, QObject *parent)
         : QObject(parent)
-        , m_lines(500)
-        , m_currentClient(0)
+        , m_lines(5000)
         , m_connected(false)
         , m_inspector(inspector)
     {
@@ -140,11 +145,8 @@ public:
 
     void add(wl_resource *res, MessageType dir, const QString &line)
     {
-        if (m_currentClient && m_currentClient != wl_resource_get_client(res))
-          return;
-
         pid_t pid;
-        wl_client_get_credentials(wl_resource_get_client(res), &pid, 0, 0);
+        wl_client_get_credentials(wl_resource_get_client(res), &pid, nullptr, nullptr);
         QString l = QStringLiteral("%1 %2 %3").arg(QString::number(pid),
                                                    dir == MessageType::Request ? QLatin1String("->") : QLatin1String("<-"),
                                                    line);
@@ -152,20 +154,15 @@ public:
         // so we save some space using utf8 rather than the utf16 QString uses
         QByteArray utf8 = l.toUtf8();
         qint64 time = m_timer.nsecsElapsed();
-        m_lines.append({ time, utf8 });
+        m_lines.append({ time, pid, utf8 });
         if (m_connected) {
-            emit m_inspector->logMessage(time, utf8);
+            emit m_inspector->logMessage(pid, time, utf8);
         }
     }
 
     void setCurrentClient(QWaylandClient *client)
     {
-        m_currentClient = client ? client->client() : nullptr;
-
-        m_lines.clear();
-        if (m_connected) {
-            emit m_inspector->resetLog();
-        }
+        emit m_inspector->setLoggingClient(client ? client->processId() : 0);
     }
 
     void setConnected(bool c)
@@ -173,16 +170,16 @@ public:
         m_connected = c;
         for (int i = 0; i < m_lines.count(); ++i) {
             const Message &m = m_lines.at(i);
-            emit m_inspector->logMessage(m.time, m.line);
+            emit m_inspector->logMessage(m.pid, m.time, m.line);
         }
     }
 
     struct Message {
       qint64 time;
+      pid_t pid;
       QByteArray line;
     };
     RingBuffer<Message> m_lines;
-    wl_client *m_currentClient;
     bool m_connected;
     WlCompositorInspector *m_inspector;
     QElapsedTimer m_timer;
@@ -317,7 +314,7 @@ public:
 
     void addResource(wl_resource *res)
     {
-        wl_resource *parentResource = 0; // wl_resource_get_parent(res);
+        wl_resource *parentResource = nullptr; // wl_resource_get_parent(res);
         Resource *parent = parentResource ? Resource::fromWlResource(parentResource) : nullptr;
         int count = parent ? parent->children.count() : m_resources.count();
 
@@ -422,126 +419,19 @@ public:
     QWaylandClient *m_client;
 };
 
-class ClientsModel : public QAbstractTableModel
-{
-public:
-    enum Columns {
-        PidColumn,
-        CommandColumn,
-        EndColumn
-    };
-
-    explicit ClientsModel(ProbeInterface *probe, QObject *parent)
-        : QAbstractTableModel(parent)
-        , m_probe(probe)
-    {
-    }
-
-    QWaylandClient *client(int index) const
-    {
-        return m_clients.at(index);
-    }
-
-    void addClient(QWaylandClient *client)
-    {
-        beginInsertRows(QModelIndex(), m_clients.count(), m_clients.count());
-        m_clients.append(client);
-        endInsertRows();
-    }
-
-    void removeClient(QWaylandClient *client)
-    {
-        int index = -1;
-        for (int i = 0; i < m_clients.count(); ++i) {
-            if (m_clients.at(i) == client) {
-                index = i;
-                break;
-            }
-        }
-
-        if (index == -1) {
-            return;
-        }
-
-        beginRemoveRows(QModelIndex(), index, index);
-        m_clients.removeAt(index);
-        endRemoveRows();
-    }
-
-    int rowCount(const QModelIndex &) const override
-    {
-        return m_clients.count();
-    }
-
-    int columnCount(const QModelIndex &) const override
-    {
-        return EndColumn;
-    }
-
-    QVariant data(const QModelIndex &index, int role) const override
-    {
-        Q_UNUSED(role)
-        auto client = m_clients.at(index.row());
-
-        switch (index.column()) {
-            case PidColumn:
-                return client->processId();
-            case CommandColumn: {
-                auto pid = client->processId();
-                QByteArray path;
-                QTextStream(&path) << "/proc/" << pid << "/cmdline";
-                QFile file(path);
-                if (!file.open(QIODevice::ReadOnly)) {
-                    return QStringLiteral("Not available :/");
-                }
-
-                QByteArray data = file.readAll();
-                data.replace('\0', ' ');
-                return data;
-            }
-        }
-        return QVariant();
-    }
-
-    QMap<int, QVariant> itemData(const QModelIndex &index) const override
-    {
-        QMap<int, QVariant> map;
-        auto insertRole = [&](int role) {
-            map[role] = data(index, role);
-        };
-        insertRole(Qt::DisplayRole);
-        return map;
-    }
-
-    QVariant headerData(int section, Qt::Orientation orientation, int) const override
-    {
-        if (orientation == Qt::Horizontal) {
-            switch (section) {
-                case PidColumn:
-                    return QStringLiteral("pid");
-                case CommandColumn:
-                    return QStringLiteral("command");
-            }
-        }
-        return QString::number(section + 1);
-    }
-
-    QVector<QWaylandClient *> m_clients;
-    ProbeInterface *m_probe;
-};
-
 WlCompositorInspector::WlCompositorInspector(ProbeInterface* probe, QObject* parent)
                      : WlCompositorInterface(parent)
                      , m_surfaceView(new SurfaceView(this))
 {
     qWarning()<<"init probe"<<probe->objectTreeModel()<<probe->probe();
 
-    MetaObject *mo = 0;
+    MetaObject *mo = nullptr;
     MO_ADD_METAOBJECT1(QWaylandObject, QObject);
     MO_ADD_METAOBJECT1(QWaylandCompositor, QWaylandObject);
 
-    m_clientsModel = new ClientsModel(probe, this);
+    m_clientsModel = new ClientsModel(this);
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.WaylandCompositorClientsModel"), m_clientsModel);
+    m_clientSelectionModel = ObjectBroker::selectionModel(m_clientsModel);
 
     m_resourcesModel = new ResourcesModel;
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.WaylandCompositorResourcesModel"), m_resourcesModel);
@@ -549,6 +439,7 @@ WlCompositorInspector::WlCompositorInspector(ProbeInterface* probe, QObject* par
     m_logger = new Logger(this, this);
 
     connect(probe->probe(), SIGNAL(objectCreated(QObject*)), this, SLOT(objectAdded(QObject*)));
+    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), SLOT(objectSelected(QObject*)));
 }
 
 WlCompositorInspector::~WlCompositorInspector()
@@ -567,6 +458,21 @@ void WlCompositorInspector::objectAdded(QObject *obj)
     }
 }
 
+void WlCompositorInspector::objectSelected(QObject *obj)
+{
+    if (auto client = qobject_cast<QWaylandClient*>(obj)) {
+        const auto indexList = m_clientsModel->match(m_clientsModel->index(0, 0),
+                    ClientsModel::ObjectIdRole,
+                    QVariant::fromValue(ObjectId(client)), 1,
+                    Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap);
+
+        if (indexList.isEmpty())
+            return;
+        const auto index = indexList.first();
+        m_clientSelectionModel->select(index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows | QItemSelectionModel::Current);
+    }
+}
+
 /* this comes from wayland */
 struct argument_details {
        char type;
@@ -631,7 +537,7 @@ void WlCompositorInspector::init(QWaylandCompositor *compositor)
                   break;
               case 'o': {
                   wl_resource *r = (wl_resource *)arg.o;
-                  line += ResourceInfo(r).name();
+                  line += r ? ResourceInfo(r).name() : QLatin1String("(nil)");
                   break;
               }
               case 'n': {
@@ -674,11 +580,11 @@ void WlCompositorInspector::addClient(wl_client *c)
 
     QString pid = QString::number(client->processId());
     qWarning()<<"client"<<client<<pid;
-    connect(client, &QObject::destroyed, [this, pid, client](QObject *) {
+    connect(client, &QObject::destroyed, this, [this, pid, client](QObject *) {
         if (m_resourcesModel->client() == client) {
           m_resourcesModel->setClient(nullptr);
-          m_clientsModel->removeClient(client);
         }
+        m_clientsModel->removeClient(client);
     });
 
     m_clientsModel->addClient(client);
