@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -56,9 +56,9 @@
 using namespace GammaRay;
 
 // previously installed Qt hooks, for daisy-chaining
-static void (*gammaray_next_startup_hook)() = 0;
-static void (*gammaray_next_addObject)(QObject *) = 0;
-static void (*gammaray_next_removeObject)(QObject *) = 0;
+static void (*gammaray_next_startup_hook)() = nullptr;
+static void (*gammaray_next_addObject)(QObject *) = nullptr;
+static void (*gammaray_next_removeObject)(QObject *) = nullptr;
 
 extern "C" Q_DECL_EXPORT void gammaray_startup_hook()
 {
@@ -160,3 +160,8 @@ extern "C" Q_DECL_EXPORT void gammaray_probe_attach()
         ProbeCreator::Create | ProbeCreator::FindExistingObjects
         | ProbeCreator::ResendServerAddress);
 }
+
+extern "C" Q_DECL_EXPORT void gammaray_install_hooks()
+{
+    Hooks::installHooks();
+}
