@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -58,6 +58,10 @@ extern Q_DECL_EXPORT void gammaray_probe_inject();
  *  on the other side.
  */
 extern Q_DECL_EXPORT void gammaray_probe_attach();
+
+/** Entry point for static injections. */
+extern Q_DECL_EXPORT void gammaray_install_hooks();
+
 }
 
 namespace GammaRay {
