@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,7 +41,7 @@ class AttachHelper : public QObject
     Q_OBJECT
 public:
     explicit AttachHelper(const QString &gammaray, const QString &injector, const QString &debuggee,
-                          const QStringList &arguments, QObject *parent = 0);
+                          const QStringList &arguments, QObject *parent = nullptr);
 
 public slots:
     void attach();
