@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,7 +32,7 @@ class MyObject : public QObject
 {
     Q_OBJECT
 public:
-    explicit MyObject(QObject *parent = 0)
+    explicit MyObject(QObject *parent = nullptr)
         : QObject(parent)
         , c(new QObject(this))
         , p1(new QObject(this))
@@ -55,7 +55,7 @@ public slots:
         if (c->parent() == p1)
             c->setParent(p2);
         else if (c->parent() == p2)
-            c->setParent(0);
+            c->setParent(nullptr);
         else
             c->setParent(p1);
     }
