@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -62,7 +62,7 @@ private slots:
         auto *mo = MetaObjectRepository::instance()->metaObject(QStringLiteral("QThread"));
         QVERIFY(mo->propertyCount() >= 7); // depends on Qt version
 
-        MetaProperty *prop = 0;
+        MetaProperty *prop = nullptr;
         for (int i = 0; i < mo->propertyCount(); ++i) {
             prop = mo->propertyAt(i);
             QVERIFY(prop);
@@ -85,7 +85,7 @@ private slots:
         QVERIFY(mo);
         QVERIFY(mo->propertyCount() >= 8); // depends on Qt version
 
-        MetaProperty *prop = 0;
+        MetaProperty *prop = nullptr;
         for (int i = 0; i < mo->propertyCount(); ++i) {
             prop = mo->propertyAt(i);
             QVERIFY(prop);
@@ -97,7 +97,7 @@ private slots:
         QCOMPARE(prop->name(), "libraryPaths");
         QCOMPARE(prop->typeName(), "QStringList");
         QCOMPARE(prop->isReadOnly(), true);
-        QCOMPARE(prop->value(0).toStringList(), QCoreApplication::libraryPaths());
+        QCOMPARE(prop->value(nullptr).toStringList(), QCoreApplication::libraryPaths());
     }
 };
 
