@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,12 +45,13 @@ public:
         , delay(0)
         , iterations(100) {}
 
-    void run() Q_DECL_OVERRIDE
+    void run() override
     {
         objects.reserve(batchSize);
         for (int i = 0; i < iterations; ++i) {
-            for (int j = 0; j < batchSize; ++j)
+            for (int j = 0; j < batchSize; ++j) {
                 objects.push_back(new QObject);
+            }
             QTest::qWait(delay);
             qDeleteAll(objects);
             objects.clear();
@@ -79,9 +80,9 @@ private:
 private slots:
     void testCreateDestroy_data()
     {
-        QTest::addColumn<int>("batchSize");
-        QTest::addColumn<int>("delay");
-        QTest::addColumn<int>("iterations");
+        QTest::addColumn<int>("batchSize", nullptr);
+        QTest::addColumn<int>("delay", nullptr);
+        QTest::addColumn<int>("iterations", nullptr);
 
         QTest::newRow("10-0-1000") << 10 << 0 << 1000;
         QTest::newRow("100-1-100") << 100 << 1 << 100;
