@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -285,7 +285,7 @@ private slots:
     void testQtMetaObject()
     {
         auto adaptor
-            = PropertyAdaptorFactory::create(ObjectInstance(0,
+            = PropertyAdaptorFactory::create(ObjectInstance(nullptr,
                                                             &PropertyTestObject::staticMetaObject),
                                              this);
         QVERIFY(adaptor);
