@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,7 +41,7 @@ class TestObject : public QObject
 {
     Q_OBJECT
 public:
-    explicit TestObject(QObject *parent = 0);
+    explicit TestObject(QObject *parent = nullptr);
     ~TestObject();
 
 private slots:
@@ -92,9 +92,9 @@ class TestThread : public QThread
     Q_OBJECT
 public:
     TestThread(TestConnections::Type type, int timeOuts, int timeoutInterval = -1,
-               QObject *parent = 0);
+               QObject *parent = nullptr);
     ~TestThread();
-    void run() Q_DECL_OVERRIDE;
+    void run() override;
 
 private:
     TestConnections::Type m_type;
