@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -54,7 +54,7 @@ public:
         Declaration
     };
 
-    explicit ContextMenuExtension(ObjectId id = ObjectId());
+    explicit ContextMenuExtension(const ObjectId &id = ObjectId());
 
     void setLocation(Location location, const SourceLocation &sourceLocation);
 
