@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,7 +49,7 @@ namespace GammaRay {
 struct HelpControllerPrivate
 {
     HelpControllerPrivate()
-        : proc(Q_NULLPTR) {}
+        : proc(nullptr) {}
 
     void startProcess();
     void sendCommand(const QByteArray &cmd);
@@ -73,7 +73,7 @@ void HelpControllerPrivate::startProcess()
                                                     QProcess::ExitStatus)>(&QProcess::finished),
                      [this](){
         proc->deleteLater();
-        proc = Q_NULLPTR;
+        proc = nullptr;
     });
     proc->setProgram(assistantPath);
     proc->setArguments(QStringList()
@@ -132,7 +132,7 @@ void HelpController::openContents()
     auto d = s_helpController();
     d->startProcess();
     d->sendCommand(
-        "setSource qthelp://com.kdab.GammaRay." GAMMARAY_PLUGIN_VERSION "/doc/index.html;syncContents\n");
+        "setSource qthelp://com.kdab.GammaRay." GAMMARAY_PLUGIN_VERSION "/gammaray/index.html;syncContents\n");
 }
 
 void HelpController::openPage(const QString &page)
