@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,6 +32,7 @@
 #include "aboutpluginsdialog.h"
 #include "aboutdialog.h"
 #include "clienttoolmanager.h"
+#include "clienttoolfilterproxymodel.h"
 #include "aboutdata.h"
 #include "uiintegration.h"
 #include "helpcontroller.h"
@@ -59,7 +60,6 @@
 #include <QMenu>
 #include <QProcess>
 #include <QSettings>
-#include <QSortFilterProxyModel>
 #include <QStyleFactory>
 #include <QTableView>
 #include <QToolButton>
@@ -90,6 +90,10 @@ static const IdeSettings ideSettings[] = {
       "kate"      },
     { "kwrite", "%f --line %l --column %c", QT_TRANSLATE_NOOP("GammaRay::MainWindow", "KWrite"),
       nullptr     },
+    { "gedit", "%f +%l:%c", QT_TRANSLATE_NOOP("GammaRay::MainWindow", "gedit"),
+      nullptr     },
+    { "gvim", "%f +%l", QT_TRANSLATE_NOOP("GammaRay::MainWindow", "gvim"),
+      nullptr     },
     { "qtcreator", "%f", QT_TRANSLATE_NOOP("GammaRay::MainWindow", "Qt Creator"), nullptr     }
 #endif
 };
@@ -193,28 +197,40 @@ MainWindow::MainWindow(QWidget *parent)
 
     setWindowIcon(QIcon(QStringLiteral(":gammaray/GammaRay-128x128.png")));
 
-    ClientToolManager *toolManager = new ClientToolManager(this);
+    // ClientConnectionManager take care of creating and requesting server tools
+    // but in-process ui need to do it itself.
+    ClientToolManager *toolManager = ClientToolManager::instance();
+    if (!toolManager) {
+        toolManager = new ClientToolManager(this);
+        toolManager->requestAvailableTools();
+    }
+
     toolManager->setToolParentWidget(this);
 
     auto sourceModel = toolManager->model();
     auto sourceSelectionModel = toolManager->selectionModel();
-    auto proxyModel = new QSortFilterProxyModel(this);
-    proxyModel->setSourceModel(sourceModel);
-    proxyModel->setDynamicSortFilter(true);
-    proxyModel->sort(0);
-    ui->toolSelector->setModel(proxyModel);
-    ui->toolSelector->setSelectionModel(new KLinkItemSelectionModel(proxyModel, sourceSelectionModel, sourceModel));
+    m_toolFilterModel = new ClientToolFilterProxyModel(this);
+    m_toolFilterModel->setSourceModel(sourceModel);
+    m_toolFilterModel->setDynamicSortFilter(true);
+    m_toolFilterModel->sort(0);
+    ui->toolSelector->setModel(m_toolFilterModel);
+    ui->toolSelector->setSelectionModel(new KLinkItemSelectionModel(m_toolFilterModel, sourceSelectionModel, sourceModel));
     ui->toolSelector->resize(ui->toolSelector->minimumSize());
     connect(toolManager->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             SLOT(toolSelected()));
+    connect(ui->toolSelector, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(toolContextMenu(QPoint)));
+
+    QSettings settings(QStringLiteral("KDAB"), QStringLiteral("GammaRay"));
+    settings.beginGroup("Sidebar");
+    m_toolFilterModel->setFilterInactiveTools(settings.value(QLatin1String("FilterInactive"), false).toBool());
+    settings.endGroup();
+
 
     // hide unused tool bar for now
     ui->mainToolBar->setHidden(true);
 
     setWindowTitle(tr("GammaRay (%1)").arg(Endpoint::instance()->label()));
 
-    selectInitialTool();
-
     // Code Navigation
     QAction *configAction = new QAction(QIcon::fromTheme(QStringLiteral(
                                                              "applications-development")),
@@ -223,13 +239,12 @@ MainWindow::MainWindow(QWidget *parent)
     auto group = new QActionGroup(this);
     group->setExclusive(true);
 
-    QSettings settings(QStringLiteral("KDAB"), QStringLiteral("GammaRay"));
     settings.beginGroup(QStringLiteral("CodeNavigation"));
     const auto currentIdx = settings.value(QStringLiteral("IDE"), -1).toInt();
 
     for (int i = 0; i < ideSettingsSize; ++i) {
         auto action = new QAction(menu);
-        action->setText(QObject::tr(ideSettings[i].name));
+        action->setText(tr(ideSettings[i].name));
         if (ideSettings[i].icon)
             action->setIcon(QIcon::fromTheme(ideSettings[i].icon));
         action->setCheckable(true);
@@ -274,10 +289,33 @@ MainWindow::MainWindow(QWidget *parent)
 
     connect(UiIntegration::instance(), SIGNAL(navigateToCode(QUrl,int,int)), this,
             SLOT(navigateToCode(QUrl,int,int)));
+
+    connect(this, SIGNAL(targetQuitRequested()), &m_stateManager, SLOT(saveState()));
 }
 
 MainWindow::~MainWindow()
 {
+    QSettings settings(QStringLiteral("KDAB"), QStringLiteral("GammaRay"));
+    settings.beginGroup("Sidebar");
+    settings.setValue(QLatin1String("FilterInactive"), m_toolFilterModel->filterInactiveTools());
+    settings.endGroup();
+}
+
+void MainWindow::saveTargetState(QSettings *settings) const
+{
+    // When closing/quitting the client main window, this is triggered but the connection is already closed
+    if (Endpoint::instance()->isConnected()) {
+        const QModelIndex toolIndex = ui->toolSelector->selectionModel()->selectedRows().value(0);
+        const QString toolId = toolIndex.data(ToolModelRole::ToolId).toString();
+        settings->setValue("selectedToolId", toolId);
+    }
+}
+
+void MainWindow::restoreTargetState(QSettings *settings)
+{
+    Q_ASSERT(ClientToolManager::instance()->isToolListLoaded());
+    const QString toolId = settings->value("selectedToolId", QStringLiteral("GammaRay::ObjectInspector")).toString();
+    selectTool(toolId);
 }
 
 void MainWindow::help()
@@ -336,13 +374,15 @@ void MainWindow::showMessageStatistics()
 
 bool MainWindow::selectTool(const QString &id)
 {
+    if (id.isEmpty())
+        return false;
+
     const QItemSelectionModel::SelectionFlags selectionFlags = QItemSelectionModel::ClearAndSelect
-                                                               |QItemSelectionModel::Rows
+                                                               | QItemSelectionModel::Rows
                                                                | QItemSelectionModel::Current;
     const Qt::MatchFlags matchFlags = Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap;
     const QAbstractItemModel *model = ui->toolSelector->model();
-    const QModelIndex toolIndex = model->match(model->index(0,
-                                                            0), ToolModelRole::ToolId, id, 1,
+    const QModelIndex toolIndex = model->match(model->index(0,0), ToolModelRole::ToolId, id, 1,
                                                matchFlags).value(0);
     if (!toolIndex.isValid())
         return false;
@@ -352,15 +392,6 @@ bool MainWindow::selectTool(const QString &id)
     return true;
 }
 
-void MainWindow::selectInitialTool()
-{
-    auto model = ui->toolSelector->model();
-    QModelIndexList matches = model->match(model->index(0, 0), ToolModelRole::ToolId, QStringLiteral("GammaRay::ObjectInspector"));
-    if (matches.isEmpty())
-        return;
-    ui->toolSelector->setCurrentIndex(matches.first());
-}
-
 void MainWindow::toolSelected()
 {
     ui->actionsMenu->clear();
@@ -413,6 +444,16 @@ void MainWindow::toolSelected()
     ui->actionsMenu->setTitle(mi.data().toString());
 }
 
+void MainWindow::toolContextMenu(QPoint pos)
+{
+    QMenu menu;
+    auto action = menu.addAction(tr("Hide inactive tools"));
+    action->setCheckable(true);
+    action->setChecked(m_toolFilterModel->filterInactiveTools());
+    connect(action, SIGNAL(toggled(bool)), m_toolFilterModel, SLOT(setFilterInactiveTools(bool)));
+    menu.exec(ui->toolSelector->viewport()->mapToGlobal(pos));
+}
+
 void MainWindow::navigateToCode(const QUrl &url, int lineNumber, int columnNumber)
 {
     // Show Qt resources in our qrc browser
@@ -441,11 +482,10 @@ void MainWindow::navigateToCode(const QUrl &url, int lineNumber, int columnNumbe
             QDesktopServices::openUrl(QUrl(url));
         }
 
-        const QString filePath = url.isLocalFile()
-                                 || url.isRelative() ? url.toLocalFile() : url.toString();
+        const QString filePath = url.isLocalFile() ? url.toLocalFile() : url.toString();
         command.replace(QStringLiteral("%f"), filePath);
-        command.replace(QStringLiteral("%l"), QString::number(std::max(0, lineNumber)));
-        command.replace(QStringLiteral("%c"), QString::number(std::max(0, columnNumber)));
+        command.replace(QStringLiteral("%l"), QString::number(std::max(1, lineNumber)));
+        command.replace(QStringLiteral("%c"), QString::number(std::max(1, columnNumber)));
 
         if (!command.isEmpty())
             QProcess::startDetached(command);
