@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -41,7 +41,7 @@ class PropertyDoublePairEditor : public QWidget
 {
     Q_OBJECT
 public:
-    explicit PropertyDoublePairEditor(QWidget *parent = 0);
+    explicit PropertyDoublePairEditor(QWidget *parent = nullptr);
     ~PropertyDoublePairEditor();
 
 protected:
@@ -53,7 +53,7 @@ class PropertyPointFEditor : public PropertyDoublePairEditor
     Q_OBJECT
     Q_PROPERTY(QPointF pointF READ pointF WRITE setPointF USER true)
 public:
-    explicit PropertyPointFEditor(QWidget *parent = 0);
+    explicit PropertyPointFEditor(QWidget *parent = nullptr);
     QPointF pointF() const;
     void setPointF(const QPointF &point);
 };
@@ -63,7 +63,7 @@ class PropertySizeFEditor : public PropertyDoublePairEditor
     Q_OBJECT
     Q_PROPERTY(QSizeF sizeF READ sizeF WRITE setSizeF USER true)
 public:
-    explicit PropertySizeFEditor(QWidget *parent = 0);
+    explicit PropertySizeFEditor(QWidget *parent = nullptr);
     QSizeF sizeF() const;
     void setSizeF(const QSizeF &size);
 };
