@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -149,14 +149,6 @@ template<> struct matrix_trait<QQuaternion> {
 
 PropertyEditorDelegate::PropertyEditorDelegate(QObject *parent)
     : QStyledItemDelegate(parent)
-    , ItemDelegateInterface(QString())
-{
-    setItemEditorFactory(PropertyEditorFactory::instance());
-}
-
-PropertyEditorDelegate::PropertyEditorDelegate(const QString &placeholderText, QObject *parent)
-    : QStyledItemDelegate(parent)
-    , ItemDelegateInterface(placeholderText)
 {
     setItemEditorFactory(PropertyEditorFactory::instance());
 }
@@ -194,23 +186,7 @@ void PropertyEditorDelegate::paint(QPainter *painter, const QStyleOptionViewItem
         paint(painter, option, index, value.value<QQuaternion>());
 #endif
     } else {
-        if (placeholderText().isEmpty()) {
-            QStyledItemDelegate::paint(painter, option, index);
-        } else {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-            QStyleOptionViewItem opt = option;
-#else
-            QStyleOptionViewItemV4 opt
-                = *qstyleoption_cast<const QStyleOptionViewItemV4 *>(&option);
-#endif
-
-            opt.text = defaultDisplayText(index);
-            initStyleOption(&opt, index);
-
-            const QWidget *widget = this->widget(option);
-            QStyle *style = this->style(option);
-            style->drawControl(QStyle::CE_ItemViewItem, &opt, painter, widget);
-        }
+        QStyledItemDelegate::paint(painter, option, index);
     }
 }
 
@@ -246,9 +222,6 @@ QSize PropertyEditorDelegate::sizeHint(const QStyleOptionViewItem &option,
         QStyleOptionViewItemV4 opt = *qstyleoption_cast<const QStyleOptionViewItemV4 *>(&option);
 #endif
 
-        if (opt.text.isEmpty() && !placeholderText().isEmpty())
-            opt.text = defaultDisplayText(index);
-
         QSize sh = QStyledItemDelegate::sizeHint(opt, index);
 
         initStyleOption(&opt, index);
@@ -273,7 +246,7 @@ void PropertyEditorDelegate::paint(QPainter *painter, const QStyleOptionViewItem
 
     QRect textRect = QApplication::style()->subElementRect(QStyle::SE_ItemViewItemText, &opt,
                                                            opt.widget);
-    const int textHMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin, 0,
+    const int textHMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin, nullptr,
                                                                opt.widget) + 1;
     static const int textVMargin = 1;
     textRect = textRect.adjusted(textHMargin, textVMargin, -textHMargin, -textVMargin);
@@ -326,7 +299,7 @@ QSize PropertyEditorDelegate::sizeHint(const QStyleOptionViewItem &option, const
     initStyleOption(&opt, index);
 
     static const int parenthesisLineWidth = 1;
-    const int textHMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin, 0,
+    const int textHMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin, nullptr,
                                                                opt.widget) + 1;
     static const int textVMargin = 1;
 
