@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,7 +45,7 @@ class PropertyIntPairEditor : public QWidget
 {
     Q_OBJECT
 public:
-    explicit PropertyIntPairEditor(QWidget *parent = 0);
+    explicit PropertyIntPairEditor(QWidget *parent = nullptr);
     ~PropertyIntPairEditor();
 
 protected:
@@ -60,7 +60,7 @@ class PropertyPointEditor : public PropertyIntPairEditor
     Q_OBJECT
     Q_PROPERTY(QPoint point READ point WRITE setPoint USER true)
 public:
-    explicit PropertyPointEditor(QWidget *parent = 0);
+    explicit PropertyPointEditor(QWidget *parent = nullptr);
 
     QPoint point() const;
     void setPoint(const QPoint &point);
@@ -72,7 +72,7 @@ class PropertySizeEditor : public PropertyIntPairEditor
     Q_OBJECT
     Q_PROPERTY(QSize sizeValue READ sizeValue WRITE setSizeValue USER true)
 public:
-    explicit PropertySizeEditor(QWidget *parent = 0);
+    explicit PropertySizeEditor(QWidget *parent = nullptr);
 
     QSize sizeValue() const;
     void setSizeValue(const QSize &size);
