@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,8 +46,8 @@ QVector<PropertyWidget *> PropertyWidget::s_propertyWidgets;
 PropertyWidget::PropertyWidget(QWidget *parent)
     : QTabWidget(parent)
     , m_tabsUpdatedTimer(new QTimer(this))
-    , m_lastManuallySelectedWidget(Q_NULLPTR)
-    , m_controller(0)
+    , m_lastManuallySelectedWidget(nullptr)
+    , m_controller(nullptr)
 {
     m_tabsUpdatedTimer->setInterval(100);
     m_tabsUpdatedTimer->setSingleShot(true);
