@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -28,12 +28,14 @@
 
 #include "remoteviewwidget.h"
 #include "modelpickerdialog.h"
+#include <visibilityfilterproxymodel.h>
 
-#include <common/remoteviewinterface.h>
-#include <common/objectbroker.h>
 #include <common/endpoint.h>
+#include <common/objectbroker.h>
 #include <common/objectidfilterproxymodel.h>
 #include <common/objectmodel.h>
+#include <common/remoteviewinterface.h>
+#include <common/streamoperators.h>
 
 #include <QAction>
 #include <QActionGroup>
@@ -47,6 +49,11 @@
 #include <cstdlib>
 
 using namespace GammaRay;
+static qint32 RemoteViewWidgetStateVersion = 1;
+
+QT_BEGIN_NAMESPACE
+GAMMARAY_ENUM_STREAM_OPERATORS(GammaRay::RemoteViewWidget::InteractionMode)
+QT_END_NAMESPACE
 
 RemoteViewWidget::RemoteViewWidget(QWidget *parent)
     : QWidget(parent)
@@ -60,11 +67,17 @@ RemoteViewWidget::RemoteViewWidget(QWidget *parent)
     , m_supportedInteractionModes(ViewInteraction | Measuring | ElementPicking | InputRedirection)
     , m_hasMeasurement(false)
     , m_pickProxyModel(new ObjectIdsFilterProxyModel(this))
+    , m_invisibleItemsProxyModel (new VisibilityFilterProxyModel(this))
+    , m_initialZoomDone(false)
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     setMouseTracking(true);
     setMinimumSize(QSize(400, 300));
     setFocusPolicy(Qt::StrongFocus);
+    window()->setAttribute(Qt::WA_AcceptTouchEvents);
+    window()->setAttribute(Qt::WA_TouchPadAcceptSingleTouchEvents);
+    setAttribute(Qt::WA_AcceptTouchEvents);
+    setAttribute(Qt::WA_TouchPadAcceptSingleTouchEvents);
 
     // Background
     QPixmap bgPattern(20, 20);
@@ -104,6 +117,7 @@ void RemoteViewWidget::setName(const QString &name)
     connect(m_interface, SIGNAL(elementsAtReceived(GammaRay::ObjectIds,int)), this, SLOT(elementsAtReceived(GammaRay::ObjectIds,int)));
     connect(m_interface, SIGNAL(frameUpdated(GammaRay::RemoteViewFrame)), this,
             SLOT(frameUpdated(GammaRay::RemoteViewFrame)));
+    connect(m_interface, SIGNAL(requestClearFrameData()), this, SLOT(clearFrameData()));
     m_interface->clientViewUpdated();
 }
 
@@ -200,9 +214,14 @@ void RemoteViewWidget::elementsAtReceived(const GammaRay::ObjectIds &ids, int be
     else {
         const int candidate = bestCandidate == -1 ? 0 : bestCandidate;
         ModelPickerDialog *dlg = new ModelPickerDialog(window());
-        dlg->setModel(m_pickProxyModel);
+        m_invisibleItemsProxyModel->setSourceModel(m_pickProxyModel);
+        m_invisibleItemsProxyModel->setFlagRole(flagRole());
+        m_invisibleItemsProxyModel->setInvisibleMask(invisibleMask());
+
+        dlg->setModel(m_invisibleItemsProxyModel);
         dlg->setCurrentIndex(ObjectModel::ObjectIdRole, QVariant::fromValue(ids[candidate]));
         connect(dlg, SIGNAL(activated(QModelIndex)), this, SLOT(pickElementId(QModelIndex)));
+        connect(dlg, SIGNAL(checkBoxStateChanged(bool)), m_invisibleItemsProxyModel, SLOT(setHideItems(bool)));
         dlg->open();
     }
 }
@@ -211,7 +230,10 @@ void RemoteViewWidget::frameUpdated(const RemoteViewFrame &frame)
 {
     if (!m_frame.isValid()) {
         m_frame = frame;
-        fitToView();
+        if (m_initialZoomDone)
+            centerView();
+        else
+            fitToView();
     } else {
         m_frame = frame;
         update();
@@ -221,6 +243,35 @@ void RemoteViewWidget::frameUpdated(const RemoteViewFrame &frame)
     QMetaObject::invokeMethod(m_interface, "clientViewUpdated", Qt::QueuedConnection);
 }
 
+void RemoteViewWidget::clearFrameData()
+{
+    if (!m_frame.isValid())
+        return;
+    auto frame = m_frame;
+    frame.setData(QVariant());
+    frameUpdated(frame);
+}
+
+int RemoteViewWidget::invisibleMask() const
+{
+    return m_invisibleMask;
+}
+
+void RemoteViewWidget::setInvisibleMask(int invisibleMask)
+{
+    m_invisibleMask = invisibleMask;
+}
+
+int RemoteViewWidget::flagRole() const
+{
+    return m_flagRole;
+}
+
+void RemoteViewWidget::setFlagRole(int flagRole)
+{
+    m_flagRole = flagRole;
+}
+
 QAbstractItemModel *RemoteViewWidget::pickSourceModel() const
 {
     return m_pickProxyModel->sourceModel();
@@ -262,6 +313,27 @@ QAction *RemoteViewWidget::zoomInAction() const
     return m_zoomInAction;
 }
 
+void RemoteViewWidget::restoreState(const QByteArray &state)
+{
+    if (state.isEmpty())
+        return;
+
+    QDataStream stream(state);
+    restoreState(stream);
+}
+
+QByteArray RemoteViewWidget::saveState() const
+{
+    QByteArray data;
+
+    {
+        QDataStream stream(&data, QIODevice::WriteOnly);
+        saveState(stream);
+    }
+
+    return data;
+}
+
 double RemoteViewWidget::zoom() const
 {
     return m_zoom;
@@ -294,8 +366,10 @@ void RemoteViewWidget::setZoom(double zoom)
     if (m_zoomLevels.at(index) == oldZoom)
         return;
     m_zoom = m_zoomLevels.at(index);
+    m_initialZoomDone = true;
     emit zoomChanged();
     emit zoomLevelChanged(index);
+    emit stateChanged();
 
     m_x = contentWidth() / 2 - (contentWidth() / 2 - m_x) * m_zoom / oldZoom;
     m_y = contentHeight() / 2 - (contentHeight() / 2 - m_y) * m_zoom / oldZoom;
@@ -340,6 +414,11 @@ void RemoteViewWidget::fitToView()
                                     (double)contentHeight()
                                     / (double)m_frame.sceneRect().height()));
     setZoom(scale);
+    centerView();
+}
+
+void RemoteViewWidget::centerView()
+{
     m_x = 0.5 * (contentWidth() - m_frame.sceneRect().width() * m_zoom);
     m_y = 0.5 * (contentHeight() - m_frame.sceneRect().height() * m_zoom);
     update();
@@ -381,6 +460,7 @@ void RemoteViewWidget::setInteractionMode(RemoteViewWidget::InteractionMode mode
     }
 
     update();
+    emit stateChanged();
 }
 
 RemoteViewWidget::InteractionModes RemoteViewWidget::supportedInteractionModes() const
@@ -639,11 +719,98 @@ QPoint RemoteViewWidget::mapToSource(QPoint pos) const
     return (pos - QPoint(m_x, m_y)) / m_zoom;
 }
 
+QPointF RemoteViewWidget::mapToSource(QPointF pos) const
+{
+    return (pos - QPointF(m_x, m_y)) / m_zoom;
+}
+
+QRectF RemoteViewWidget::mapToSource(const QRectF &r) const
+{
+    return QRectF(mapToSource(r.topLeft()), mapToSource(r.bottomRight()));
+}
+
 QPoint RemoteViewWidget::mapFromSource(QPoint pos) const
 {
     return pos * m_zoom + QPoint(m_x, m_y);
 }
 
+QPointF RemoteViewWidget::mapFromSource(QPointF pos) const
+{
+    return pos * m_zoom + QPointF(m_x, m_y);
+}
+
+QTouchEvent::TouchPoint RemoteViewWidget::mapToSource(const QTouchEvent::TouchPoint &point)
+{
+    QTouchEvent::TouchPoint p;
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    p.setFlags(point.flags());
+#endif
+    p.setId(point.id());
+    p.setPressure(point.pressure());
+    p.setState(point.state());
+
+    p.setStartPos(mapToSource(point.startPos()));
+    p.setLastPos(mapToSource(point.lastPos()));
+    p.setPos(mapToSource(point.pos())); // relative
+    p.setRect(mapToSource(point.rect()));
+
+    p.setStartNormalizedPos(mapToSource(point.startNormalizedPos()));
+    p.setLastNormalizedPos(mapToSource(point.lastNormalizedPos()));
+    p.setNormalizedPos(mapToSource(point.normalizedPos()));
+
+    p.setStartScenePos(mapToSource(point.startScenePos()));
+    p.setLastScenePos(mapToSource(point.lastScenePos()));
+    p.setScenePos(mapToSource(point.scenePos()));
+    p.setSceneRect(mapToSource(point.sceneRect()));
+
+    // These may not have the right x,y but i don't think there is a way to get the right value.
+    // On the other hand, it's not a problem, probably
+    p.setStartScreenPos(mapToSource(point.startScreenPos()));
+    p.setLastScreenPos(mapToSource(point.lastScreenPos()));
+    p.setScreenPos(mapToSource(point.screenPos()));
+    p.setScreenRect(mapToSource(point.screenRect()));
+
+    return p;
+}
+
+void RemoteViewWidget::restoreState(QDataStream &stream)
+{
+    stream.setVersion(QDataStream::Qt_4_8);
+
+    qint32 version;
+    InteractionMode interactionMode = m_interactionMode;
+    double zoom = m_zoom;
+
+    stream >> version;
+
+    switch (version) {
+    case 1: {
+        stream >> interactionMode;
+        stream >> zoom;
+        break;
+    }
+    }
+
+    setInteractionMode(interactionMode);
+    setZoom(zoom);
+}
+
+void RemoteViewWidget::saveState(QDataStream &stream) const
+{
+    stream.setVersion(QDataStream::Qt_4_8);
+
+    stream << RemoteViewWidgetStateVersion;
+
+    switch (RemoteViewWidgetStateVersion) {
+    case 1: {
+        stream << m_interactionMode;
+        stream << m_zoom;
+        break;
+    }
+    }
+}
+
 void RemoteViewWidget::clampPanPosition()
 {
     if (m_x > width() / 2)
@@ -868,6 +1035,27 @@ bool RemoteViewWidget::eventFilter(QObject *receiver, QEvent *event)
     return QWidget::eventFilter(receiver, event);
 }
 
+bool RemoteViewWidget::event(QEvent *event)
+{
+    if (m_interactionMode == InputRedirection) {
+        switch (event->type()) {
+        case QEvent::TouchBegin:
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+        case QEvent::TouchCancel:
+#endif
+        case QEvent::TouchEnd:
+        case QEvent::TouchUpdate:
+            sendTouchEvent(static_cast<QTouchEvent *>(event));
+            return true;
+
+        default:
+            break;
+        }
+    }
+
+    return QWidget::event(event);
+}
+
 int RemoteViewWidget::contentWidth() const
 {
     return width() - verticalRulerWidth();
@@ -922,3 +1110,29 @@ void RemoteViewWidget::sendWheelEvent(QWheelEvent *event)
     m_interface->sendWheelEvent(mapToSource(event->pos()), pixelDelta, angleDelta,
                                 event->buttons(), event->modifiers());
 }
+
+void RemoteViewWidget::sendTouchEvent(QTouchEvent *event)
+{
+    event->accept();
+
+    QList<QTouchEvent::TouchPoint> touchPoints;
+    foreach (const QTouchEvent::TouchPoint &point, event->touchPoints()) {
+        touchPoints << mapToSource(point);
+    }
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    QTouchDevice::Capabilities caps = event->device()->capabilities();
+    caps &= ~QTouchDevice::RawPositions; //we don't have a way to meaningfully map the raw positions to the source
+    caps &= ~QTouchDevice::Velocity; //neither for velocity
+#endif
+
+    m_interface->sendTouchEvent(event->type(),
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+                                event->device()->type(),
+                                caps,
+                                event->device()->maximumTouchPoints(),
+#else
+                                event->deviceType(), 0, 0,
+#endif
+                                event->modifiers(), event->touchPointStates(), touchPoints);
+}
