@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
   Author: Volker Krause <volker.krause@kdab.com>
 
@@ -36,6 +36,7 @@
 #include <common/remoteviewframe.h>
 
 #include <QWidget>
+#include <QTouchEvent>
 #include <QPointer>
 
 QT_BEGIN_NAMESPACE
@@ -43,11 +44,14 @@ class QAbstractItemModel;
 class QActionGroup;
 class QStandardItemModel;
 class QModelIndex;
+class QEvent;
+class QTouchEvent;
 QT_END_NAMESPACE
 
 namespace GammaRay {
 class RemoteViewInterface;
 class ObjectIdsFilterProxyModel;
+class VisibilityFilterProxyModel;
 
 /** Widget showing remote screen content and providing both visual inspection
  *  capabilities as well as input redirection.
@@ -58,7 +62,7 @@ class GAMMARAY_UI_EXPORT RemoteViewWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit RemoteViewWidget(QWidget *parent = Q_NULLPTR);
+    explicit RemoteViewWidget(QWidget *parent = nullptr);
     ~RemoteViewWidget();
 
     /// Set the object name for connecting to the server.
@@ -96,6 +100,15 @@ public:
     QAbstractItemModel *pickSourceModel() const;
     void setPickSourceModel(QAbstractItemModel *pickSourceModel);
 
+    virtual void restoreState(const QByteArray &state);
+    virtual QByteArray saveState() const;
+
+    int flagRole() const;
+    void setFlagRole(int flagRole);
+
+    int invisibleMask() const;
+    void setInvisibleMask(int invisibleMask);
+
 public slots:
     /// Clears the current view content.
     void reset();
@@ -106,10 +119,12 @@ public slots:
     void zoomIn();
     void zoomOut();
     void fitToView();
+    void centerView();
 
 signals:
     void zoomChanged();
     void zoomLevelChanged(int zoomLevelIndex);
+    void stateChanged();
 
 protected:
     /** Current frame data. */
@@ -122,22 +137,31 @@ protected:
 
     // translate from view coordinates to source coordinates
     QPoint mapToSource(QPoint pos) const;
+    QPointF mapToSource(QPointF pos) const;
+    QRectF mapToSource(const QRectF &r) const;
     // translates from source coordinates to view coordinates
     QPoint mapFromSource(QPoint pos) const;
+    QPointF mapFromSource(QPointF pos) const;
+    // translate from view to source coordinates
+    QTouchEvent::TouchPoint mapToSource(const QTouchEvent::TouchPoint &point);
 
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
-    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
-    void hideEvent(QHideEvent *event) Q_DECL_OVERRIDE;
-    void contextMenuEvent(QContextMenuEvent *event) Q_DECL_OVERRIDE;
+    void restoreState(QDataStream &stream);
+    void saveState(QDataStream &stream) const;
 
-    bool eventFilter(QObject *receiver, QEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
+    void mousePressEvent(QMouseEvent *event) override;
+    void mouseReleaseEvent(QMouseEvent *event) override;
+    void mouseMoveEvent(QMouseEvent *event) override;
+    void wheelEvent(QWheelEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
+    void keyReleaseEvent(QKeyEvent *event) override;
+    void showEvent(QShowEvent *event) override;
+    void hideEvent(QHideEvent *event) override;
+    void contextMenuEvent(QContextMenuEvent *event) override;
+
+    bool eventFilter(QObject *receiver, QEvent *event) override;
+    bool event(QEvent *event) override;
 
 private:
     void setupActions();
@@ -154,6 +178,7 @@ private:
     void sendMouseEvent(QMouseEvent *event);
     void sendKeyEvent(QKeyEvent *event);
     void sendWheelEvent(QWheelEvent *event);
+    void sendTouchEvent(QTouchEvent *event);
 
     // size of the content area, ie. excluding the rulers
     int contentWidth() const;
@@ -168,6 +193,7 @@ private slots:
     void pickElementId(const QModelIndex &index);
     void elementsAtReceived(const GammaRay::ObjectIds &ids, int bestCandidate);
     void frameUpdated(const GammaRay::RemoteViewFrame &frame);
+    void clearFrameData();
 
 private:
     RemoteViewFrame m_frame;
@@ -191,6 +217,10 @@ private:
     QPoint m_measurementEndPosition; // in source coordinates
     bool m_hasMeasurement;
     ObjectIdsFilterProxyModel *m_pickProxyModel;
+    VisibilityFilterProxyModel *m_invisibleItemsProxyModel;
+    bool m_initialZoomDone;
+    int m_flagRole;
+    int m_invisibleMask;
 };
 }
 
