@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,13 +36,13 @@ using namespace GammaRay;
 class Delegate : public QStyledItemDelegate
 {
 public:
-    explicit Delegate(QObject *parent = 0)
+    explicit Delegate(QObject *parent = nullptr)
         : QStyledItemDelegate(parent)
     {
     }
 
     QSize sizeHint(const QStyleOptionViewItem &option,
-                   const QModelIndex &index) const Q_DECL_OVERRIDE
+                   const QModelIndex &index) const override
     {
         static const int heightMargin = 10;
 
