@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -30,8 +30,10 @@
 
 #include <QSplashScreen>
 #include <QBitmap>
+#include <QApplication>
+#include <QDesktopWidget>
 
-QSplashScreen *splash = 0;
+QSplashScreen *splash = nullptr;
 
 namespace GammaRay {
 void showSplashScreen()
@@ -42,6 +44,18 @@ void showSplashScreen()
         splash->setMask(pixmap.mask());
     }
 
+    const QWidget *window = qApp->activeWindow();
+
+    if (window && window != splash) {
+        splash->ensurePolished();
+
+        const QRect windowRect = qApp->desktop()->availableGeometry(window);
+        QRect splashRect = QRect(QPoint(), splash->size());
+
+        splashRect.moveCenter(windowRect.center());
+        splash->move(splashRect.topLeft());
+    }
+
     splash->show();
 }
 
