@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,7 +37,7 @@ class MessageHandlerClient : public MessageHandlerInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::MessageHandlerInterface)
 public:
-    explicit MessageHandlerClient(QObject *parent = 0);
+    explicit MessageHandlerClient(QObject *parent = nullptr);
 };
 }
 
