@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -38,17 +38,19 @@ class MetaObjectTreeClientProxyModel : public QIdentityProxyModel
 {
     Q_OBJECT
 public:
-    explicit MetaObjectTreeClientProxyModel(QObject *parent = Q_NULLPTR);
+    explicit MetaObjectTreeClientProxyModel(QObject *parent = nullptr);
     ~MetaObjectTreeClientProxyModel();
 
-    void setSourceModel(QAbstractItemModel *source) Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    void setSourceModel(QAbstractItemModel *source) override;
+    QVariant data(const QModelIndex &index, int role) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
 private slots:
     void findQObjectIndex();
 
 private:
+    bool needsBackground(const QModelIndex &index) const;
+
     QPersistentModelIndex m_qobjIndex;
 };
 }
