@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,12 +37,12 @@ class ConnectionsExtensionClient : public ConnectionsExtensionInterface
     Q_OBJECT
     Q_INTERFACES(GammaRay::ConnectionsExtensionInterface)
 public:
-    explicit ConnectionsExtensionClient(const QString &name, QObject *parent = 0);
+    explicit ConnectionsExtensionClient(const QString &name, QObject *parent = nullptr);
     virtual ~ConnectionsExtensionClient();
 
 public slots:
-    void navigateToReceiver(int modelRow) Q_DECL_OVERRIDE;
-    void navigateToSender(int modelRow) Q_DECL_OVERRIDE;
+    void navigateToReceiver(int modelRow) override;
+    void navigateToSender(int modelRow) override;
 };
 }
 
