@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,7 +49,7 @@ using namespace GammaRay;
 MethodsTab::MethodsTab(PropertyWidget *parent)
     : QWidget(parent)
     , m_ui(new Ui_MethodsTab)
-    , m_interface(0)
+    , m_interface(nullptr)
 {
     m_ui->setupUi(this);
     m_ui->methodView->header()->setObjectName("methodViewHeader");
@@ -109,7 +109,7 @@ void MethodsTab::methodContextMenu(const QPoint &pos)
     const QMetaMethod::MethodType methodType
         = index.data(ObjectMethodModelRole::MetaMethodType).value<QMetaMethod::MethodType>();
     QMenu contextMenu;
-    QAction *invokeAction = 0, *connectToAction = 0;
+    QAction *invokeAction = nullptr, *connectToAction = nullptr;
     if (methodType == QMetaMethod::Slot || methodType == QMetaMethod::Method) {
         invokeAction = contextMenu.addAction(tr("Invoke"));
     } else if (methodType == QMetaMethod::Signal) {
