@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -75,7 +75,7 @@ ObjectInspectorWidget::ObjectInspectorWidget(QWidget *parent)
 
     m_stateManager.setDefaultSizes(ui->mainSplitter, UISizeVector() << "60%" << "40%");
 
-    connect(ui->objectPropertyWidget, SIGNAL(tabsUpdated()), &m_stateManager, SLOT(reset()));
+    connect(ui->objectPropertyWidget, SIGNAL(tabsUpdated()), this, SLOT(propertyWidgetTabsChanged()));
 }
 
 ObjectInspectorWidget::~ObjectInspectorWidget()
@@ -107,3 +107,9 @@ void ObjectInspectorWidget::objectContextMenuRequested(const QPoint &pos)
 
     menu.exec(ui->objectTreeView->viewport()->mapToGlobal(pos));
 }
+
+void ObjectInspectorWidget::propertyWidgetTabsChanged()
+{
+    m_stateManager.saveState();
+    m_stateManager.reset();
+}
