@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -48,7 +48,7 @@ class ResourceBrowserWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ResourceBrowserWidget(QWidget *parent = 0);
+    explicit ResourceBrowserWidget(QWidget *parent = nullptr);
     ~ResourceBrowserWidget();
 
 public slots:
