@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -47,11 +47,11 @@ class StandardPathsProxy : public QIdentityProxyModel
 {
     Q_OBJECT
 public:
-    StandardPathsProxy(QObject *parent = 0)
+    StandardPathsProxy(QObject *parent = nullptr)
         : QIdentityProxyModel(parent) { }
 
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+                        int role = Qt::DisplayRole) const override
     {
         if (section == 2 && role == Qt::DisplayRole)
             return tr("Locations Standard / Writable");
@@ -64,11 +64,11 @@ class StandardPathsDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
-    StandardPathsDelegate(QObject *parent = 0)
+    StandardPathsDelegate(QObject *parent = nullptr)
         : QStyledItemDelegate(parent) { }
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex &index) const Q_DECL_OVERRIDE
+               const QModelIndex &index) const override
     {
         if (index.column() == 2) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
@@ -83,7 +83,7 @@ public:
             QStyle *style = widget ? widget->style() : QApplication::style();
             style->drawControl(QStyle::CE_ItemViewItem, &opt, painter, widget);
 
-            const int textMargin = style->pixelMetric(QStyle::PM_FocusFrameHMargin, 0, widget) + 1;
+            const int textMargin = style->pixelMetric(QStyle::PM_FocusFrameHMargin, nullptr, widget) + 1;
             const QRect textRect = style->subElementRect(QStyle::SE_ItemViewItemText, &opt, widget)
                                    .adjusted(textMargin, 1, -textMargin, -1);
             painter->setPen(((opt.state
@@ -97,7 +97,7 @@ public:
     }
 
     QSize sizeHint(const QStyleOptionViewItem &option,
-                   const QModelIndex &index) const Q_DECL_OVERRIDE
+                   const QModelIndex &index) const override
     {
         if (index.column() == 2) {
             QSize s1 = QStyledItemDelegate::sizeHint(option, index.sibling(index.row(), 2));
