@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -91,12 +91,12 @@ template<typename ToolUi>
 class StandardToolUiFactory : public ToolUiFactory
 {
 public:
-    QString id() const Q_DECL_OVERRIDE
+    QString id() const override
     {
         return QString(); // TODO is this a problem??
     }
 
-    QWidget *createWidget(QWidget *parentWidget) Q_DECL_OVERRIDE
+    QWidget *createWidget(QWidget *parentWidget) override
     {
         return new ToolUi(parentWidget);
     }
