@@ -2,7 +2,7 @@
  * This file is part of GammaRay, the Qt application inspection and
  * manipulation tool.
  *
- * Copyright (C) 2014-2016 Klar?lvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+ * Copyright (C) 2014-2017 Klar?lvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  * Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
  *
  * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,7 +31,7 @@
 
 using namespace GammaRay;
 
-UiIntegration *UiIntegration::s_uiIntegrationInstance = 0;
+UiIntegration *UiIntegration::s_uiIntegrationInstance = nullptr;
 
 UiIntegration::UiIntegration(QObject *parent)
     : QObject(parent)
@@ -42,7 +42,7 @@ UiIntegration::UiIntegration(QObject *parent)
 
 UiIntegration::~UiIntegration()
 {
-    s_uiIntegrationInstance = 0;
+    s_uiIntegrationInstance = nullptr;
 }
 
 UiIntegration *UiIntegration::instance()
