@@ -2,7 +2,7 @@
  * This file is part of GammaRay, the Qt application inspection and
  * manipulation tool.
  *
- * Copyright (C) 2014-2016 Klar?lvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+ * Copyright (C) 2014-2017 Klar?lvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  * Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
  *
  * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,7 +46,7 @@ class GAMMARAY_UI_EXPORT UiIntegration : public QObject
     Q_OBJECT
 public:
 
-    explicit UiIntegration(QObject *parent = 0);
+    explicit UiIntegration(QObject *parent = nullptr);
     virtual ~UiIntegration();
 
     static UiIntegration *instance();
