@@ -2,7 +2,7 @@
  * This file is part of GammaRay, the Qt application inspection and
  * manipulation tool.
  *
- * Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+ * Copyright (C) 2014-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  * Author: Filipe Azevedo <filipe.azevedo@kdab.com>
  *
  * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -28,6 +28,7 @@
 #include "uistatemanager.h"
 #include "deferredtreeview.h"
 #include "deferredtreeview_p.h"
+#include "common/endpoint.h"
 #include "common/settempvalue.h"
 
 #include <QApplication>
@@ -85,8 +86,12 @@ UIStateManager::UIStateManager(QWidget *widget)
     , m_stateSettings(new QSettings("KDAB", "GammaRay", this))
     , m_initialized(false)
     , m_resizing(false)
+    , m_targetStateSource(nullptr)
+    , m_targetRestoreMethodId(-1)
+    , m_targetSaveMethodId(-1)
 {
     Q_ASSERT(m_widget);
+
     m_widget->installEventFilter(this);
 }
 
@@ -94,6 +99,16 @@ UIStateManager::~UIStateManager()
 {
 }
 
+QWidget *UIStateManager::widget() const
+{
+    return m_widget;
+}
+
+bool UIStateManager::initialized() const
+{
+    return m_initialized;
+}
+
 QList<QSplitter *> UIStateManager::splitters() const
 {
     return m_widget->findChildren<QSplitter *>();
@@ -106,6 +121,8 @@ QList<QHeaderView *> UIStateManager::headers() const
 
 void UIStateManager::setup()
 {
+    Q_ASSERT(Endpoint::instance()->isConnected());
+    Q_ASSERT(!m_initialized);
     if (!checkWidget(m_widget))
         return;
 
@@ -159,18 +176,70 @@ void UIStateManager::setup()
         view->installEventFilter(this);
     }
 
+    // Try to find methods on widget
+    m_targetStateSource = m_widget->metaObject();
+    m_targetRestoreMethodId = m_targetStateSource->indexOfMethod("restoreTargetState(QSettings*)");
+    m_targetSaveMethodId = m_targetStateSource->indexOfMethod("saveTargetState(QSettings*)");
+
+    // Here for inherited UIStateManager where widget is not modifiable (ie: QtC)
+    if (m_targetRestoreMethodId == -1 || m_targetSaveMethodId == -1) {
+        m_targetStateSource = metaObject();
+        m_targetRestoreMethodId = m_targetStateSource->indexOfMethod("restoreTargetState(QSettings*)");
+        m_targetSaveMethodId = m_targetStateSource->indexOfMethod("saveTargetState(QSettings*)");
+    }
+
+    if (m_targetRestoreMethodId == -1 || m_targetSaveMethodId == -1) {
+        m_targetStateSource = nullptr;
+        m_targetRestoreMethodId = -1;
+        m_targetSaveMethodId = -1;
+    }
+
     restoreState();
 }
 
 void UIStateManager::restoreState()
 {
+    Q_ASSERT(Endpoint::instance()->isConnected());
+
+    if (!m_initialized) {
+        qWarning() << Q_FUNC_INFO << "Attempting to restoreState for a not yet initialized state manager.";
+        return;
+    }
+
     restoreWindowState();
     restoreSplitterState();
     restoreHeaderState();
+
+    // Allow restore state per end point
+    if (m_targetStateSource) {
+        Q_ASSERT(!Endpoint::instance()->key().isEmpty());
+        m_stateSettings->beginGroup(Endpoint::instance()->key());
+        QMetaMethod method = m_targetStateSource->method(m_targetRestoreMethodId);
+        QObject *target = m_targetStateSource == m_widget->metaObject() ? qobject_cast<QObject *>(m_widget) : this;
+        method.invoke(target, Q_ARG(QSettings *, m_stateSettings));
+        m_stateSettings->endGroup();
+    }
 }
 
 void UIStateManager::saveState()
 {
+    Q_ASSERT(Endpoint::instance()->isConnected());
+
+    if (!m_initialized) {
+        qWarning() << Q_FUNC_INFO << "Attempting to saveState for a not yet initialized state manager.";
+        return;
+    }
+
+    // Allow save state per end point
+    if (m_targetStateSource) {
+        Q_ASSERT(!Endpoint::instance()->key().isEmpty());
+        m_stateSettings->beginGroup(Endpoint::instance()->key());
+        QMetaMethod method = m_targetStateSource->method(m_targetSaveMethodId);
+        QObject *target = m_targetStateSource == m_widget->metaObject() ? qobject_cast<QObject *>(m_widget) : this;
+        method.invoke(target, Q_ARG(QSettings *, m_stateSettings));
+        m_stateSettings->endGroup();
+    }
+
     saveWindowState();
     saveSplitterState();
     saveHeaderState();
@@ -178,7 +247,9 @@ void UIStateManager::saveState()
 
 bool UIStateManager::eventFilter(QObject *object, QEvent *event)
 {
-    if (object == m_widget) {
+    const bool connected = Endpoint::instance()->isConnected();
+
+    if (connected && object == m_widget) {
         if (event->type() == QEvent::Hide) {
             if (m_initialized)
                 saveState();
@@ -187,14 +258,14 @@ bool UIStateManager::eventFilter(QObject *object, QEvent *event)
 
     const bool result = QObject::eventFilter(object, event);
 
-    if (object == m_widget) {
+    if (connected && object == m_widget) {
         if (event->type() == QEvent::Show) {
             if (!m_initialized)
                 setup();
         }
     }
 
-    if (event->type() == QEvent::Resize) {
+    if (connected && event->type() == QEvent::Resize) {
         if (m_initialized && !m_resizing)
             widgetResized(qobject_cast<QWidget *>(object));
     }
@@ -246,8 +317,10 @@ void UIStateManager::setDefaultSizes(QHeaderView *header, const UISizeVector &de
 
 void UIStateManager::reset()
 {
-    m_initialized = false;
-    m_stateSettings->endGroup();
+    if (m_initialized) {
+        m_initialized = false;
+        m_stateSettings->endGroup();
+    }
     setup();
 }
 
